@@ -1,7 +1,7 @@
 <?php
 //
-// ZoneMinder web function library, $Date: 2005/01/26 20:52:59 $, $Revision: 1.42 $
-// Copyright (C) 2003  Philip Coombes
+// ZoneMinder web function library, $Date: 2005/03/13 20:40:49 $, $Revision: 1.46 $
+// Copyright (C) 2003, 2004, 2005  Philip Coombes
 // 
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -18,9 +18,24 @@
 // Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 // 
 
+// Compatibility functions
+if ( version_compare( phpversion(), "4.3.0", "<") )
+{
+	function ob_get_clean()
+	{
+		$buffer = ob_get_contents();
+		ob_end_clean();
+		return( $buffer );
+	}
+}
+
 function userLogin( $username, $password )
 {
-	global $user, $cookies, $_SESSION, $_SERVER;
+	global $user, $cookies;
+	if ( version_compare( phpversion(), "4.1.0", "<") )
+	{
+		global $_SESSION, $_SERVER;
+	}
 
 	$sql = "select * from Users where Username = '".mysql_escape_string($username)."' and Password = password('".mysql_escape_string($password)."') and Enabled = 1";
 	$result = mysql_query( $sql );
@@ -47,7 +62,11 @@ function userLogin( $username, $password )
 
 function userLogout()
 {
-	global $user, $_SESSION;
+	global $user;
+	if ( version_compare( phpversion(), "4.1.0", "<") )
+	{
+		global $_SESSION;
+	}
 
 	unset( $_SESSION['user'] );
 	unset( $user );
@@ -57,7 +76,10 @@ function userLogout()
 
 function authHash( $use_remote_addr=true )
 {
-	global $_SESSION;
+	if ( version_compare( phpversion(), "4.1.0", "<") )
+	{
+		global $_SESSION;
+	}
 
 	if ( ZM_OPT_USE_AUTH && ZM_AUTH_METHOD == "hashed" )
 	{
@@ -81,7 +103,10 @@ function authHash( $use_remote_addr=true )
 
 function getStreamSrc( $args )
 {
-	global $_SESSION;
+	if ( version_compare( phpversion(), "4.1.0", "<") )
+	{
+		global $_SESSION;
+	}
 
 	$stream_src = ZM_PATH_ZMS;
 
@@ -112,7 +137,10 @@ function getStreamSrc( $args )
 
 function getZmuCommand( $args )
 {
-	global $_SESSION;
+	if ( version_compare( phpversion(), "4.1.0", "<") )
+	{
+		global $_SESSION;
+	}
 
 	$zmu_command = ZMU_PATH;
 
@@ -229,7 +257,7 @@ function buildSelect( $name, $contents, $onchange="" )
 	return( $html );
 }
 
-function getFormChanges( $values, $new_values, $types=false )
+function getFormChanges( $values, $new_values, $types=false, $columns=false )
 {
 	$changes = array();
 	if ( !$types )
@@ -237,6 +265,9 @@ function getFormChanges( $values, $new_values, $types=false )
 
 	foreach( $new_values as $key=>$value )
 	{
+		if ( $columns && !$columns[$key] )
+			continue;
+
 		switch( $types[$key] )
 		{
 			case 'set' :
@@ -254,6 +285,62 @@ function getFormChanges( $values, $new_values, $types=false )
 				}
 				break;
 			}
+			case 'image' :
+			{
+				if ( is_array( $new_values[$key] ) )
+				{
+					$image_data = getimagesize( $new_values[$key]['tmp_name'] );
+					$changes[$key.'Width'] = $key."Width = ".$image_data[0];
+					$changes[$key.'Height'] = $key."Height = ".$image_data[1];
+					$changes[$key.'Type'] = $key."Type = '".$new_values[$key]['type']."'";
+					$changes[$key.'Size'] = $key."Size = ".$new_values[$key]['size'];
+					ob_start();
+					readfile( $new_values[$key]['tmp_name'] );
+					$changes[$key] = $key." = '".addslashes( ob_get_contents() )."'";
+					ob_end_clean();
+				}
+				else
+				{
+					$changes[] = "$key = '$value'";
+				}
+				break;
+			}
+			case 'document' :
+			{
+				if ( is_array( $new_values[$key] ) )
+				{
+					$image_data = getimagesize( $new_values[$key]['tmp_name'] );
+					$changes[$key.'Type'] = $key."Type = '".$new_values[$key]['type']."'";
+					$changes[$key.'Size'] = $key."Size = ".$new_values[$key]['size'];
+					ob_start();
+					readfile( $new_values[$key]['tmp_name'] );
+					$changes[$key] = $key." = '".addslashes( ob_get_contents() )."'";
+					ob_end_clean();
+				}
+				else
+				{
+					$changes[] = "$key = '$value'";
+				}
+				break;
+			}
+			case 'file' :
+			{
+				$changes[$key.'Type'] = $key."Type = '".$new_values[$key]['type']."'";
+				$changes[$key.'Size'] = $key."Size = ".$new_values[$key]['size'];
+				ob_start();
+				readfile( $new_values[$key]['tmp_name'] );
+				$changes[$key] = $key." = '".addslashes( ob_get_contents() )."'";
+				ob_end_clean();
+				break;
+			}
+			case 'raw' :
+			{
+				if ( $values[$key] != $value )
+				{
+					$changes[] = "$key = $value";
+				}
+				break;
+			}
 			default :
 			{
 				if ( $values[$key] != $value )
@@ -264,12 +351,25 @@ function getFormChanges( $values, $new_values, $types=false )
 			}
 		}
 	}
+	foreach( $values as $key=>$value )
+	{
+		if ( $columns[$key] && $types[$key] == 'toggle' )
+		{
+			if ( !isset($new_values[$key]) && !empty($value) )
+			{
+				$changes[] = "$key = 0";
+			}
+		}
+	}
 	return( $changes );
 }
 
 function getBrowser( &$browser, &$version )
 {
-	global $_SERVER;
+	if ( version_compare( phpversion(), "4.1.0", "<") )
+	{
+		global $_SERVER;
+	}
 
 	if (ereg( 'MSIE ([0-9].[0-9]{1,2})',$_SERVER['HTTP_USER_AGENT'],$log_version))
 	{
@@ -314,7 +414,10 @@ function isInternetExplorer()
 
 function isWindows()
 {
-	global $_SERVER;
+	if ( version_compare( phpversion(), "4.1.0", "<") )
+	{
+		global $_SERVER;
+	}
 
 	return ( preg_match( '/Win/', $_SERVER['HTTP_USER_AGENT'] ) );
 }
@@ -419,6 +522,10 @@ function zmaControl( $monitor, $restart=false )
 		{
 			if ( $restart )
 			{
+				if ( ZM_OPT_CONTROL )
+				{
+					daemonControl( "stop", "zmtrack.pl", "-m ".$monitor['Id'] );
+				}
 				daemonControl( "stop", "zma", "-m ".$monitor['Id'] );
 				if ( ZM_OPT_FRAME_SERVER )
 				{
@@ -430,10 +537,18 @@ function zmaControl( $monitor, $restart=false )
 				daemonControl( "start", "zmf", "-m ".$monitor['Id'] );
 			}
 			daemonControl( "start", "zma", "-m ".$monitor['Id'] );
+			if ( ZM_OPT_CONTROL && $monitor['Controllable'] && $monitor['TrackMotion'] && ( $monitor['Function'] == 'Modect' || $monitor['Function'] == 'Mocord' ) )
+			{
+				daemonControl( "start", "zmtrack.pl", "-m ".$monitor['Id'] );
+			}
 			break;
 		}
 		default :
 		{
+			if ( ZM_OPT_CONTROL )
+			{
+				daemonControl( "stop", "zmtrack.pl", "-m ".$monitor['Id'] );
+			}
 			daemonControl( "stop", "zma", "-m ".$monitor['Id'] );
 			if ( ZM_OPT_FRAME_SERVER )
 			{
@@ -575,11 +690,22 @@ function reScale( $dimension, $scale=SCALE_SCALE )
 	return( (int)(($dimension*$scale)/SCALE_SCALE) );
 }
 
+function deScale( $dimension, $scale=SCALE_SCALE )
+{
+	if ( $scale == SCALE_SCALE )
+		return( $dimension );
+
+	return( (int)(($dimension*SCALE_SCALE)/$scale) );
+}
+
 function parseSort( $save_to_session=false )
 {
-	global $_SESSION;
 	global $sort_field, $sort_asc; // Inputs
 	global $sort_query, $sort_column, $sort_order; // Outputs
+	if ( version_compare( phpversion(), "4.1.0", "<") )
+	{
+		global $_SESSION;
+	}
 
 	if ( !isset($sort_field) )
 	{
@@ -638,9 +764,12 @@ function parseSort( $save_to_session=false )
 
 function parseFilter( $save_to_session=false )
 {
-	global $_SESSION;
 	global $trms; // Inputs
 	global $filter_query, $filter_sql, $filter_fields; // Outputs
+	if ( version_compare( phpversion(), "4.1.0", "<") )
+	{
+		global $_SESSION;
+	}
 
 	$filter_query = ''; 
 	$filter_sql = '';
