@@ -1,7 +1,7 @@
 <?php
 //
-// ZoneMinder web German language file, $Date: 2004/12/29 18:50:34 $, $Revision: 1.13 $
-// Copyright (C) 2003  Philip Coombes
+// ZoneMinder web German language file, $Date: 2005/03/16 17:38:37 $, $Revision: 1.15 $
+// Copyright (C) 2003, 2004, 2005  Philip Coombes
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -73,6 +73,7 @@
 $zmSlang24BitColour          = '24 bit Farbe';
 $zmSlang8BitGrey             = '8 bit Graustufe';
 $zmSlangActual               = 'Aktuell';
+$zmSlangAddNewControl        = 'Add New Control';
 $zmSlangAddNewMonitor        = 'Neuer Monitor';
 $zmSlangAddNewUser           = 'Neuer User';
 $zmSlangAddNewZone           = 'Neue Zone';
@@ -108,21 +109,60 @@ $zmSlangAttrTime             = 'Zeit';
 $zmSlangAttrTotalScore       = 'Total Zhler';
 $zmSlangAttrWeekday          = 'Wochentag';
 $zmSlangAutoArchiveEvents    = 'Automatically archive all matches';
+$zmSlangAuto                 = 'Auto';
 $zmSlangAutoDeleteEvents     = 'Automatically delete all matches';
 $zmSlangAutoEmailEvents      = 'Automatically email details of all matches';
 $zmSlangAutoExecuteEvents    = 'Automatically execute command on all matches';
 $zmSlangAutoMessageEvents    = 'Automatically message details of all matches';
 $zmSlangAutoUploadEvents     = 'Automatically upload all matches';
 $zmSlangAvgBrScore           = 'Avg.<br/>Zhler';
-$zmSlangBadMonitorChars      = 'Monitor Namen drfen nur aus buchstaben,zahlen und trenn oder unterstrich bestehen ';
+$zmSlangBadNameChars         = 'Namen drfen nur aus buchstaben,zahlen und trenn oder unterstrich bestehen ';
 $zmSlangBandwidth            = 'Bandbreite';
 $zmSlangBlobPx               = 'Gebiets Pixel';
 $zmSlangBlobs                = 'Gebiet ';
 $zmSlangBlobSizes            = 'Gebiets Gre';
 $zmSlangBrightness           = 'Helligkeit';
 $zmSlangBuffers              = 'Puffer';
+$zmSlangCanAutoFocus         = 'Can Auto Focus';
+$zmSlangCanAutoGain          = 'Can Auto Gain';
+$zmSlangCanAutoIris          = 'Can Auto Iris';
+$zmSlangCanAutoWhite         = 'Can Auto White Bal.';
+$zmSlangCanAutoZoom          = 'Can Auto Zoom';
 $zmSlangCancel               = 'Abbruch';
 $zmSlangCancelForcedAlarm    = 'Abbruch&nbsp;Unbedingter&nbsp;Alarm';
+$zmSlangCanFocusAbs          = 'Can Focus Absolute';
+$zmSlangCanFocus             = 'Can Focus';
+$zmSlangCanFocusCon          = 'Can Focus Continuous';
+$zmSlangCanFocusRel          = 'Can Focus Relative';
+$zmSlangCanGainAbs           = 'Can Gain Absolute';
+$zmSlangCanGain              = 'Can Gain ';
+$zmSlangCanGainCon           = 'Can Gain Continuous';
+$zmSlangCanGainRel           = 'Can Gain Relative';
+$zmSlangCanIrisAbs           = 'Can Iris Absolute';
+$zmSlangCanIris              = 'Can Iris';
+$zmSlangCanIrisCon           = 'Can Iris Continuous';
+$zmSlangCanIrisRel           = 'Can Iris Relative';
+$zmSlangCanMoveAbs           = 'Can Move Absolute';
+$zmSlangCanMove              = 'Can Move';
+$zmSlangCanMoveCon           = 'Can Move Continuous';
+$zmSlangCanMoveDiag          = 'Can Move Diagonally';
+$zmSlangCanMoveMap           = 'Can Move Mapped';
+$zmSlangCanMoveRel           = 'Can Move Relative';
+$zmSlangCanPan               = 'Can Pan' ;
+$zmSlangCanReset             = 'Can Reset';
+$zmSlangCanSetPresets        = 'Can Set Presets';
+$zmSlangCanSleep             = 'Can Sleep';
+$zmSlangCanTilt              = 'Can Tilt';
+$zmSlangCanWake              = 'Can Wake';
+$zmSlangCanWhiteAbs          = 'Can White Bal. Absolute';
+$zmSlangCanWhiteBal          = 'Can White Bal.';
+$zmSlangCanWhite             = 'Can White Balance';
+$zmSlangCanWhiteCon          = 'Can White Bal. Continuous';
+$zmSlangCanWhiteRel          = 'Can White Bal. Relative';
+$zmSlangCanZoomAbs           = 'Can Zoom Absolute';
+$zmSlangCanZoom              = 'Can Zoom';
+$zmSlangCanZoomCon           = 'Can Zoom Continuous';
+$zmSlangCanZoomRel           = 'Can Zoom Relative';
 $zmSlangCaptureHeight        = 'Capture Hhe';
 $zmSlangCapturePalette       = 'Capture FarbPalette';
 $zmSlangCaptureWidth         = 'Capture Breite';
@@ -132,6 +172,7 @@ $zmSlangCheckMethod          = 'Alarm Check Methode';
 $zmSlangChooseFilter         = 'Filterauswahl';
 $zmSlangClose                = 'Schlieen';
 $zmSlangColour               = 'Farbe';
+$zmSlangCommand              = 'Command';
 $zmSlangConfig               = 'Config';
 $zmSlangConfiguredFor        = 'Eingerichtet fr';
 $zmSlangConfirmPassword      = 'Passwortbesttigung';
@@ -141,6 +182,13 @@ $zmSlangConsole              = 'Konsole';
 $zmSlangContactAdmin         = 'Bitte den Administrator fr Details ansprechen.';
 $zmSlangContinue             = 'Continue';
 $zmSlangContrast             = 'Kontrast';
+$zmSlangControlAddress       = 'Control Address';
+$zmSlangControlCap           = 'Control Capability';
+$zmSlangControlCaps          = 'Control Capabilities';
+$zmSlangControl              = 'Control';
+$zmSlangControlDevice        = 'Control Device';
+$zmSlangControllable         = 'Controllable';
+$zmSlangControlType          = 'Control Type';
 $zmSlangCycle                = 'Cycle';
 $zmSlangCycleWatch           = 'Zeitzyklus';
 $zmSlangDay                  = 'Tag';
@@ -170,9 +218,11 @@ $zmSlangEventName            = 'Event Name';
 $zmSlangEventPrefix          = 'Event Prefix';
 $zmSlangEvents               = 'Ereignisse';
 $zmSlangExclude              = 'Ausschlu';
+$zmSlangFar                  = 'Far';
 $zmSlangFeed                 = 'Feed';
 $zmSlangFilterPx             = 'Filter Px';
 $zmSlangFirst                = 'Erstes';
+$zmSlangFocus                = 'Focus';
 $zmSlangForceAlarm           = 'Unbedingter&nbsp;Alarm';
 $zmSlangFPS                  = 'fps';
 $zmSlangFPSReportInterval    = 'FPS Report Interval';
@@ -184,13 +234,26 @@ $zmSlangFrameSkip            = 'Bilder auslassen';
 $zmSlangFTP                  = 'FTP';
 $zmSlangFunc                 = 'Funktion';
 $zmSlangFunction             = 'Funktion';
+$zmSlangGain                 = 'Gain';
 $zmSlangGenerateVideo        = 'Erzeuge Video';
 $zmSlangGeneratingVideo      = 'Erzeuge Video';
 $zmSlangGoToZoneMinder       = 'Gehe zu ZoneMinder.com';
 $zmSlangGrey                 = 'Grau';
 $zmSlangGroups               = 'Groups';
+$zmSlangHasFocusSpeed        = 'Has Focus Speed';
+$zmSlangHasGainSpeed         = 'Has Gain Speed';
+$zmSlangHasHomePreset        = 'Has Home Preset';
+$zmSlangHasIrisSpeed         = 'Has Iris Speed';
+$zmSlangHasPanSpeed          = 'Has Pan Speed';
+$zmSlangHasPresets           = 'Has Presets';
+$zmSlangHasTiltSpeed         = 'Has Tilt Speed';
+$zmSlangHasTurboPan          = 'Has Turbo Pan';
+$zmSlangHasTurboTilt         = 'Has Turbo Tilt';
+$zmSlangHasWhiteSpeed        = 'Has White Bal. Speed';
+$zmSlangHasZoomSpeed         = 'Has Zoom Speed';
 $zmSlangHighBW               = 'Hohe&nbsp;B/W';
 $zmSlangHigh                 = 'Hohe';
+$zmSlangHome                 = 'Home';
 $zmSlangHour                 = 'Stunde';
 $zmSlangHue                  = 'Farbabstufung';
 $zmSlangId                   = 'Id';
@@ -199,7 +262,9 @@ $zmSlangIgnore               = 'Ignoriere';
 $zmSlangImage                = 'Bild';
 $zmSlangImageBufferSize      = 'Bildpuffergre (bilder)';
 $zmSlangInclude              = 'Einschlu';
+$zmSlangIn                   = 'In';
 $zmSlangInverted             = 'Invertiert';
+$zmSlangIris                 = 'Iris';
 $zmSlangLanguage             = 'Sprache';
 $zmSlangLast                 = 'Letztes';
 $zmSlangLimitResultsPost     = 'results only;'; // This is used at the end of the phrase 'Limit to first N results only'
@@ -212,10 +277,34 @@ $zmSlangLogin                = 'Anmeldung';
 $zmSlangLogout               = 'Abmelden';
 $zmSlangLowBW                = 'Niedrige&nbsp;B/W';
 $zmSlangLow                  = 'Niedrige';
+$zmSlangMain                 = 'Main';
+$zmSlangMan                  = 'Man';
+$zmSlangManual               = 'Manual';
 $zmSlangMark                 = 'Markiert';
 $zmSlangMaxBrScore           = 'Max.<br/>Zhler';
+$zmSlangMaxFocusRange        = 'Max Focus Range';
+$zmSlangMaxFocusSpeed        = 'Max Focus Speed';
+$zmSlangMaxFocusStep         = 'Max Focus Step';
+$zmSlangMaxGainRange         = 'Max Gain Range';
+$zmSlangMaxGainSpeed         = 'Max Gain Speed';
+$zmSlangMaxGainStep          = 'Max Gain Step';
 $zmSlangMaximumFPS           = 'Maximal FPS';
+$zmSlangMaxIrisRange         = 'Max Iris Range';
+$zmSlangMaxIrisSpeed         = 'Max Iris Speed';
+$zmSlangMaxIrisStep          = 'Max Iris Step';
 $zmSlangMax                  = 'Max';
+$zmSlangMaxPanRange          = 'Max Pan Range';
+$zmSlangMaxPanSpeed          = 'Max Pan Speed';
+$zmSlangMaxPanStep           = 'Max Pan Step';
+$zmSlangMaxTiltRange         = 'Max Tilt Range';
+$zmSlangMaxTiltSpeed         = 'Max Tilt Speed';
+$zmSlangMaxTiltStep          = 'Max Tilt Step';
+$zmSlangMaxWhiteRange        = 'Max White Bal. Range';
+$zmSlangMaxWhiteSpeed        = 'Max White Bal. Speed';
+$zmSlangMaxWhiteStep         = 'Max White Bal. Step';
+$zmSlangMaxZoomRange         = 'Max Zoom Range';
+$zmSlangMaxZoomSpeed         = 'Max Zoom Speed';
+$zmSlangMaxZoomStep          = 'Max Zoom Step';
 $zmSlangMediumBW             = 'Mittlere&nbsp;B/W';
 $zmSlangMedium               = 'Mittlere';
 $zmSlangMinAlarmGeMinBlob    = 'Minimale alarmpixelzahl muss grer oder gleich der minimum Arealpixel sein';
@@ -224,19 +313,42 @@ $zmSlangMinAlarmPixelsLtMax  = 'Minimale Alarmpixelanzahl muss kleiner als maxim
 $zmSlangMinBlobAreaLtMax     = 'Minimale Gebietsflche muss kleiner sein als maximale Gebietsflche';
 $zmSlangMinBlobsLtMax        = 'Minimal Blobs muss kleiner als maximal Blobs sein';
 $zmSlangMinFilterPixelsLtMax = 'Minimale Filterpixelanzahl muss kleiner als maximale Filterpixelanzahl sein';
+$zmSlangMinFocusRange        = 'Min Focus Range';
+$zmSlangMinFocusSpeed        = 'Min Focus Speed';
+$zmSlangMinFocusStep         = 'Min Focus Step';
+$zmSlangMinGainRange         = 'Min Gain Range';
+$zmSlangMinGainSpeed         = 'Min Gain Speed';
+$zmSlangMinGainStep          = 'Min Gain Step';
+$zmSlangMinIrisRange         = 'Min Iris Range';
+$zmSlangMinIrisSpeed         = 'Min Iris Speed';
+$zmSlangMinIrisStep          = 'Min Iris Step';
+$zmSlangMinPanRange          = 'Min Pan Range';
+$zmSlangMinPanSpeed          = 'Min Pan Speed';
+$zmSlangMinPanStep           = 'Min Pan Step';
 $zmSlangMinPixelThresLtMax   = 'Minimaler pixelschwellwert muss kleiner als maximaler pixelschwellwert sein';
+$zmSlangMinTiltRange         = 'Min Tilt Range';
+$zmSlangMinTiltSpeed         = 'Min Tilt Speed';
+$zmSlangMinTiltStep          = 'Min Tilt Step';
+$zmSlangMinWhiteRange        = 'Min White Bal. Range';
+$zmSlangMinWhiteSpeed        = 'Min White Bal. Speed';
+$zmSlangMinWhiteStep         = 'Min White Bal. Step';
+$zmSlangMinZoomRange         = 'Min Zoom Range';
+$zmSlangMinZoomSpeed         = 'Min Zoom Speed';
+$zmSlangMinZoomStep          = 'Min Zoom Step';
 $zmSlangMisc                 = 'Misc';
 $zmSlangMonitorIds           = 'Monitor&nbsp;Id';
 $zmSlangMonitor              = 'Monitor';
 $zmSlangMonitors             = 'Monitors';
 $zmSlangMontage              = 'Montage';
 $zmSlangMonth                = 'Monat';
+$zmSlangMove                 = 'Move';
 $zmSlangMustBeGe             = 'muss grer oder gleich sein wie';
 $zmSlangMustBeLe             = 'muss kleiner oder gleich sein wie';
 $zmSlangMustConfirmPassword  = 'Sie mssen das Passwort besttigen';
 $zmSlangMustSupplyPassword   = 'Sie mssen ein Passwort vergeben';
 $zmSlangMustSupplyUsername   = 'Sie mssen einen Usernamen vergeben';
 $zmSlangName                 = 'Name';
+$zmSlangNear                 = 'Near';
 $zmSlangNetwork              = 'Netzwerk';
 $zmSlangNewGroup             = 'New Group';
 $zmSlangNew                  = 'Neu';
@@ -252,6 +364,8 @@ $zmSlangNone                 = 'Nichts';
 $zmSlangNormal               = 'Normal';
 $zmSlangNoSavedFilters       = 'Keine gespeicherten Filter';
 $zmSlangNoStatisticsRecorded = 'Keine Statistik fr dieses Ereigniss/Bilder';
+$zmSlangNumPresets           = 'Num Presets';
+$zmSlangOpen                 = 'Open';
 $zmSlangOpEq                 = 'gleich zu';
 $zmSlangOpGtEq               = 'grer oder gleich wie';
 $zmSlangOpGt                 = 'grer als';
@@ -267,8 +381,11 @@ $zmSlangOptionRestartWarning = 'Vernderungen werden erst bei Neustart des Progra
 $zmSlangOptions              = 'Optionen';
 $zmSlangOrEnterNewName       = 'oder neuen Name eingeben';
 $zmSlangOrientation          = 'Ausrichtung';
+$zmSlangOut                  = 'Out';
 $zmSlangOverwriteExisting    = 'berschreibe bestehende';
 $zmSlangPaged                = 'Paged';
+$zmSlangPan                  = 'Pan';
+$zmSlangPanTilt              = 'Pan/Tilt';
 $zmSlangParameter            = 'Parameter';
 $zmSlangPassword             = 'Passwort';
 $zmSlangPasswordsDifferent   = 'Die Passwrter sind unterschiedlich';
@@ -280,6 +397,8 @@ $zmSlangPlayAll              = 'Play All';
 $zmSlangPleaseWait           = 'Bitte Warten';
 $zmSlangPostEventImageBuffer = 'Post Ereigniss Bildpuffer';
 $zmSlangPreEventImageBuffer  = 'Voriges Ereigniss Bildpuffer';
+$zmSlangPreset               = 'Preset';
+$zmSlangPresets              = 'Presets';
 $zmSlangPrev                 = 'Voriges';
 $zmSlangRate                 = 'Rate';
 $zmSlangReal                 = 'Real';
@@ -298,6 +417,8 @@ $zmSlangReset                = 'Reset';
 $zmSlangRestarting           = 'Neustarten';
 $zmSlangRestart              = 'Neustart';
 $zmSlangRestrictedCameraIds  = 'Verbotene Kamera Id';
+$zmSlangReturnDelay          = 'Return Delay';
+$zmSlangReturnLocation       = 'Return Location';
 $zmSlangRotateLeft           = 'Drehung Links';
 $zmSlangRotateRight          = 'Drehung Rechts';
 $zmSlangRunMode              = 'Betriebsmodus';
@@ -313,24 +434,39 @@ $zmSlangSectionlength        = 'Sektions Lnge';
 $zmSlangSelect               = 'Select';
 $zmSlangSetLearnPrefs        = 'Setze Lernmerkmale'; // This can be ignored for now
 $zmSlangSetNewBandwidth      = 'Setze Neue Bandbreite';
+$zmSlangSetPreset            = 'Set Preset';
+$zmSlangSet                  = 'Set';
 $zmSlangSettings             = 'Einstellungen';
 $zmSlangShowFilterWindow     = 'ZeigeFilterFenster';
+$zmSlangSleep                = 'Sleep';
 $zmSlangSortAsc              = 'Asc';
 $zmSlangSortBy               = 'Sort by';
 $zmSlangSortDesc             = 'Desc';
 $zmSlangSource               = 'Quelle';
 $zmSlangSourceType           = 'Quellen Typ';
+$zmSlangSpeedHigh            = 'High Speed';
+$zmSlangSpeedLow             = 'Low Speed';
+$zmSlangSpeedMedium          = 'Medium Speed';
+$zmSlangSpeed                = 'Speed';
+$zmSlangSpeedTurbo           = 'Turbo Speed';
 $zmSlangStart                = 'Start';
 $zmSlangState                = 'Status';
 $zmSlangStats                = 'Status';
 $zmSlangStatus               = 'Status';
+$zmSlangStepLarge            = 'Large Step';
+$zmSlangStepMedium           = 'Medium Step';
+$zmSlangStepNone             = 'No Step';
+$zmSlangStepSmall            = 'Small Step';
+$zmSlangStep                 = 'Step';
 $zmSlangStills               = 'Standbilder';
 $zmSlangStopped              = 'Gestoppt';
 $zmSlangStop                 = 'Stop';
 $zmSlangStream               = 'Stream';
 $zmSlangSubmit               = 'Submit';
 $zmSlangSystem               = 'System';
+$zmSlangTele                 = 'Tele';
 $zmSlangThumbnail            = 'Thumbnail';
+$zmSlangTilt                 = 'Tilt';
 $zmSlangTimeDelta            = 'Zeitdifferenz';
 $zmSlangTimestampLabelFormat = 'Zeitstempel Marke Format';
 $zmSlangTimestampLabelX      = 'Zeitstempel Marke X';
@@ -341,7 +477,11 @@ $zmSlangTime                 = 'Zeit';
 $zmSlangToday                = 'Today';
 $zmSlangTools                = 'Tools';
 $zmSlangTotalBrScore         = 'Total<br/>Zhler';
+$zmSlangTrackDelay           = 'Track Delay';
+$zmSlangTrackMotion          = 'Track Motion';
 $zmSlangTriggers             = 'Auslser';
+$zmSlangTurboPanSpeed        = 'Turbo Pan Speed';
+$zmSlangTurboTiltSpeed       = 'Turbo Tilt Speed';
 $zmSlangType                 = 'Typ';
 $zmSlangUnarchive            = 'Nichtarchiviert';
 $zmSlangUnits                = 'Einheiten';
@@ -368,10 +508,14 @@ $zmSlangVideo                = 'Video';
 $zmSlangViewAll              = 'Alles Anschauen';
 $zmSlangView                 = 'Anschauen';
 $zmSlangViewPaged            = 'Seitenansicht';
+$zmSlangWake                 = 'Wake';
 $zmSlangWarmupFrames         = 'Aufwrm Bilder';
 $zmSlangWatch                = 'Beobachte';
 $zmSlangWeb                  = 'Web';
 $zmSlangWeek                 = 'Woche';
+$zmSlangWhiteBalance         = 'White Balance';
+$zmSlangWhite                = 'White';
+$zmSlangWide                 = 'Wide';
 $zmSlangX10ActivationString  = 'X10 Aktivierungs Wert';
 $zmSlangX10InputAlarmString  = 'X10 Eingabe Alarm Wert';
 $zmSlangX10OutputAlarmString = 'X10 Ausgabe Alarm Wert';
@@ -379,25 +523,26 @@ $zmSlangX10                  = 'X10';
 $zmSlangYes                  = 'Ja';
 $zmSlangYouNoPerms           = 'Keine Erlaubniss zum Zugang dieser Resource.';
 $zmSlangZoneAlarmColour      = 'Alarm Farbe (RGB)';
-$zmSlangZoneAlarmThreshold   = 'Alarm Schwellwert (0>=?<=255)';
+$zmSlangZoneAlarmThreshold   = 'Alarm Schwellwert (0-255)';
 $zmSlangZoneFilterHeight     = 'Filter Hhe (pixels)';
 $zmSlangZoneFilterWidth      = 'Filter Breite (pixels)';
 $zmSlangZoneMaxAlarmedArea   = 'Maximal berwachte Flche';
 $zmSlangZoneMaxBlobArea      = 'Maximale Gebietsflche';
 $zmSlangZoneMaxBlobs         = 'Maximale Gebietsanzahl';
 $zmSlangZoneMaxFilteredArea  = 'Maximal gefilterte Flche';
-$zmSlangZoneMaxPixelThres    = 'Maximaler Pixelschwellwert(0>=?<=255)';
+$zmSlangZoneMaxPixelThres    = 'Maximaler Pixelschwellwert(0-255)';
 $zmSlangZoneMaxX             = 'Maximum X (rechts)';
 $zmSlangZoneMaxY             = 'Maximum Y (unten)';
 $zmSlangZoneMinAlarmedArea   = 'Minimal berwachte Flche';
 $zmSlangZoneMinBlobArea      = 'Minimale Gebietsflche';
 $zmSlangZoneMinBlobs         = 'Minimale Gebietsanzahl';
 $zmSlangZoneMinFilteredArea  = 'Minimal gefilterte Flche';
-$zmSlangZoneMinPixelThres    = 'Minimaler Pixelschwellwert (0>=?<=255)';
+$zmSlangZoneMinPixelThres    = 'Minimaler Pixelschwellwert (0-255)';
 $zmSlangZoneMinX             = 'Minimum X (links)';
 $zmSlangZoneMinY             = 'Minimum Y (oben)';
 $zmSlangZones                = 'Zonen';
 $zmSlangZone                 = 'Zone';
+$zmSlangZoom                 = 'Zoom';
 
 // Complex replacements with formatting and/or placements, must be passed through sprintf
 $zmClangCurrentLogin         = 'Momentan angemeldet ist \'%1$s\'';
