@@ -1,7 +1,7 @@
 <?php
 //
-// ZoneMinder web UK English language file, $Date: 2004/12/28 18:20:11 $, $Revision: 1.30 $
-// Copyright (C) 2003  Philip Coombes
+// ZoneMinder web UK English language file, $Date: 2005/03/16 17:38:25 $, $Revision: 1.34 $
+// Copyright (C) 2003, 2004, 2005  Philip Coombes
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -73,6 +73,7 @@
 $zmSlang24BitColour          = '24 bit colour';
 $zmSlang8BitGrey             = '8 bit greyscale';
 $zmSlangActual               = 'Actual';
+$zmSlangAddNewControl        = 'Add New Control';
 $zmSlangAddNewMonitor        = 'Add New Monitor';
 $zmSlangAddNewUser           = 'Add New User';
 $zmSlangAddNewZone           = 'Add New Zone';
@@ -108,21 +109,60 @@ $zmSlangAttrTime             = 'Time';
 $zmSlangAttrTotalScore       = 'Total Score';
 $zmSlangAttrWeekday          = 'Weekday';
 $zmSlangAutoArchiveEvents    = 'Automatically archive all matches';
+$zmSlangAuto                 = 'Auto';
 $zmSlangAutoDeleteEvents     = 'Automatically delete all matches';
 $zmSlangAutoEmailEvents      = 'Automatically email details of all matches';
 $zmSlangAutoExecuteEvents    = 'Automatically execute command on all matches';
 $zmSlangAutoMessageEvents    = 'Automatically message details of all matches';
 $zmSlangAutoUploadEvents     = 'Automatically upload all matches';
 $zmSlangAvgBrScore           = 'Avg.<br/>Score';
-$zmSlangBadMonitorChars      = 'Monitor Names may only contain alphanumeric characters plus hyphen and underscore';
+$zmSlangBadNameChars         = 'Names may only contain alphanumeric characters plus hyphen and underscore';
 $zmSlangBandwidth            = 'Bandwidth';
 $zmSlangBlobPx               = 'Blob Px';
 $zmSlangBlobs                = 'Blobs';
 $zmSlangBlobSizes            = 'Blob Sizes';
 $zmSlangBrightness           = 'Brightness';
 $zmSlangBuffers              = 'Buffers';
+$zmSlangCanAutoFocus         = 'Can Auto Focus';
+$zmSlangCanAutoGain          = 'Can Auto Gain';
+$zmSlangCanAutoIris          = 'Can Auto Iris';
+$zmSlangCanAutoWhite         = 'Can Auto White Bal.';
+$zmSlangCanAutoZoom          = 'Can Auto Zoom';
 $zmSlangCancel               = 'Cancel';
 $zmSlangCancelForcedAlarm    = 'Cancel&nbsp;Forced&nbsp;Alarm';
+$zmSlangCanFocusAbs          = 'Can Focus Absolute';
+$zmSlangCanFocus             = 'Can Focus';
+$zmSlangCanFocusCon          = 'Can Focus Continuous';
+$zmSlangCanFocusRel          = 'Can Focus Relative';
+$zmSlangCanGainAbs           = 'Can Gain Absolute';
+$zmSlangCanGain              = 'Can Gain ';
+$zmSlangCanGainCon           = 'Can Gain Continuous';
+$zmSlangCanGainRel           = 'Can Gain Relative';
+$zmSlangCanIrisAbs           = 'Can Iris Absolute';
+$zmSlangCanIris              = 'Can Iris';
+$zmSlangCanIrisCon           = 'Can Iris Continuous';
+$zmSlangCanIrisRel           = 'Can Iris Relative';
+$zmSlangCanMoveAbs           = 'Can Move Absolute';
+$zmSlangCanMove              = 'Can Move';
+$zmSlangCanMoveCon           = 'Can Move Continuous';
+$zmSlangCanMoveDiag          = 'Can Move Diagonally';
+$zmSlangCanMoveMap           = 'Can Move Mapped';
+$zmSlangCanMoveRel           = 'Can Move Relative';
+$zmSlangCanPan               = 'Can Pan' ;
+$zmSlangCanReset             = 'Can Reset';
+$zmSlangCanSetPresets        = 'Can Set Presets';
+$zmSlangCanSleep             = 'Can Sleep';
+$zmSlangCanTilt              = 'Can Tilt';
+$zmSlangCanWake              = 'Can Wake';
+$zmSlangCanWhiteAbs          = 'Can White Bal. Absolute';
+$zmSlangCanWhiteBal          = 'Can White Bal.';
+$zmSlangCanWhite             = 'Can White Balance';
+$zmSlangCanWhiteCon          = 'Can White Bal. Continuous';
+$zmSlangCanWhiteRel          = 'Can White Bal. Relative';
+$zmSlangCanZoomAbs           = 'Can Zoom Absolute';
+$zmSlangCanZoom              = 'Can Zoom';
+$zmSlangCanZoomCon           = 'Can Zoom Continuous';
+$zmSlangCanZoomRel           = 'Can Zoom Relative';
 $zmSlangCaptureHeight        = 'Capture Height';
 $zmSlangCapturePalette       = 'Capture Palette';
 $zmSlangCaptureWidth         = 'Capture Width';
@@ -132,6 +172,7 @@ $zmSlangCheckMethod          = 'Alarm Check Method';
 $zmSlangChooseFilter         = 'Choose Filter';
 $zmSlangClose                = 'Close';
 $zmSlangColour               = 'Colour';
+$zmSlangCommand              = 'Command';
 $zmSlangConfig               = 'Config';
 $zmSlangConfiguredFor        = 'Configured for';
 $zmSlangConfirmPassword      = 'Confirm Password';
@@ -141,6 +182,13 @@ $zmSlangConsole              = 'Console';
 $zmSlangContactAdmin         = 'Please contact your adminstrator for details.';
 $zmSlangContinue             = 'Continue';
 $zmSlangContrast             = 'Contrast';
+$zmSlangControlAddress       = 'Control Address';
+$zmSlangControlCap           = 'Control Capability';
+$zmSlangControlCaps          = 'Control Capabilities';
+$zmSlangControl              = 'Control';
+$zmSlangControlDevice        = 'Control Device';
+$zmSlangControllable         = 'Controllable';
+$zmSlangControlType          = 'Control Type';
 $zmSlangCycle                = 'Cycle';
 $zmSlangCycleWatch           = 'Cycle Watch';
 $zmSlangDay                  = 'Day';
@@ -170,9 +218,11 @@ $zmSlangEventName            = 'Event Name';
 $zmSlangEventPrefix          = 'Event Prefix';
 $zmSlangEvents               = 'Events';
 $zmSlangExclude              = 'Exclude';
+$zmSlangFar                  = 'Far';
 $zmSlangFeed                 = 'Feed';
 $zmSlangFilterPx             = 'Filter Px';
 $zmSlangFirst                = 'First';
+$zmSlangFocus                = 'Focus';
 $zmSlangForceAlarm           = 'Force&nbsp;Alarm';
 $zmSlangFPS                  = 'fps';
 $zmSlangFPSReportInterval    = 'FPS Report Interval';
@@ -184,13 +234,26 @@ $zmSlangFrameSkip            = 'Frame Skip';
 $zmSlangFTP                  = 'FTP';
 $zmSlangFunc                 = 'Func';
 $zmSlangFunction             = 'Function';
+$zmSlangGain                 = 'Gain';
 $zmSlangGenerateVideo        = 'Generate Video';
 $zmSlangGeneratingVideo      = 'Generating Video';
 $zmSlangGoToZoneMinder       = 'Go to ZoneMinder.com';
 $zmSlangGrey                 = 'Grey';
 $zmSlangGroups               = 'Groups';
+$zmSlangHasFocusSpeed        = 'Has Focus Speed';
+$zmSlangHasGainSpeed         = 'Has Gain Speed';
+$zmSlangHasHomePreset        = 'Has Home Preset';
+$zmSlangHasIrisSpeed         = 'Has Iris Speed';
+$zmSlangHasPanSpeed          = 'Has Pan Speed';
+$zmSlangHasPresets           = 'Has Presets';
+$zmSlangHasTiltSpeed         = 'Has Tilt Speed';
+$zmSlangHasTurboPan          = 'Has Turbo Pan';
+$zmSlangHasTurboTilt         = 'Has Turbo Tilt';
+$zmSlangHasWhiteSpeed        = 'Has White Bal. Speed';
+$zmSlangHasZoomSpeed         = 'Has Zoom Speed';
 $zmSlangHighBW               = 'High&nbsp;B/W';
 $zmSlangHigh                 = 'High';
+$zmSlangHome                 = 'Home';
 $zmSlangHour                 = 'Hour';
 $zmSlangHue                  = 'Hue';
 $zmSlangId                   = 'Id';
@@ -199,7 +262,9 @@ $zmSlangIgnore               = 'Ignore';
 $zmSlangImageBufferSize      = 'Image Buffer Size (frames)';
 $zmSlangImage                = 'Image';
 $zmSlangInclude              = 'Include';
+$zmSlangIn                   = 'In';
 $zmSlangInverted             = 'Inverted';
+$zmSlangIris                 = 'Iris';
 $zmSlangLanguage             = 'Language';
 $zmSlangLast                 = 'Last';
 $zmSlangLimitResultsPost     = 'results only;'; // This is used at the end of the phrase 'Limit to first N results only'
@@ -212,10 +277,34 @@ $zmSlangLogin                = 'Login';
 $zmSlangLogout               = 'Logout';
 $zmSlangLowBW                = 'Low&nbsp;B/W';
 $zmSlangLow                  = 'Low';
+$zmSlangMain                 = 'Main';
+$zmSlangMan                  = 'Man';
+$zmSlangManual               = 'Manual';
 $zmSlangMark                 = 'Mark';
 $zmSlangMaxBrScore           = 'Max.<br/>Score';
+$zmSlangMaxFocusRange        = 'Max Focus Range';
+$zmSlangMaxFocusSpeed        = 'Max Focus Speed';
+$zmSlangMaxFocusStep         = 'Max Focus Step';
+$zmSlangMaxGainRange         = 'Max Gain Range';
+$zmSlangMaxGainSpeed         = 'Max Gain Speed';
+$zmSlangMaxGainStep          = 'Max Gain Step';
 $zmSlangMaximumFPS           = 'Maximum FPS';
+$zmSlangMaxIrisRange         = 'Max Iris Range';
+$zmSlangMaxIrisSpeed         = 'Max Iris Speed';
+$zmSlangMaxIrisStep          = 'Max Iris Step';
 $zmSlangMax                  = 'Max';
+$zmSlangMaxPanRange          = 'Max Pan Range';
+$zmSlangMaxPanSpeed          = 'Max Pan Speed';
+$zmSlangMaxPanStep           = 'Max Pan Step';
+$zmSlangMaxTiltRange         = 'Max Tilt Range';
+$zmSlangMaxTiltSpeed         = 'Max Tilt Speed';
+$zmSlangMaxTiltStep          = 'Max Tilt Step';
+$zmSlangMaxWhiteRange        = 'Max White Bal. Range';
+$zmSlangMaxWhiteSpeed        = 'Max White Bal. Speed';
+$zmSlangMaxWhiteStep         = 'Max White Bal. Step';
+$zmSlangMaxZoomRange         = 'Max Zoom Range';
+$zmSlangMaxZoomSpeed         = 'Max Zoom Speed';
+$zmSlangMaxZoomStep          = 'Max Zoom Step';
 $zmSlangMediumBW             = 'Medium&nbsp;B/W';
 $zmSlangMedium               = 'Medium';
 $zmSlangMinAlarmGeMinBlob    = 'Minimum alarm pixels should be greater than or equal to minimum blob pixels';
@@ -224,34 +313,59 @@ $zmSlangMinAlarmPixelsLtMax  = 'Minimum alarm pixels should be less than maximum
 $zmSlangMinBlobAreaLtMax     = 'Minimum blob area should be less than maximum blob area';
 $zmSlangMinBlobsLtMax        = 'Minimum blobs should be less than maximum blobs';
 $zmSlangMinFilterPixelsLtMax = 'Minimum filter pixels should be less than maximum filter pixels';
+$zmSlangMinFocusRange        = 'Min Focus Range';
+$zmSlangMinFocusSpeed        = 'Min Focus Speed';
+$zmSlangMinFocusStep         = 'Min Focus Step';
+$zmSlangMinGainRange         = 'Min Gain Range';
+$zmSlangMinGainSpeed         = 'Min Gain Speed';
+$zmSlangMinGainStep          = 'Min Gain Step';
+$zmSlangMinIrisRange         = 'Min Iris Range';
+$zmSlangMinIrisSpeed         = 'Min Iris Speed';
+$zmSlangMinIrisStep          = 'Min Iris Step';
+$zmSlangMinPanRange          = 'Min Pan Range';
+$zmSlangMinPanSpeed          = 'Min Pan Speed';
+$zmSlangMinPanStep           = 'Min Pan Step';
 $zmSlangMinPixelThresLtMax   = 'Minimum pixel threshold should be less than maximum pixel threshold';
+$zmSlangMinTiltRange         = 'Min Tilt Range';
+$zmSlangMinTiltSpeed         = 'Min Tilt Speed';
+$zmSlangMinTiltStep          = 'Min Tilt Step';
+$zmSlangMinWhiteRange        = 'Min White Bal. Range';
+$zmSlangMinWhiteSpeed        = 'Min White Bal. Speed';
+$zmSlangMinWhiteStep         = 'Min White Bal. Step';
+$zmSlangMinZoomRange         = 'Min Zoom Range';
+$zmSlangMinZoomSpeed         = 'Min Zoom Speed';
+$zmSlangMinZoomStep          = 'Min Zoom Step';
 $zmSlangMisc                 = 'Misc';
 $zmSlangMonitorIds           = 'Monitor&nbsp;Ids';
 $zmSlangMonitor              = 'Monitor';
 $zmSlangMonitors             = 'Monitors';
 $zmSlangMontage              = 'Montage';
 $zmSlangMonth                = 'Month';
+$zmSlangMove                 = 'Move';
 $zmSlangMustBeGe             = 'must be greater than or equal to';
 $zmSlangMustBeLe             = 'must be less than or equal to';
 $zmSlangMustConfirmPassword  = 'You must confirm the password';
 $zmSlangMustSupplyPassword   = 'You must supply a password';
 $zmSlangMustSupplyUsername   = 'You must supply a username';
 $zmSlangName                 = 'Name';
+$zmSlangNear                 = 'Near';
 $zmSlangNetwork              = 'Network';
-$zmSlangNew                  = 'New';
 $zmSlangNewGroup             = 'New Group';
+$zmSlangNew                  = 'New';
 $zmSlangNewPassword          = 'New Password';
 $zmSlangNewState             = 'New State';
 $zmSlangNewUser              = 'New User';
 $zmSlangNext                 = 'Next';
 $zmSlangNoFramesRecorded     = 'There are no frames recorded for this event';
+$zmSlangNoGroups             = 'No groups have been defined';
 $zmSlangNoneAvailable        = 'None available';
 $zmSlangNone                 = 'None';
 $zmSlangNo                   = 'No';
-$zmSlangNoGroups             = 'No groups have been defined';
 $zmSlangNormal               = 'Normal';
 $zmSlangNoSavedFilters       = 'NoSavedFilters';
 $zmSlangNoStatisticsRecorded = 'There are no statistics recorded for this event/frame';
+$zmSlangNumPresets           = 'Num Presets';
+$zmSlangOpen                 = 'Open';
 $zmSlangOpEq                 = 'equal to';
 $zmSlangOpGtEq               = 'greater than or equal to';
 $zmSlangOpGt                 = 'greater than';
@@ -267,19 +381,24 @@ $zmSlangOptionRestartWarning = 'These changes may not come into effect fully\nwh
 $zmSlangOptions              = 'Options';
 $zmSlangOrEnterNewName       = 'or enter new name';
 $zmSlangOrientation          = 'Orientation';
+$zmSlangOut                  = 'Out';
 $zmSlangOverwriteExisting    = 'Overwrite Existing';
 $zmSlangPaged                = 'Paged';
+$zmSlangPan                  = 'Pan';
+$zmSlangPanTilt              = 'Pan/Tilt';
 $zmSlangParameter            = 'Parameter';
 $zmSlangPassword             = 'Password';
 $zmSlangPasswordsDifferent   = 'The new and confirm passwords are different';
 $zmSlangPaths                = 'Paths';
-$zmSlangPlayAll              = 'Play All';
-$zmSlangPhone                = 'Phone';
 $zmSlangPhoneBW              = 'Phone&nbsp;B/W';
+$zmSlangPhone                = 'Phone';
 $zmSlangPixels               = 'pixels';
+$zmSlangPlayAll              = 'Play All';
 $zmSlangPleaseWait           = 'Please Wait';
 $zmSlangPostEventImageBuffer = 'Post Event Image Buffer';
 $zmSlangPreEventImageBuffer  = 'Pre Event Image Buffer';
+$zmSlangPreset               = 'Preset';
+$zmSlangPresets              = 'Presets';
 $zmSlangPrev                 = 'Prev';
 $zmSlangRate                 = 'Rate';
 $zmSlangReal                 = 'Real';
@@ -293,11 +412,13 @@ $zmSlangRemoteImageColours   = 'Remote Image Colours';
 $zmSlangRemote               = 'Remote';
 $zmSlangRename               = 'Rename';
 $zmSlangReplay               = 'Replay';
-$zmSlangReset                = 'Reset';
 $zmSlangResetEventCounts     = 'Reset Event Counts';
+$zmSlangReset                = 'Reset';
 $zmSlangRestarting           = 'Restarting';
 $zmSlangRestart              = 'Restart';
 $zmSlangRestrictedCameraIds  = 'Restricted Camera Ids';
+$zmSlangReturnDelay          = 'Return Delay';
+$zmSlangReturnLocation       = 'Return Location';
 $zmSlangRotateLeft           = 'Rotate Left';
 $zmSlangRotateRight          = 'Rotate Right';
 $zmSlangRunMode              = 'Run Mode';
@@ -309,28 +430,43 @@ $zmSlangSave                 = 'Save';
 $zmSlangScale                = 'Scale';
 $zmSlangScore                = 'Score';
 $zmSlangSecs                 = 'Secs';
-$zmSlangSelect               = 'Select';
 $zmSlangSectionlength        = 'Section length';
+$zmSlangSelect               = 'Select';
 $zmSlangSetLearnPrefs        = 'Set Learn Prefs'; // This can be ignored for now
 $zmSlangSetNewBandwidth      = 'Set New Bandwidth';
+$zmSlangSetPreset            = 'Set Preset';
+$zmSlangSet                  = 'Set';
 $zmSlangSettings             = 'Settings';
 $zmSlangShowFilterWindow     = 'ShowFilterWindow';
+$zmSlangSleep                = 'Sleep';
 $zmSlangSortAsc              = 'Asc';
 $zmSlangSortBy               = 'Sort by';
 $zmSlangSortDesc             = 'Desc';
 $zmSlangSource               = 'Source';
 $zmSlangSourceType           = 'Source Type';
+$zmSlangSpeedHigh            = 'High Speed';
+$zmSlangSpeedLow             = 'Low Speed';
+$zmSlangSpeedMedium          = 'Medium Speed';
+$zmSlangSpeed                = 'Speed';
+$zmSlangSpeedTurbo           = 'Turbo Speed';
 $zmSlangStart                = 'Start';
 $zmSlangState                = 'State';
 $zmSlangStats                = 'Stats';
 $zmSlangStatus               = 'Status';
+$zmSlangStepLarge            = 'Large Step';
+$zmSlangStepMedium           = 'Medium Step';
+$zmSlangStepNone             = 'No Step';
+$zmSlangStepSmall            = 'Small Step';
+$zmSlangStep                 = 'Step';
 $zmSlangStills               = 'Stills';
 $zmSlangStopped              = 'Stopped';
 $zmSlangStop                 = 'Stop';
 $zmSlangStream               = 'Stream';
 $zmSlangSubmit               = 'Submit';
 $zmSlangSystem               = 'System';
+$zmSlangTele                 = 'Tele';
 $zmSlangThumbnail            = 'Thumbnail';
+$zmSlangTilt                 = 'Tilt';
 $zmSlangTimeDelta            = 'Time Delta';
 $zmSlangTimestampLabelFormat = 'Timestamp Label Format';
 $zmSlangTimestampLabelX      = 'Timestamp Label X';
@@ -341,7 +477,11 @@ $zmSlangTime                 = 'Time';
 $zmSlangToday                = 'Today';
 $zmSlangTools                = 'Tools';
 $zmSlangTotalBrScore         = 'Total<br/>Score';
+$zmSlangTrackDelay           = 'Track Delay';
+$zmSlangTrackMotion          = 'Track Motion';
 $zmSlangTriggers             = 'Triggers';
+$zmSlangTurboPanSpeed        = 'Turbo Pan Speed';
+$zmSlangTurboTiltSpeed       = 'Turbo Tilt Speed';
 $zmSlangType                 = 'Type';
 $zmSlangUnarchive            = 'Unarchive';
 $zmSlangUnits                = 'Units';
@@ -368,10 +508,14 @@ $zmSlangVideo                = 'Video';
 $zmSlangViewAll              = 'View All';
 $zmSlangViewPaged            = 'View Paged';
 $zmSlangView                 = 'View';
+$zmSlangWake                 = 'Wake';
 $zmSlangWarmupFrames         = 'Warmup Frames';
 $zmSlangWatch                = 'Watch';
 $zmSlangWeb                  = 'Web';
 $zmSlangWeek                 = 'Week';
+$zmSlangWhiteBalance         = 'White Balance';
+$zmSlangWhite                = 'White';
+$zmSlangWide                 = 'Wide';
 $zmSlangX10ActivationString  = 'X10 Activation String';
 $zmSlangX10InputAlarmString  = 'X10 Input Alarm String';
 $zmSlangX10OutputAlarmString = 'X10 Output Alarm String';
@@ -385,18 +529,19 @@ $zmSlangZoneMaxAlarmedArea   = 'Maximum Alarmed Area';
 $zmSlangZoneMaxBlobArea      = 'Maximum Blob Area';
 $zmSlangZoneMaxBlobs         = 'Maximum Blobs';
 $zmSlangZoneMaxFilteredArea  = 'Maximum Filtered Area';
-$zmSlangZoneMaxPixelThres    = 'Maximum Pixel Threshold (0>=?<=255)';
+$zmSlangZoneMaxPixelThres    = 'Maximum Pixel Threshold (0-255)';
 $zmSlangZoneMaxX             = 'Maximum X (right)';
 $zmSlangZoneMaxY             = 'Maximum Y (bottom)';
 $zmSlangZoneMinAlarmedArea   = 'Minimum Alarmed Area';
 $zmSlangZoneMinBlobArea      = 'Minimum Blob Area';
 $zmSlangZoneMinBlobs         = 'Minimum Blobs';
 $zmSlangZoneMinFilteredArea  = 'Minimum Filtered Area';
-$zmSlangZoneMinPixelThres    = 'Minimum Pixel Threshold (0>=?<=255)';
+$zmSlangZoneMinPixelThres    = 'Minimum Pixel Threshold (0-255)';
 $zmSlangZoneMinX             = 'Minimum X (left)';
 $zmSlangZoneMinY             = 'Minimum Y (top)';
 $zmSlangZones                = 'Zones';
 $zmSlangZone                 = 'Zone';
+$zmSlangZoom                 = 'Zoom';
 
 // Complex replacements with formatting and/or placements, must be passed through sprintf
 $zmClangCurrentLogin         = 'Current login is \'%1$s\'';
