@@ -1,7 +1,7 @@
 <?php
 //
-// ZoneMinder web Argentinian Spanish language file, $Date: 2004/12/29 18:50:34 $, $Revision: 1.6 $
-// Copyright (C) 2003  Philip Coombes
+// ZoneMinder web Argentinian Spanish language file, $Date: 2005/03/16 17:38:37 $, $Revision: 1.8 $
+// Copyright (C) 2003, 2004, 2005  Philip Coombes
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -24,6 +24,7 @@
 $zmSlang24BitColour          = 'Color 24 bits';
 $zmSlang8BitGrey             = 'Grises 8 bits';
 $zmSlangActual               = 'Actual';
+$zmSlangAddNewControl        = 'Add New Control';
 $zmSlangAddNewMonitor        = 'Agregar Nuevo Monitor';
 $zmSlangAddNewUser           = 'Agregar Nuevo Usuario';
 $zmSlangAddNewZone           = 'Agregar Nueva Zona';
@@ -52,34 +53,78 @@ $zmSlangAttrDuration         = 'Duracin';
 $zmSlangAttrFrames           = 'Cuadros';
 $zmSlangAttrId               = 'Id';
 $zmSlangAttrMaxScore         = 'Puntaje Mximo';
+$zmSlangAttrMonitorId        = 'Monitor Id';
+$zmSlangAttrMonitorName      = 'Nombre Monitor';
 $zmSlangAttrMontage          = 'Cmara Mltiple';
 $zmSlangAttrName             = 'Name';
 $zmSlangAttrTime             = 'Hora';
 $zmSlangAttrTotalScore       = 'Puntaje Total';
 $zmSlangAttrWeekday          = 'Da Semana';
 $zmSlangAutoArchiveEvents    = 'Archivar todos los eventos';
+$zmSlangAuto                 = 'Auto';
 $zmSlangAutoDeleteEvents     = 'Borrar todos los eventos';
 $zmSlangAutoEmailEvents      = 'Mandar un mail de todos los eventos';
 $zmSlangAutoExecuteEvents    = 'Ejecutar un comando en las coincidencias';
 $zmSlangAutoMessageEvents    = 'Mandar un mensaje de los eventos';
 $zmSlangAutoUploadEvents     = 'Subir los eventos que coincidan';
 $zmSlangAvgBrScore           = 'Punt.<br/>Promedio';
+$zmSlangBadNameChars         = 'Los nombres pueden contener solamente caracteres alfanumricos ms el guin y la raya';
 $zmSlangBandwidth            = 'Velocidad';
 $zmSlangBlobPx               = 'Blob Px';
 $zmSlangBlobs                = 'Blobs';
 $zmSlangBlobSizes            = 'Blob Sizes';
 $zmSlangBrightness           = 'Brillo';
 $zmSlangBuffers              = 'Buffers';
+$zmSlangCanAutoFocus         = 'Can Auto Focus';
+$zmSlangCanAutoGain          = 'Can Auto Gain';
+$zmSlangCanAutoIris          = 'Can Auto Iris';
+$zmSlangCanAutoWhite         = 'Can Auto White Bal.';
+$zmSlangCanAutoZoom          = 'Can Auto Zoom';
 $zmSlangCancel               = 'Cancelar';
 $zmSlangCancelForcedAlarm    = 'Cancelar&nbsp;Alarma&nbsp;Forzada';
+$zmSlangCanFocusAbs          = 'Can Focus Absolute';
+$zmSlangCanFocus             = 'Can Focus';
+$zmSlangCanFocusCon          = 'Can Focus Continuous';
+$zmSlangCanFocusRel          = 'Can Focus Relative';
+$zmSlangCanGainAbs           = 'Can Gain Absolute';
+$zmSlangCanGain              = 'Can Gain ';
+$zmSlangCanGainCon           = 'Can Gain Continuous';
+$zmSlangCanGainRel           = 'Can Gain Relative';
+$zmSlangCanIrisAbs           = 'Can Iris Absolute';
+$zmSlangCanIris              = 'Can Iris';
+$zmSlangCanIrisCon           = 'Can Iris Continuous';
+$zmSlangCanIrisRel           = 'Can Iris Relative';
+$zmSlangCanMoveAbs           = 'Can Move Absolute';
+$zmSlangCanMove              = 'Can Move';
+$zmSlangCanMoveCon           = 'Can Move Continuous';
+$zmSlangCanMoveDiag          = 'Can Move Diagonally';
+$zmSlangCanMoveMap           = 'Can Move Mapped';
+$zmSlangCanMoveRel           = 'Can Move Relative';
+$zmSlangCanPan               = 'Can Pan' ;
+$zmSlangCanReset             = 'Can Reset';
+$zmSlangCanSetPresets        = 'Can Set Presets';
+$zmSlangCanSleep             = 'Can Sleep';
+$zmSlangCanTilt              = 'Can Tilt';
+$zmSlangCanWake              = 'Can Wake';
+$zmSlangCanWhiteAbs          = 'Can White Bal. Absolute';
+$zmSlangCanWhiteBal          = 'Can White Bal.';
+$zmSlangCanWhite             = 'Can White Balance';
+$zmSlangCanWhiteCon          = 'Can White Bal. Continuous';
+$zmSlangCanWhiteRel          = 'Can White Bal. Relative';
+$zmSlangCanZoomAbs           = 'Can Zoom Absolute';
+$zmSlangCanZoom              = 'Can Zoom';
+$zmSlangCanZoomCon           = 'Can Zoom Continuous';
+$zmSlangCanZoomRel           = 'Can Zoom Relative';
 $zmSlangCaptureHeight        = 'Captura Alto';
 $zmSlangCapturePalette       = 'Captura Paleta';
 $zmSlangCaptureWidth         = 'Captura Ancho';
 $zmSlangCause                = 'Cause';
 $zmSlangCheckAll             = 'Marcar Todo';
+$zmSlangCheckMethod          = 'Alarm Check Method';
 $zmSlangChooseFilter         = 'Elegir Filtro';
 $zmSlangClose                = 'Cerrar';
 $zmSlangColour               = 'Color';
+$zmSlangCommand              = 'Command';
 $zmSlangConfig		     = 'Config.';
 $zmSlangConfiguredFor        = 'Configurado Para';
 $zmSlangConfirmPassword      = 'Confirmar Contrasea';
@@ -90,6 +135,13 @@ $zmSlangConsole              = 'Console';
 $zmSlangContactAdmin         = 'Contacte el Administrador para detalles.';
 $zmSlangContinue             = 'Continue';
 $zmSlangContrast             = 'Contraste';
+$zmSlangControlAddress       = 'Control Address';
+$zmSlangControlCap           = 'Control Capability';
+$zmSlangControlCaps          = 'Control Capabilities';
+$zmSlangControl              = 'Control';
+$zmSlangControlDevice        = 'Control Device';
+$zmSlangControllable         = 'Controllable';
+$zmSlangControlType          = 'Control Type';
 $zmSlangCycle                = 'Cycle';
 $zmSlangCycleWatch           = 'Cycle Watch';
 $zmSlangDay                  = 'Da';
@@ -119,9 +171,11 @@ $zmSlangEventName            = 'Event Name';
 $zmSlangEventPrefix          = 'Event Prefix';
 $zmSlangEvents               = 'Eventos';
 $zmSlangExclude              = 'Excluir';
+$zmSlangFar                  = 'Far';
 $zmSlangFeed                 = 'Vista';
 $zmSlangFilterPx             = 'Filtro Px';
 $zmSlangFirst                = 'Primero';
+$zmSlangFocus                = 'Focus';
 $zmSlangForceAlarm           = 'Forzar&nbsp;Alarma';
 $zmSlangFPS                  = 'fps';
 $zmSlangFPSReportInterval    = 'Intervalo de Reporte FPS';
@@ -133,12 +187,26 @@ $zmSlangFrameSkip            = 'Saltear Cuadro';
 $zmSlangFTP                  = 'FTP';
 $zmSlangFunc                 = 'Func';
 $zmSlangFunction             = 'Funcin';
+$zmSlangGain                 = 'Gain';
 $zmSlangGenerateVideo        = 'Crear Video';
 $zmSlangGeneratingVideo      = 'Creando Video';
+$zmSlangGoToZoneMinder       = 'Ir a Zoneminder.com';
 $zmSlangGrey                 = 'Gris';
 $zmSlangGroups               = 'Groups';
+$zmSlangHasFocusSpeed        = 'Has Focus Speed';
+$zmSlangHasGainSpeed         = 'Has Gain Speed';
+$zmSlangHasHomePreset        = 'Has Home Preset';
+$zmSlangHasIrisSpeed         = 'Has Iris Speed';
+$zmSlangHasPanSpeed          = 'Has Pan Speed';
+$zmSlangHasPresets           = 'Has Presets';
+$zmSlangHasTiltSpeed         = 'Has Tilt Speed';
+$zmSlangHasTurboPan          = 'Has Turbo Pan';
+$zmSlangHasTurboTilt         = 'Has Turbo Tilt';
+$zmSlangHasWhiteSpeed        = 'Has White Bal. Speed';
+$zmSlangHasZoomSpeed         = 'Has Zoom Speed';
 $zmSlangHigh                 = 'Alta';
 $zmSlangHighBW               = 'Alta&nbsp;B/W';
+$zmSlangHome                 = 'Home';
 $zmSlangHour                 = 'Hora';
 $zmSlangHue                  = 'Saturacin';
 $zmSlangId                   = 'Id';
@@ -147,7 +215,9 @@ $zmSlangIgnore               = 'Ignorar';
 $zmSlangImageBufferSize      = 'Tamao del Buffer de Imagen';
 $zmSlangImage                = 'Imagen';
 $zmSlangInclude              = 'Incluir';
+$zmSlangIn                   = 'In';
 $zmSlangInverted             = 'Invertido';
+$zmSlangIris                 = 'Iris';
 $zmSlangIsequalto            = 'Es igual a';
 $zmSlangIsEqualTo            = 'is equal to'; 
 $zmSlangLanguage             = 'Lenguaje';
@@ -162,25 +232,77 @@ $zmSlangLogin                = 'Ingresar';
 $zmSlangLogout               = 'Salir';
 $zmSlangLow                  = 'Baja';
 $zmSlangLowBW                = 'Baja&nbsp;B/W';
+$zmSlangMain                 = 'Main';
+$zmSlangMan                  = 'Man';
+$zmSlangManual               = 'Manual';
 $zmSlangMark                 = 'Marca';
 $zmSlangMaxBrScore           = 'Puntaje<br/>Max.';
+$zmSlangMaxFocusRange        = 'Max Focus Range';
+$zmSlangMaxFocusSpeed        = 'Max Focus Speed';
+$zmSlangMaxFocusStep         = 'Max Focus Step';
+$zmSlangMaxGainRange         = 'Max Gain Range';
+$zmSlangMaxGainSpeed         = 'Max Gain Speed';
+$zmSlangMaxGainStep          = 'Max Gain Step';
 $zmSlangMaximumFPS           = 'Maximos FPS';
+$zmSlangMaxIrisRange         = 'Max Iris Range';
+$zmSlangMaxIrisSpeed         = 'Max Iris Speed';
+$zmSlangMaxIrisStep          = 'Max Iris Step';
 $zmSlangMax                  = 'Max';
+$zmSlangMaxPanRange          = 'Max Pan Range';
+$zmSlangMaxPanSpeed          = 'Max Pan Speed';
+$zmSlangMaxPanStep           = 'Max Pan Step';
+$zmSlangMaxTiltRange         = 'Max Tilt Range';
+$zmSlangMaxTiltSpeed         = 'Max Tilt Speed';
+$zmSlangMaxTiltStep          = 'Max Tilt Step';
+$zmSlangMaxWhiteRange        = 'Max White Bal. Range';
+$zmSlangMaxWhiteSpeed        = 'Max White Bal. Speed';
+$zmSlangMaxWhiteStep         = 'Max White Bal. Step';
+$zmSlangMaxZoomRange         = 'Max Zoom Range';
+$zmSlangMaxZoomSpeed         = 'Max Zoom Speed';
+$zmSlangMaxZoomStep          = 'Max Zoom Step';
 $zmSlangMediumBW             = 'Media&nbsp;B/W';
 $zmSlangMedium               = 'Media';
 $zmSlangMinAlarmGeMinBlob    = 'Minimum alarm pixels should be greater than or equal to minimum blob pixels';
 $zmSlangMinAlarmGeMinFilter  = 'Minimum alarm pixels should be greater than or equal to minimum filter pixels';
+$zmSlangMinAlarmPixelsLtMax  = 'Minimum alarm pixels should be less than maximum alarm pixels';
+$zmSlangMinBlobAreaLtMax     = 'Minimum blob area should be less than maximum blob area';
+$zmSlangMinBlobsLtMax        = 'Minimum blobs should be less than maximum blobs';
+$zmSlangMinFilterPixelsLtMax = 'Minimum filter pixels should be less than maximum filter pixels';
+$zmSlangMinFocusRange        = 'Min Focus Range';
+$zmSlangMinFocusSpeed        = 'Min Focus Speed';
+$zmSlangMinFocusStep         = 'Min Focus Step';
+$zmSlangMinGainRange         = 'Min Gain Range';
+$zmSlangMinGainSpeed         = 'Min Gain Speed';
+$zmSlangMinGainStep          = 'Min Gain Step';
+$zmSlangMinIrisRange         = 'Min Iris Range';
+$zmSlangMinIrisSpeed         = 'Min Iris Speed';
+$zmSlangMinIrisStep          = 'Min Iris Step';
+$zmSlangMinPanRange          = 'Min Pan Range';
+$zmSlangMinPanSpeed          = 'Min Pan Speed';
+$zmSlangMinPanStep           = 'Min Pan Step';
+$zmSlangMinPixelThresLtMax   = 'Minimum pixel threshold should be less than maximum pixel threshold';
+$zmSlangMinTiltRange         = 'Min Tilt Range';
+$zmSlangMinTiltSpeed         = 'Min Tilt Speed';
+$zmSlangMinTiltStep          = 'Min Tilt Step';
+$zmSlangMinWhiteRange        = 'Min White Bal. Range';
+$zmSlangMinWhiteSpeed        = 'Min White Bal. Speed';
+$zmSlangMinWhiteStep         = 'Min White Bal. Step';
+$zmSlangMinZoomRange         = 'Min Zoom Range';
+$zmSlangMinZoomSpeed         = 'Min Zoom Speed';
+$zmSlangMinZoomStep          = 'Min Zoom Step';
 $zmSlangMisc                 = 'Otros';
 $zmSlangMonitorIds           = 'Ids&nbsp;Monitor';
 $zmSlangMonitor              = 'Monitor';
 $zmSlangMonitors             = 'Monitores';
 $zmSlangMontage              = 'Cmara Mltiple';
 $zmSlangMonth                = 'Mes';
+$zmSlangMove                 = 'Move';
 $zmSlangMustBeGe             = 'Debe ser mayor o igual que';
 $zmSlangMustBeLe             = 'Debe ser menor o igual que';
 $zmSlangMustConfirmPassword  = 'Debe confirmar la contrasea';
 $zmSlangMustSupplyPassword   = 'Debe ingresar una contrasea';
 $zmSlangName                 = 'Nombre';
+$zmSlangNear                 = 'Near';
 $zmSlangNetwork              = 'Red';
 $zmSlangNewGroup             = 'New Group';
 $zmSlangNew                  = 'Nuevo';
@@ -196,19 +318,28 @@ $zmSlangNo                   = 'No';
 $zmSlangNormal               = 'Normal';
 $zmSlangNoSavedFilters       = 'FiltrosNoGuardados';
 $zmSlangNoStatisticsRecorded = 'No hay estadisticas guardadas para este evento/marco';
+$zmSlangNumPresets           = 'Num Presets';
+$zmSlangOpen                 = 'Open';
 $zmSlangOpEq                 = 'igual que';
 $zmSlangOpGtEq               = 'mayor o igual que';
 $zmSlangOpGt                 = 'mayor que';
+$zmSlangOpIn                 = 'En sistema';
 $zmSlangOpLtEq               = 'menor o igual que';
 $zmSlangOpLt                 = 'menor que';
+$zmSlangOpMatches            = 'Coincide';
 $zmSlangOpNe                 = 'distinto que';
+$zmSlangOpNotIn              = 'No en sistema';
+$zmSlangOpNotMatches         = 'No coincide';
 $zmSlangOptionHelp           = 'Ayuda';
 $zmSlangOptionRestartWarning = 'Estos cambios no se guardaran completamente\nmientras el sistema se ejecute. Cuando termine\nde realizar los cambios asegurese de\nreiniciar Zoneminder.';
 $zmSlangOptions              = 'Opciones';
 $zmSlangOrEnterNewName       = 'o agregue  nombre';
 $zmSlangOrientation          = 'Orientacin';
+$zmSlangOut                  = 'Out';
 $zmSlangOverwriteExisting    = 'Sobreescribir Exitente';
 $zmSlangPaged                = 'Paged';
+$zmSlangPan                  = 'Pan';
+$zmSlangPanTilt              = 'Pan/Tilt';
 $zmSlangParameter            = 'Parametro';
 $zmSlangPassword             = 'Contrasea';
 $zmSlangPasswordsDifferent   = 'Las contraseas nueva y de confirmacion son diferentes';
@@ -220,6 +351,8 @@ $zmSlangPlayAll              = 'Play All';
 $zmSlangPleaseWait           = 'Espere por favor';
 $zmSlangPostEventImageBuffer = 'Buffer Imagenes despues evento';
 $zmSlangPreEventImageBuffer  = 'Buffer Imagenes antes evento';
+$zmSlangPreset               = 'Preset';
+$zmSlangPresets              = 'Presets';
 $zmSlangPrev                 = 'Prev';
 $zmSlangRate                 = 'Ritmo';
 $zmSlangReal                 = 'Real';
@@ -238,6 +371,8 @@ $zmSlangReset                = 'Reset';
 $zmSlangRestarting           = 'Reiniciando';
 $zmSlangRestart              = 'Reiniciar';
 $zmSlangRestrictedCameraIds  = 'Id. Camara restringida';
+$zmSlangReturnDelay          = 'Return Delay';
+$zmSlangReturnLocation       = 'Return Location';
 $zmSlangRotateLeft           = 'Rotar a la derecha';
 $zmSlangRotateRight          = 'Rotar a la izquierda';
 $zmSlangRunMode              = 'Metodo Ejecucion';
@@ -254,24 +389,39 @@ $zmSlangSelect               = 'Select';
 $zmSlangServerLoad           = 'Carga Servidor';
 $zmSlangSetLearnPrefs        = 'Set Learn Prefs'; // This can be ignored for now
 $zmSlangSetNewBandwidth      = 'Nuevo Ancho de Banda';
+$zmSlangSetPreset            = 'Set Preset';
+$zmSlangSet                  = 'Set';
 $zmSlangSettings             = 'Configuracion';
 $zmSlangShowFilterWindow     = 'Abrir Filtro';
+$zmSlangSleep                = 'Sleep';
 $zmSlangSortAsc              = 'Asc';
 $zmSlangSortBy               = 'Ordenar por';
 $zmSlangSortDesc             = 'Desc';
 $zmSlangSource               = 'Origen';
 $zmSlangSourceType           = 'Tipo Origen';
+$zmSlangSpeedHigh            = 'High Speed';
+$zmSlangSpeedLow             = 'Low Speed';
+$zmSlangSpeedMedium          = 'Medium Speed';
+$zmSlangSpeed                = 'Speed';
+$zmSlangSpeedTurbo           = 'Turbo Speed';
 $zmSlangStart                = 'Iniciar';
 $zmSlangState                = 'Estado';
 $zmSlangStats                = 'Est.';
 $zmSlangStatus               = 'Estado';
+$zmSlangStepLarge            = 'Large Step';
+$zmSlangStepMedium           = 'Medium Step';
+$zmSlangStepNone             = 'No Step';
+$zmSlangStepSmall            = 'Small Step';
+$zmSlangStep                 = 'Step';
 $zmSlangStills               = 'Fotos';
 $zmSlangStop                 = 'Desactivar';
 $zmSlangStopped              = 'Apagado';
 $zmSlangStream               = 'Stream';
 $zmSlangSubmit               = 'Submit';
 $zmSlangSystem               = 'Sistema';
+$zmSlangTele                 = 'Tele';
 $zmSlangThumbnail            = 'Thumbnail';
+$zmSlangTilt                 = 'Tilt';
 $zmSlangTimeDelta            = 'Hora Delta';
 $zmSlangTime                 = 'Hora';
 $zmSlangTimestamp            = 'Etiqueta Hora';
@@ -282,11 +432,17 @@ $zmSlangTimestampLabelY      = 'Eje Y Etiqueta Hora';
 $zmSlangToday                = 'Today';
 $zmSlangTools                = 'Herra.';
 $zmSlangTotalBrScore         = 'Total<br/>puntuacin';
+$zmSlangTrackDelay           = 'Track Delay';
+$zmSlangTrackMotion          = 'Track Motion';
 $zmSlangTriggers             = 'Gatillos';
+$zmSlangTurboPanSpeed        = 'Turbo Pan Speed';
+$zmSlangTurboTiltSpeed       = 'Turbo Tilt Speed';
 $zmSlangType                 = 'Tipo';
 $zmSlangUnarchive            = 'Desarchivar';
 $zmSlangUnits                = 'Unidades';
 $zmSlangUnknown              = 'Desconocido';
+$zmSlangUpdateAvailable      = 'Una Actualizacin a ZoneMinder esta disponible';
+$zmSlangUpdateNotNecessary   = 'No se requiere Actualizacin';
 $zmSlangUseFilterExprsPost   = '&nbsp;filtrar&nbsp;sentencias'; // This is used at the end of the phrase 'use N filter expressions'
 $zmSlangUseFilterExprsPre    = 'Utilizar&nbsp;'; // This is used at the beginning of the phrase 'use N filter expressions'
 $zmSlangUseFilter            = 'Usar Filtro';
@@ -294,6 +450,12 @@ $zmSlangUsername             = 'Nombre';
 $zmSlangUsers                = 'Usuarios';
 $zmSlangUser                 = 'Usuario';
 $zmSlangValue                = 'Valor';
+$zmSlangVersionIgnore        = 'Ignore esta versin';
+$zmSlangVersionRemindDay     = 'Recordar en 1 da';
+$zmSlangVersionRemindHour    = 'Recordar en 1 hora';
+$zmSlangVersionRemindNever   = 'No avizar de nuevas versiones';
+$zmSlangVersionRemindWeek    = 'Recordar en 1 semana';
+$zmSlangVersion              = 'Versin';
 $zmSlangVideoGenFailed       = 'Fallo la creacion del video!';
 $zmSlangVideoGenParms        = 'Parametros Generacion Video';
 $zmSlangVideoSize            = 'Tamao Video';
@@ -301,10 +463,14 @@ $zmSlangVideo                = 'Video';
 $zmSlangViewAll              = 'Ver Todo';
 $zmSlangViewPaged            = 'View Paged';
 $zmSlangView                 = 'Ver';
+$zmSlangWake                 = 'Wake';
 $zmSlangWarmupFrames         = 'Avisos Movimiento';
 $zmSlangWatch                = 'Monitor';
 $zmSlangWeb                  = 'Web';
 $zmSlangWeek                 = 'Semana';
+$zmSlangWhiteBalance         = 'White Balance';
+$zmSlangWhite                = 'White';
+$zmSlangWide                 = 'Wide';
 $zmSlangX10ActivationString  = 'X10 Comando Activacin';
 $zmSlangX10InputAlarmString  = 'X10 Comando Entrada Alarma';
 $zmSlangX10OutputAlarmString = 'X10 Output Alarm String';
@@ -312,32 +478,35 @@ $zmSlangX10                  = 'X10';
 $zmSlangYes                  = 'Si';
 $zmSlangYouNoPerms           = 'No tiene permisos para acceder a este recurso.';
 $zmSlangZoneAlarmColour      = 'Color Alarma (RGB)';
-$zmSlangZoneAlarmThreshold   = 'Alarm Threshold (0>=?<=255)';
+$zmSlangZoneAlarmThreshold   = 'Alarm Threshold (0-255)';
 $zmSlangZoneFilterHeight     = 'Altura Filtro (pixels)';
 $zmSlangZoneFilterWidth      = 'Ancho FIltro (pixels)';
 $zmSlangZoneMaxAlarmedArea   = 'Maximo Area Alarma';
 $zmSlangZoneMaxBlobArea      = 'Maximo Blob Area';
 $zmSlangZoneMaxBlobs         = 'Maximo Blobs';
 $zmSlangZoneMaxFilteredArea  = 'Maximo Area Filtrada';
+$zmSlangZoneMaxPixelThres    = 'Maximum Pixel Threshold (0-255)';
 $zmSlangZoneMaxX             = 'Maximo X (Derecha)';
 $zmSlangZoneMaxY             = 'Maximo Y (Abajo)';
 $zmSlangZoneMinAlarmedArea   = 'Minimo Area Alarma';
 $zmSlangZoneMinBlobArea      = 'Minimum Blob Area';
 $zmSlangZoneMinBlobs         = 'Minimum Blobs';
 $zmSlangZoneMinFilteredArea  = 'Minimo Area Filtrada';
+$zmSlangZoneMinPixelThres    = 'Minimum Pixel Threshold (0-255)';
 $zmSlangZoneMinX             = 'Minimo X (Izquierda)';
 $zmSlangZoneMinY             = 'Minimo Y (Arriba)';
 $zmSlangZones                = 'Zonas';
 $zmSlangZone                 = 'Zona';
+$zmSlangZoom                 = 'Zoom';
 
-// Complex replacements with formatting and/or placements, must be passed through sprintf
 // Complex replacements with formatting and/or placements, must be passed through sprintf
 $zmClangCurrentLogin         = 'Usuario actual es \'%1$s\'';
 $zmClangEventCount           = '%1$s %2$s';
 $zmClangLastEvents           = 'Ultimo %1$s %2$s';
+$zmClangLatestRelease        = 'The latest release is v%1$s, you have v%2$s.';
 $zmClangMonitorCount         = '%1$s %2$s';
 $zmClangMonitorFunction      = 'Monitor %1$s Funcion';
-
+$zmClangRunningRecentVer     = 'You are running the most recent version of Zoneminder, v%s.';
 
 // Variable arrays expressing plurality, see the zmVlang description above
 $zmVlangEvent                = array( 0=>'Eventos', 1=>'Evento', 2=>'Eventos' );
@@ -357,34 +526,4 @@ function zmVlang( $lang_var_array, $count )
 	die( 'Error, unable to correlate variable language string' );
 }
 
-
-
-$zmSlangGoToZoneMinder       = 'Ir a Zoneminder.com';
-$zmSlangMinAlarmPixelsLtMax  = 'Minimum alarm pixels should be less than maximum alarm pixels';
-$zmSlangMinBlobAreaLtMax     = 'Minimum blob area should be less than maximum blob area';
-$zmSlangMinBlobsLtMax        = 'Minimum blobs should be less than maximum blobs';
-$zmSlangMinFilterPixelsLtMax = 'Minimum filter pixels should be less than maximum filter pixels';
-$zmSlangMinPixelThresLtMax   = 'Minimum pixel threshold should be less than maximum pixel threshold';
-$zmSlangUpdateNotNecessary   = 'No se requiere Actualizacin';
-$zmSlangUpdateAvailable      = 'Una Actualizacin a ZoneMinder esta disponible';
-$zmSlangVersion              = 'Versin';
-$zmSlangVersionIgnore        = 'Ignore esta versin';
-$zmSlangVersionRemindHour    = 'Recordar en 1 hora';
-$zmSlangVersionRemindDay     = 'Recordar en 1 da';
-$zmSlangVersionRemindWeek    = 'Recordar en 1 semana';
-$zmSlangVersionRemindNever   = 'No avizar de nuevas versiones';
-$zmSlangZoneMaxPixelThres    = 'Maximum Pixel Threshold (0>=?<=255)';
-$zmSlangZoneMinPixelThres    = 'Minimum Pixel Threshold (0>=?<=255)';
-$zmClangLatestRelease        = 'The latest release is v%1$s, you have v%2$s.';
-$zmClangRunningRecentVer     = 'You are running the most recent version of Zoneminder, v%s.';
-
-$zmSlangAttrMonitorId        = 'Monitor Id';
-$zmSlangAttrMonitorName      = 'Nombre Monitor';
-$zmSlangBadMonitorChars      = 'Los nombres del monitor pueden contener solamente caracteres alfanumricos ms el guin y la raya';
-$zmSlangCheckMethod          = 'Alarm Check Method';
-$zmSlangOpIn                 = 'En sistema';
-$zmSlangOpMatches            = 'Coincide';
-$zmSlangOpNotIn              = 'No en sistema';
-$zmSlangOpNotMatches         = 'No coincide';
-
 ?>
