@@ -1,7 +1,7 @@
 <?php
 //
-// ZoneMinder web UK French language file, $Date: 2004/12/29 18:50:34 $, $Revision: 1.9 $
-// Copyright (C) 2003  Philip Coombes
+// ZoneMinder web UK French language file, $Date: 2005/03/16 17:38:37 $, $Revision: 1.11 $
+// Copyright (C) 2003, 2004, 2005  Philip Coombes
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -73,6 +73,7 @@
 $zmSlang24BitColour          = 'Couleur 24 bit';
 $zmSlang8BitGrey             = 'Gris 8 bit';
 $zmSlangActual               = 'Rel';
+$zmSlangAddNewControl        = 'Add New Control';
 $zmSlangAddNewMonitor        = 'Aj. nouv. cran';
 $zmSlangAddNewUser           = 'Aj. nouv. util.';
 $zmSlangAddNewZone           = 'Aj. nouv. zone';
@@ -108,21 +109,60 @@ $zmSlangAttrTime             = 'Temps';
 $zmSlangAttrTotalScore       = 'Score total';
 $zmSlangAttrWeekday          = 'Semaine';
 $zmSlangAutoArchiveEvents    = 'Automatically archive all matches';
+$zmSlangAuto                 = 'Auto';
 $zmSlangAutoDeleteEvents     = 'Automatically delete all matches';
 $zmSlangAutoEmailEvents      = 'Automatically email details of all matches';
 $zmSlangAutoExecuteEvents    = 'Automatically execute command on all matches';
 $zmSlangAutoMessageEvents    = 'Automatically message details of all matches';
 $zmSlangAutoUploadEvents     = 'Automatically upload all matches';
 $zmSlangAvgBrScore           = 'Score<br/>moy.';
-$zmSlangBadMonitorChars      = 'Les noms d\'crans ne peuvent contenir que des lettres, chiffres, trait d\'union ou soulign';
+$zmSlangBadNameChars         = 'Les noms ne peuvent contenir que des lettres, chiffres, trait d\'union ou soulign';
 $zmSlangBandwidth            = 'Bande-pass.';
 $zmSlangBlobPx               = 'Px forme';
 $zmSlangBlobs                = 'Formes';
 $zmSlangBlobSizes            = 'Taille forme';
 $zmSlangBrightness           = 'Luminosit;';
 $zmSlangBuffers              = 'Tampons';
+$zmSlangCanAutoFocus         = 'Can Auto Focus';
+$zmSlangCanAutoGain          = 'Can Auto Gain';
+$zmSlangCanAutoIris          = 'Can Auto Iris';
+$zmSlangCanAutoWhite         = 'Can Auto White Bal.';
+$zmSlangCanAutoZoom          = 'Can Auto Zoom';
 $zmSlangCancel               = 'Annul.';
 $zmSlangCancelForcedAlarm    = 'Annul.&nbsp;Forc&eacute;&nbsp;Alarme';
+$zmSlangCanFocusAbs          = 'Can Focus Absolute';
+$zmSlangCanFocus             = 'Can Focus';
+$zmSlangCanFocusCon          = 'Can Focus Continuous';
+$zmSlangCanFocusRel          = 'Can Focus Relative';
+$zmSlangCanGainAbs           = 'Can Gain Absolute';
+$zmSlangCanGain              = 'Can Gain ';
+$zmSlangCanGainCon           = 'Can Gain Continuous';
+$zmSlangCanGainRel           = 'Can Gain Relative';
+$zmSlangCanIrisAbs           = 'Can Iris Absolute';
+$zmSlangCanIris              = 'Can Iris';
+$zmSlangCanIrisCon           = 'Can Iris Continuous';
+$zmSlangCanIrisRel           = 'Can Iris Relative';
+$zmSlangCanMoveAbs           = 'Can Move Absolute';
+$zmSlangCanMove              = 'Can Move';
+$zmSlangCanMoveCon           = 'Can Move Continuous';
+$zmSlangCanMoveDiag          = 'Can Move Diagonally';
+$zmSlangCanMoveMap           = 'Can Move Mapped';
+$zmSlangCanMoveRel           = 'Can Move Relative';
+$zmSlangCanPan               = 'Can Pan' ;
+$zmSlangCanReset             = 'Can Reset';
+$zmSlangCanSetPresets        = 'Can Set Presets';
+$zmSlangCanSleep             = 'Can Sleep';
+$zmSlangCanTilt              = 'Can Tilt';
+$zmSlangCanWake              = 'Can Wake';
+$zmSlangCanWhiteAbs          = 'Can White Bal. Absolute';
+$zmSlangCanWhiteBal          = 'Can White Bal.';
+$zmSlangCanWhite             = 'Can White Balance';
+$zmSlangCanWhiteCon          = 'Can White Bal. Continuous';
+$zmSlangCanWhiteRel          = 'Can White Bal. Relative';
+$zmSlangCanZoomAbs           = 'Can Zoom Absolute';
+$zmSlangCanZoom              = 'Can Zoom';
+$zmSlangCanZoomCon           = 'Can Zoom Continuous';
+$zmSlangCanZoomRel           = 'Can Zoom Relative';
 $zmSlangCaptureHeight        = 'Haut. capture';
 $zmSlangCapturePalette       = 'palette capture';
 $zmSlangCaptureWidth         = 'Larg. capture';
@@ -132,6 +172,7 @@ $zmSlangCheckMethod          = 'Mthode vrif. alarme';
 $zmSlangChooseFilter         = 'Choisir filtre';
 $zmSlangClose                = 'Fermer';
 $zmSlangColour               = 'Couleur';
+$zmSlangCommand              = 'Command';
 $zmSlangConfig               = 'Config';
 $zmSlangConfiguredFor        = 'Configur pour';
 $zmSlangConfirmPassword      = 'Confirmer mt de pass.';
@@ -141,6 +182,13 @@ $zmSlangConsole              = 'Console';
 $zmSlangContactAdmin         = 'Contactez votre administrateur SVP';
 $zmSlangContinue             = 'Continue';
 $zmSlangContrast             = 'Contraste';
+$zmSlangControlAddress       = 'Control Address';
+$zmSlangControlCap           = 'Control Capability';
+$zmSlangControlCaps          = 'Control Capabilities';
+$zmSlangControl              = 'Control';
+$zmSlangControlDevice        = 'Control Device';
+$zmSlangControllable         = 'Controllable';
+$zmSlangControlType          = 'Control Type';
 $zmSlangCycle                = 'Cycle';
 $zmSlangCycleWatch           = 'Cycle vision';
 $zmSlangDay                  = 'Jour';
@@ -170,9 +218,11 @@ $zmSlangEventName            = 'Event Name';
 $zmSlangEventPrefix          = 'Event Prefix';
 $zmSlangEvents               = 'Evnts';
 $zmSlangExclude              = 'Exclure';
+$zmSlangFar                  = 'Far';
 $zmSlangFeed                 = 'Feed';
 $zmSlangFilterPx             = 'Filter Px';
 $zmSlangFirst                = 'Prem.';
+$zmSlangFocus                = 'Focus';
 $zmSlangForceAlarm           = 'Force&nbsp;Alarme';
 $zmSlangFPS                  = 'i/s';
 $zmSlangFPSReportInterval    = 'FPS Report Interval';
@@ -184,13 +234,26 @@ $zmSlangFrameSkip            = 'Saut image';
 $zmSlangFTP                  = 'FTP';
 $zmSlangFunc                 = 'Fct';
 $zmSlangFunction             = 'Fonction';
+$zmSlangGain                 = 'Gain';
 $zmSlangGenerateVideo        = 'Gnrer Vido';
 $zmSlangGeneratingVideo      = 'Gnration Vido';
 $zmSlangGoToZoneMinder       = 'Aller sur ZoneMinder.com';
 $zmSlangGrey                 = 'Gris';
 $zmSlangGroups               = 'Groups';
+$zmSlangHasFocusSpeed        = 'Has Focus Speed';
+$zmSlangHasGainSpeed         = 'Has Gain Speed';
+$zmSlangHasHomePreset        = 'Has Home Preset';
+$zmSlangHasIrisSpeed         = 'Has Iris Speed';
+$zmSlangHasPanSpeed          = 'Has Pan Speed';
+$zmSlangHasPresets           = 'Has Presets';
+$zmSlangHasTiltSpeed         = 'Has Tilt Speed';
+$zmSlangHasTurboPan          = 'Has Turbo Pan';
+$zmSlangHasTurboTilt         = 'Has Turbo Tilt';
+$zmSlangHasWhiteSpeed        = 'Has White Bal. Speed';
+$zmSlangHasZoomSpeed         = 'Has Zoom Speed';
 $zmSlangHighBW               = 'Haut&nbsp;N/B';
 $zmSlangHigh                 = 'Haut';
+$zmSlangHome                 = 'Home';
 $zmSlangHour                 = 'Heure';
 $zmSlangHue                  = 'Teinte';
 $zmSlangIdle                 = 'Vide';
@@ -199,7 +262,9 @@ $zmSlangIgnore               = 'Ignorer';
 $zmSlangImageBufferSize      = 'Taille tampon image';
 $zmSlangImage                = 'Image';
 $zmSlangInclude              = 'Inclure';
+$zmSlangIn                   = 'In';
 $zmSlangInverted             = 'Invers';
+$zmSlangIris                 = 'Iris';
 $zmSlangLanguage             = 'Langue';
 $zmSlangLast                 = 'Dernier';
 $zmSlangLimitResultsPost     = 'results only;'; // This is used at the end of the phrase 'Limit to first N results only'
@@ -212,10 +277,34 @@ $zmSlangLogin                = 'Login';
 $zmSlangLogout               = 'Dconnexion';
 $zmSlangLow                  = 'Bas';
 $zmSlangLowBW                = 'Basse&nbsp;N/B';
+$zmSlangMain                 = 'Main';
+$zmSlangMan                  = 'Man';
+$zmSlangManual               = 'Manual';
 $zmSlangMark                 = 'Marque';
 $zmSlangMaxBrScore           = 'Score<br/>max';
+$zmSlangMaxFocusRange        = 'Max Focus Range';
+$zmSlangMaxFocusSpeed        = 'Max Focus Speed';
+$zmSlangMaxFocusStep         = 'Max Focus Step';
+$zmSlangMaxGainRange         = 'Max Gain Range';
+$zmSlangMaxGainSpeed         = 'Max Gain Speed';
+$zmSlangMaxGainStep          = 'Max Gain Step';
 $zmSlangMaximumFPS           = 'i/s maximum';
+$zmSlangMaxIrisRange         = 'Max Iris Range';
+$zmSlangMaxIrisSpeed         = 'Max Iris Speed';
+$zmSlangMaxIrisStep          = 'Max Iris Step';
 $zmSlangMax                  = 'Max';
+$zmSlangMaxPanRange          = 'Max Pan Range';
+$zmSlangMaxPanSpeed          = 'Max Pan Speed';
+$zmSlangMaxPanStep           = 'Max Pan Step';
+$zmSlangMaxTiltRange         = 'Max Tilt Range';
+$zmSlangMaxTiltSpeed         = 'Max Tilt Speed';
+$zmSlangMaxTiltStep          = 'Max Tilt Step';
+$zmSlangMaxWhiteRange        = 'Max White Bal. Range';
+$zmSlangMaxWhiteSpeed        = 'Max White Bal. Speed';
+$zmSlangMaxWhiteStep         = 'Max White Bal. Step';
+$zmSlangMaxZoomRange         = 'Max Zoom Range';
+$zmSlangMaxZoomSpeed         = 'Max Zoom Speed';
+$zmSlangMaxZoomStep          = 'Max Zoom Step';
 $zmSlangMediumBW             = 'Moy.&nbsp;N/B';
 $zmSlangMedium               = 'Medium';
 $zmSlangMinAlarmGeMinBlob    = 'Minimum alarm pixels should be greater than or equal to minimum blob pixels';
@@ -224,19 +313,42 @@ $zmSlangMinAlarmPixelsLtMax  = 'Pixels alarme min. doit  < pixels alarme max.';
 $zmSlangMinBlobAreaLtMax     = 'Aire blob min. doit  < aire blob maximum';
 $zmSlangMinBlobsLtMax        = 'Blobs min. doit  < blobs max.';
 $zmSlangMinFilterPixelsLtMax = 'Pixels filtre min. doit  < pixels filtre max';
+$zmSlangMinFocusRange        = 'Min Focus Range';
+$zmSlangMinFocusSpeed        = 'Min Focus Speed';
+$zmSlangMinFocusStep         = 'Min Focus Step';
+$zmSlangMinGainRange         = 'Min Gain Range';
+$zmSlangMinGainSpeed         = 'Min Gain Speed';
+$zmSlangMinGainStep          = 'Min Gain Step';
+$zmSlangMinIrisRange         = 'Min Iris Range';
+$zmSlangMinIrisSpeed         = 'Min Iris Speed';
+$zmSlangMinIrisStep          = 'Min Iris Step';
+$zmSlangMinPanRange          = 'Min Pan Range';
+$zmSlangMinPanSpeed          = 'Min Pan Speed';
+$zmSlangMinPanStep           = 'Min Pan Step';
 $zmSlangMinPixelThresLtMax   = 'Seuil pixel min. doit  < seuil pixel max.';
+$zmSlangMinTiltRange         = 'Min Tilt Range';
+$zmSlangMinTiltSpeed         = 'Min Tilt Speed';
+$zmSlangMinTiltStep          = 'Min Tilt Step';
+$zmSlangMinWhiteRange        = 'Min White Bal. Range';
+$zmSlangMinWhiteSpeed        = 'Min White Bal. Speed';
+$zmSlangMinWhiteStep         = 'Min White Bal. Step';
+$zmSlangMinZoomRange         = 'Min Zoom Range';
+$zmSlangMinZoomSpeed         = 'Min Zoom Speed';
+$zmSlangMinZoomStep          = 'Min Zoom Step';
 $zmSlangMisc                 = 'Div.';
 $zmSlangMonitor              = 'Ecran';
 $zmSlangMonitorIds           = 'N&nbsp;cran';
 $zmSlangMonitors             = 'Ecrans';
 $zmSlangMontage              = 'Montage';
 $zmSlangMonth                = 'Mois';
+$zmSlangMove                 = 'Move';
 $zmSlangMustBeGe             = 'doit tre sup. ou gal ';
 $zmSlangMustBeLe             = 'doit tre inf. ou gal ';
 $zmSlangMustConfirmPassword  = 'Confirmez le mot de passe';
 $zmSlangMustSupplyPassword   = 'Entrez un mot de passe';
 $zmSlangMustSupplyUsername   = 'Entrez un nom d\'utilisateur';
 $zmSlangName                 = 'Nom';
+$zmSlangNear                 = 'Near';
 $zmSlangNetwork              = 'Rseau';
 $zmSlangNewGroup             = 'New Group';
 $zmSlangNew                  = 'Nouv.';
@@ -252,6 +364,8 @@ $zmSlangNo                   = 'Non';
 $zmSlangNormal               = 'Normal';
 $zmSlangNoSavedFilters       = 'Pasfiltressauv';
 $zmSlangNoStatisticsRecorded = 'Pas de statistiques disponibles pour cet vnmnt/imag.';
+$zmSlangNumPresets           = 'Num Presets';
+$zmSlangOpen                 = 'Open';
 $zmSlangOpEq                 = 'gal ';
 $zmSlangOpGtEq               = 'plus grand ou gal ';
 $zmSlangOpGt                 = 'sup. ';
@@ -267,8 +381,11 @@ $zmSlangOptionRestartWarning = 'These changes may not come into effect fully\nwh
 $zmSlangOptions              = 'Options';
 $zmSlangOrEnterNewName       = 'ou entrez nv nom';
 $zmSlangOrientation          = 'Orientation';
+$zmSlangOut                  = 'Out';
 $zmSlangOverwriteExisting    = 'Ecraser l\'existant';
 $zmSlangPaged                = 'Paged';
+$zmSlangPan                  = 'Pan';
+$zmSlangPanTilt              = 'Pan/Tilt';
 $zmSlangParameter            = 'Paramtre';
 $zmSlangPassword             = 'Mt de passe';
 $zmSlangPasswordsDifferent   = 'Les 2 mots de passe sont diffrents';
@@ -280,6 +397,8 @@ $zmSlangPlayAll              = 'Play All';
 $zmSlangPleaseWait           = 'Attendez';
 $zmSlangPostEventImageBuffer = 'Post Event Image Buffer';
 $zmSlangPreEventImageBuffer  = 'Pre Event Image Buffer';
+$zmSlangPreset               = 'Preset';
+$zmSlangPresets              = 'Presets';
 $zmSlangPrev                 = 'Prec.';
 $zmSlangRate                 = 'Dbit';
 $zmSlangReal                 = 'Rel';
@@ -298,6 +417,8 @@ $zmSlangReset                = 'Reset';
 $zmSlangRestarting           = 'Redmarrage';
 $zmSlangRestart              = 'Redmarrer';
 $zmSlangRestrictedCameraIds  = 'N camras confid.';
+$zmSlangReturnDelay          = 'Return Delay';
+$zmSlangReturnLocation       = 'Return Location';
 $zmSlangRotateLeft           = 'Rotation g.';
 $zmSlangRotateRight          = 'Rotation d.';
 $zmSlangRunMode              = 'Run Mode';
@@ -313,24 +434,39 @@ $zmSlangSectionlength        = 'Longueur section';
 $zmSlangSelect               = 'Select';
 $zmSlangSetLearnPrefs        = 'Rgler prf. apprises'; // This can be ignored for now
 $zmSlangSetNewBandwidth      = 'Rgler la bande passante';
+$zmSlangSetPreset            = 'Set Preset';
+$zmSlangSet                  = 'Set';
 $zmSlangSettings             = 'Rglages';
 $zmSlangShowFilterWindow     = 'Montrerfen.filtre';
+$zmSlangSleep                = 'Sleep';
 $zmSlangSortAsc              = 'Asc';
 $zmSlangSortBy               = 'Sort by';
 $zmSlangSortDesc             = 'Desc';
 $zmSlangSource               = 'Source';
 $zmSlangSourceType           = 'Source Type';
+$zmSlangSpeedHigh            = 'High Speed';
+$zmSlangSpeedLow             = 'Low Speed';
+$zmSlangSpeedMedium          = 'Medium Speed';
+$zmSlangSpeed                = 'Speed';
+$zmSlangSpeedTurbo           = 'Turbo Speed';
 $zmSlangStart                = 'Dmarrer';
 $zmSlangState                = 'Etat';
 $zmSlangStats                = 'Stats';
 $zmSlangStatus               = 'Statut';
+$zmSlangStepLarge            = 'Large Step';
+$zmSlangStepMedium           = 'Medium Step';
+$zmSlangStepNone             = 'No Step';
+$zmSlangStepSmall            = 'Small Step';
+$zmSlangStep                 = 'Step';
 $zmSlangStills               = 'Photos';
 $zmSlangStopped              = 'Arrt';
 $zmSlangStop                 = 'Stop';
 $zmSlangStream               = 'Flux';
 $zmSlangSubmit               = 'Submit';
 $zmSlangSystem               = 'Systme';
+$zmSlangTele                 = 'Tele';
 $zmSlangThumbnail            = 'Thumbnail';
+$zmSlangTilt                 = 'Tilt';
 $zmSlangTimeDelta            = 'Time Delta';
 $zmSlangTimestampLabelFormat = 'Timestamp Label Format';
 $zmSlangTimestampLabelX      = 'Timestamp Label X';
@@ -341,7 +477,11 @@ $zmSlangTime                 = 'Temps';
 $zmSlangToday                = 'Today';
 $zmSlangTools                = 'Outils';
 $zmSlangTotalBrScore         = 'Score<br/>total';
+$zmSlangTrackDelay           = 'Track Delay';
+$zmSlangTrackMotion          = 'Track Motion';
 $zmSlangTriggers             = 'Dclenchements';
+$zmSlangTurboPanSpeed        = 'Turbo Pan Speed';
+$zmSlangTurboTiltSpeed       = 'Turbo Tilt Speed';
 $zmSlangType                 = 'Type';
 $zmSlangUnarchive            = 'Dsarchiv.';
 $zmSlangUnits                = 'Units';
@@ -368,10 +508,14 @@ $zmSlangVideo                = 'Vido';
 $zmSlangViewAll              = 'Voir tt';
 $zmSlangViewPaged            = 'Vue recherche';
 $zmSlangView                 = 'Voir';
+$zmSlangWake                 = 'Wake';
 $zmSlangWarmupFrames         = 'Images test';
 $zmSlangWatch                = 'Regarder';
 $zmSlangWeb                  = 'Web';
 $zmSlangWeek                 = 'Semaine';
+$zmSlangWhiteBalance         = 'White Balance';
+$zmSlangWhite                = 'White';
+$zmSlangWide                 = 'Wide';
 $zmSlangX10ActivationString  = 'X10:chane activation';
 $zmSlangX10InputAlarmString  = 'X10:chane alarme entre';
 $zmSlangX10OutputAlarmString = 'X10:chane alarme sortie';
@@ -379,25 +523,26 @@ $zmSlangX10                  = 'X10';
 $zmSlangYes                  = 'Oui';
 $zmSlangYouNoPerms           = 'Permissions ncessaires pour cette ressource.';
 $zmSlangZoneAlarmColour      = 'Couleur alarme (RGB)';
-$zmSlangZoneAlarmThreshold   = 'Seuil alarme (0>=?<=255)';
+$zmSlangZoneAlarmThreshold   = 'Seuil alarme (0-255)';
 $zmSlangZoneFilterHeight     = 'Haut. filtre (pixels)';
 $zmSlangZoneFilterWidth      = 'Larg. filtre (pixels)';
 $zmSlangZoneMaxAlarmedArea   = 'Aire max. d\'alarme';
 $zmSlangZoneMaxBlobArea      = 'Maximum Blob Area';
 $zmSlangZoneMaxBlobs         = 'Maximum Blobs';
 $zmSlangZoneMaxFilteredArea  = 'Aire filtre max.';
-$zmSlangZoneMaxPixelThres    = 'Seuil pixel max. (0>=?<=255)';
+$zmSlangZoneMaxPixelThres    = 'Seuil pixel max. (0-255)';
 $zmSlangZoneMaxX             = 'X Maximum (dr.)';
 $zmSlangZoneMaxY             = 'Y Maximum (bas)';
 $zmSlangZoneMinAlarmedArea   = 'Aire min. d\'alarme';
 $zmSlangZoneMinBlobArea      = 'Minimum Blob Area';
 $zmSlangZoneMinBlobs         = 'Minimum Blobs';
 $zmSlangZoneMinFilteredArea  = 'Aire filtre minimum';
-$zmSlangZoneMinPixelThres    = 'Seuil pixel min. (0>=?<=255)';
+$zmSlangZoneMinPixelThres    = 'Seuil pixel min. (0-255)';
 $zmSlangZoneMinX             = 'X Minimum (gau.)';
 $zmSlangZoneMinY             = 'Y Minimum (som.)';
 $zmSlangZones                = 'Zones';
 $zmSlangZone                 = 'Zone';
+$zmSlangZoom                 = 'Zoom';
 
 // Complex replacements with formatting and/or placements, must be passed through sprintf
 $zmClangCurrentLogin         = 'Util. Actuel: \'%1$s\'';
