@@ -1,7 +1,7 @@
 <?php
 //
-// ZoneMinder web Italian language file, $Date: 2004/12/29 18:50:35 $, $Revision: 1.6 $
-// Copyright (C) 2003  Philip Coombes
+// ZoneMinder web Italian language file, $Date: 2005/03/16 17:38:37 $, $Revision: 1.8 $
+// Copyright (C) 2003, 2004, 2005  Philip Coombes
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -73,6 +73,7 @@
 $zmSlang24BitColour          = '24 bit colori';
 $zmSlang8BitGrey             = '8 bit toni di grigio';
 $zmSlangActual               = 'Attuale';
+$zmSlangAddNewControl        = 'Add New Control';
 $zmSlangAddNewMonitor        = 'Aggiungi Monitor';
 $zmSlangAddNewUser           = 'Aggiungi Utente';
 $zmSlangAddNewZone           = 'Aggiungi Zona';
@@ -108,21 +109,60 @@ $zmSlangAttrTime             = 'Ora';
 $zmSlangAttrTotalScore       = 'Punteggio totale';
 $zmSlangAttrWeekday          = 'Giorno della settimana';
 $zmSlangAutoArchiveEvents    = 'Archivia automaticamente';
+$zmSlangAuto                 = 'Auto';
 $zmSlangAutoDeleteEvents     = 'Elimina automaticamente';
 $zmSlangAutoEmailEvents      = 'Invia dettagli via email automaticamente';
 $zmSlangAutoExecuteEvents    = 'Esegui un comendo automaticamente';
 $zmSlangAutoMessageEvents    = 'Invia dettagli tramite messaggio automaticamente';
 $zmSlangAutoUploadEvents     = 'Automaticamente fai upload via FTP';
 $zmSlangAvgBrScore           = 'Punteggio<br/>medio';
-$zmSlangBadMonitorChars      = 'I nomi dei Monitor possono contenere solo caratteri alfanumerici pi&ugrave; i caratteri - e _';
+$zmSlangBadNameChars         = 'I nomi possono contenere solo caratteri alfanumerici pi&ugrave; i caratteri - e _';
 $zmSlangBandwidth            = 'Banda';
 $zmSlangBlobPx               = 'Blob Px';
 $zmSlangBlobs                = 'Blobs';
 $zmSlangBlobSizes            = 'Dimensioni Blob';
 $zmSlangBrightness           = 'Luminosit&agrave;';
 $zmSlangBuffers              = 'Buffers';
+$zmSlangCanAutoFocus         = 'Can Auto Focus';
+$zmSlangCanAutoGain          = 'Can Auto Gain';
+$zmSlangCanAutoIris          = 'Can Auto Iris';
+$zmSlangCanAutoWhite         = 'Can Auto White Bal.';
+$zmSlangCanAutoZoom          = 'Can Auto Zoom';
 $zmSlangCancel               = 'Annulla';
 $zmSlangCancelForcedAlarm    = 'Annulla&nbsp;Allarme&nbsp;Forzato';
+$zmSlangCanFocusAbs          = 'Can Focus Absolute';
+$zmSlangCanFocus             = 'Can Focus';
+$zmSlangCanFocusCon          = 'Can Focus Continuous';
+$zmSlangCanFocusRel          = 'Can Focus Relative';
+$zmSlangCanGainAbs           = 'Can Gain Absolute';
+$zmSlangCanGain              = 'Can Gain ';
+$zmSlangCanGainCon           = 'Can Gain Continuous';
+$zmSlangCanGainRel           = 'Can Gain Relative';
+$zmSlangCanIrisAbs           = 'Can Iris Absolute';
+$zmSlangCanIris              = 'Can Iris';
+$zmSlangCanIrisCon           = 'Can Iris Continuous';
+$zmSlangCanIrisRel           = 'Can Iris Relative';
+$zmSlangCanMoveAbs           = 'Can Move Absolute';
+$zmSlangCanMove              = 'Can Move';
+$zmSlangCanMoveCon           = 'Can Move Continuous';
+$zmSlangCanMoveDiag          = 'Can Move Diagonally';
+$zmSlangCanMoveMap           = 'Can Move Mapped';
+$zmSlangCanMoveRel           = 'Can Move Relative';
+$zmSlangCanPan               = 'Can Pan' ;
+$zmSlangCanReset             = 'Can Reset';
+$zmSlangCanSetPresets        = 'Can Set Presets';
+$zmSlangCanSleep             = 'Can Sleep';
+$zmSlangCanTilt              = 'Can Tilt';
+$zmSlangCanWake              = 'Can Wake';
+$zmSlangCanWhiteAbs          = 'Can White Bal. Absolute';
+$zmSlangCanWhiteBal          = 'Can White Bal.';
+$zmSlangCanWhite             = 'Can White Balance';
+$zmSlangCanWhiteCon          = 'Can White Bal. Continuous';
+$zmSlangCanWhiteRel          = 'Can White Bal. Relative';
+$zmSlangCanZoomAbs           = 'Can Zoom Absolute';
+$zmSlangCanZoom              = 'Can Zoom';
+$zmSlangCanZoomCon           = 'Can Zoom Continuous';
+$zmSlangCanZoomRel           = 'Can Zoom Relative';
 $zmSlangCaptureHeight        = 'Altezza di Cattura';
 $zmSlangCapturePalette       = 'Paletta di Cattura';
 $zmSlangCaptureWidth         = 'Larghezza di Cattura';
@@ -132,6 +172,7 @@ $zmSlangCheckMethod          = 'Metodo di Controllo Allarme';
 $zmSlangChooseFilter         = 'Scegli Filtro';
 $zmSlangClose                = 'Chiudi';
 $zmSlangColour               = 'Colori';
+$zmSlangCommand              = 'Command';
 $zmSlangConfig               = 'Configura';
 $zmSlangConfiguredFor        = 'Configurato per';
 $zmSlangConfirmPassword      = 'Conferma Password';
@@ -141,6 +182,13 @@ $zmSlangConsole              = 'Console';
 $zmSlangContactAdmin         = 'Contatta il tuo amministratore per dettagli.';
 $zmSlangContinue             = 'Continue';
 $zmSlangContrast             = 'Contrasto';
+$zmSlangControlAddress       = 'Control Address';
+$zmSlangControlCap           = 'Control Capability';
+$zmSlangControlCaps          = 'Control Capabilities';
+$zmSlangControl              = 'Control';
+$zmSlangControlDevice        = 'Control Device';
+$zmSlangControllable         = 'Controllable';
+$zmSlangControlType          = 'Control Type';
 $zmSlangCycle                = 'Cycle';
 $zmSlangCycleWatch           = 'Vista Ciclica';
 $zmSlangDay                  = 'Giorno';
@@ -170,9 +218,11 @@ $zmSlangEventName            = 'Event Name';
 $zmSlangEventPrefix          = 'Event Prefix';
 $zmSlangEvents               = 'Eventi';
 $zmSlangExclude              = 'Escludi';
+$zmSlangFar                  = 'Far';
 $zmSlangFeed                 = 'Feed';
 $zmSlangFilterPx             = 'Px Filtro';
 $zmSlangFirst                = 'Primo';
+$zmSlangFocus                = 'Focus';
 $zmSlangForceAlarm           = 'Forza&nbsp;Allarme';
 $zmSlangFPS                  = 'fps';
 $zmSlangFPSReportInterval    = 'Intervallo Report FPS';
@@ -184,13 +234,26 @@ $zmSlangFrameSkip            = 'Salta Immagine';
 $zmSlangFTP                  = 'FTP';
 $zmSlangFunc                 = 'Funz';
 $zmSlangFunction             = 'Funzione';
+$zmSlangGain                 = 'Gain';
 $zmSlangGenerateVideo        = 'Genera Video';
 $zmSlangGeneratingVideo      = 'Sto generando il Video';
 $zmSlangGoToZoneMinder       = 'Vai su ZoneMinder.com';
 $zmSlangGrey                 = 'Grigio';
 $zmSlangGroups               = 'Groups';
+$zmSlangHasFocusSpeed        = 'Has Focus Speed';
+$zmSlangHasGainSpeed         = 'Has Gain Speed';
+$zmSlangHasHomePreset        = 'Has Home Preset';
+$zmSlangHasIrisSpeed         = 'Has Iris Speed';
+$zmSlangHasPanSpeed          = 'Has Pan Speed';
+$zmSlangHasPresets           = 'Has Presets';
+$zmSlangHasTiltSpeed         = 'Has Tilt Speed';
+$zmSlangHasTurboPan          = 'Has Turbo Pan';
+$zmSlangHasTurboTilt         = 'Has Turbo Tilt';
+$zmSlangHasWhiteSpeed        = 'Has White Bal. Speed';
+$zmSlangHasZoomSpeed         = 'Has Zoom Speed';
 $zmSlangHigh                 = 'Alta';
 $zmSlangHighBW               = 'Banda&nbsp;Alta';
+$zmSlangHome                 = 'Home';
 $zmSlangHour                 = 'Ora';
 $zmSlangHue                  = 'Tinta';
 $zmSlangId                   = 'Id';
@@ -199,7 +262,9 @@ $zmSlangIgnore               = 'Ignora';
 $zmSlangImageBufferSize      = 'Dimensione del Buffer Immagine (quante immagini)';
 $zmSlangImage                = 'Immagine';
 $zmSlangInclude              = 'Includi';
+$zmSlangIn                   = 'In';
 $zmSlangInverted             = 'Invertito';
+$zmSlangIris                 = 'Iris';
 $zmSlangLanguage             = 'Linguaggio';
 $zmSlangLast                 = 'Ultimo';
 $zmSlangLimitResultsPost     = 'primi risultati;'; // This is used at the end of the phrase 'Limit to first N results only'
@@ -212,10 +277,34 @@ $zmSlangLogin                = 'Login';
 $zmSlangLogout               = 'Logout';
 $zmSlangLow                  = 'Bassa';
 $zmSlangLowBW                = 'Banda&nbsp;Bassa';
+$zmSlangMain                 = 'Main';
+$zmSlangMan                  = 'Man';
+$zmSlangManual               = 'Manual';
 $zmSlangMark                 = 'Seleziona';
 $zmSlangMaxBrScore           = 'Punteggio<br/>Massimo';
+$zmSlangMaxFocusRange        = 'Max Focus Range';
+$zmSlangMaxFocusSpeed        = 'Max Focus Speed';
+$zmSlangMaxFocusStep         = 'Max Focus Step';
+$zmSlangMaxGainRange         = 'Max Gain Range';
+$zmSlangMaxGainSpeed         = 'Max Gain Speed';
+$zmSlangMaxGainStep          = 'Max Gain Step';
 $zmSlangMaximumFPS           = 'Max FPS';
+$zmSlangMaxIrisRange         = 'Max Iris Range';
+$zmSlangMaxIrisSpeed         = 'Max Iris Speed';
+$zmSlangMaxIrisStep          = 'Max Iris Step';
 $zmSlangMax                  = 'Max';
+$zmSlangMaxPanRange          = 'Max Pan Range';
+$zmSlangMaxPanSpeed          = 'Max Pan Speed';
+$zmSlangMaxPanStep           = 'Max Pan Step';
+$zmSlangMaxTiltRange         = 'Max Tilt Range';
+$zmSlangMaxTiltSpeed         = 'Max Tilt Speed';
+$zmSlangMaxTiltStep          = 'Max Tilt Step';
+$zmSlangMaxWhiteRange        = 'Max White Bal. Range';
+$zmSlangMaxWhiteSpeed        = 'Max White Bal. Speed';
+$zmSlangMaxWhiteStep         = 'Max White Bal. Step';
+$zmSlangMaxZoomRange         = 'Max Zoom Range';
+$zmSlangMaxZoomSpeed         = 'Max Zoom Speed';
+$zmSlangMaxZoomStep          = 'Max Zoom Step';
 $zmSlangMediumBW             = 'Banda&nbsp;Media';
 $zmSlangMedium               = 'Media';
 $zmSlangMinAlarmGeMinBlob    = 'I pixel minimi dell\'allarme devono essere grandi almeno quanto i pixel minimi del blob';
@@ -224,19 +313,42 @@ $zmSlangMinAlarmPixelsLtMax  = 'I pixel minimi dell\'allarme devono essere minor
 $zmSlangMinBlobAreaLtMax     = 'L\'area di blob minima deve essere minore dell\'area di blob massima';
 $zmSlangMinBlobsLtMax        = 'I blob minini devono essere minori dei blob massimi';
 $zmSlangMinFilterPixelsLtMax = 'I pixel minimi del filtro devono essere minori di pixel massimi del filtro';
+$zmSlangMinFocusRange        = 'Min Focus Range';
+$zmSlangMinFocusSpeed        = 'Min Focus Speed';
+$zmSlangMinFocusStep         = 'Min Focus Step';
+$zmSlangMinGainRange         = 'Min Gain Range';
+$zmSlangMinGainSpeed         = 'Min Gain Speed';
+$zmSlangMinGainStep          = 'Min Gain Step';
+$zmSlangMinIrisRange         = 'Min Iris Range';
+$zmSlangMinIrisSpeed         = 'Min Iris Speed';
+$zmSlangMinIrisStep          = 'Min Iris Step';
+$zmSlangMinPanRange          = 'Min Pan Range';
+$zmSlangMinPanSpeed          = 'Min Pan Speed';
+$zmSlangMinPanStep           = 'Min Pan Step';
 $zmSlangMinPixelThresLtMax   = 'I pixel minimi della soglia devono essere minori del pixel massimi della soglia';
+$zmSlangMinTiltRange         = 'Min Tilt Range';
+$zmSlangMinTiltSpeed         = 'Min Tilt Speed';
+$zmSlangMinTiltStep          = 'Min Tilt Step';
+$zmSlangMinWhiteRange        = 'Min White Bal. Range';
+$zmSlangMinWhiteSpeed        = 'Min White Bal. Speed';
+$zmSlangMinWhiteStep         = 'Min White Bal. Step';
+$zmSlangMinZoomRange         = 'Min Zoom Range';
+$zmSlangMinZoomSpeed         = 'Min Zoom Speed';
+$zmSlangMinZoomStep          = 'Min Zoom Step';
 $zmSlangMisc                 = 'Altro';
 $zmSlangMonitorIds           = 'Monitor&nbsp;Ids';
 $zmSlangMonitor              = 'Monitor';
 $zmSlangMonitors             = 'Monitors';
 $zmSlangMontage              = 'Montaggio';
 $zmSlangMonth                = 'Mese';
+$zmSlangMove                 = 'Move';
 $zmSlangMustBeGe             = 'deve essere superiore a';
 $zmSlangMustBeLe             = 'deve essere inferiore o pari a';
 $zmSlangMustConfirmPassword  = 'Devi confermare la password';
 $zmSlangMustSupplyPassword   = 'Devi inserire una password';
 $zmSlangMustSupplyUsername   = 'Devi specificare un nome utente';
 $zmSlangName                 = 'Nome';
+$zmSlangNear                 = 'Near';
 $zmSlangNetwork              = 'Rete';
 $zmSlangNewGroup             = 'New Group';
 $zmSlangNew                  = 'Nuovo';
@@ -252,6 +364,8 @@ $zmSlangNo                   = 'No';
 $zmSlangNormal               = 'Normale';
 $zmSlangNoSavedFilters       = 'NessunFiltroSalvato';
 $zmSlangNoStatisticsRecorded = 'Non ci sono statistiche salvate per questo evento/immagine';
+$zmSlangNumPresets           = 'Num Presets';
+$zmSlangOpen                 = 'Open';
 $zmSlangOpEq                 = 'uguale a';
 $zmSlangOpGtEq               = 'maggiore o uguale a';
 $zmSlangOpGt                 = 'maggiore di';
@@ -267,8 +381,11 @@ $zmSlangOptionRestartWarning = 'Queste modifiche potrebbero essere attive solo d
 $zmSlangOptions              = 'Opzioni';
 $zmSlangOrEnterNewName       = 'o inserisci un nuovo nome';
 $zmSlangOrientation          = 'Orientamento';
+$zmSlangOut                  = 'Out';
 $zmSlangOverwriteExisting    = 'Sovrascrivi';
 $zmSlangPaged                = 'Con paginazione';
+$zmSlangPan                  = 'Pan';
+$zmSlangPanTilt              = 'Pan/Tilt';
 $zmSlangParameter            = 'Parametri';
 $zmSlangPassword             = 'Password';
 $zmSlangPasswordsDifferent   = 'Le password non coincidono';
@@ -280,6 +397,8 @@ $zmSlangPlayAll              = 'Play All';
 $zmSlangPleaseWait           = 'Attendere prego';
 $zmSlangPostEventImageBuffer = 'Buffer di immagini Dopo Evento';
 $zmSlangPreEventImageBuffer  = 'Buffer di immagini Pre Evento';
+$zmSlangPreset               = 'Preset';
+$zmSlangPresets              = 'Presets';
 $zmSlangPrev                 = 'Prec';
 $zmSlangRate                 = 'Rate';
 $zmSlangReal                 = 'Reale';
@@ -298,6 +417,8 @@ $zmSlangReset                = 'Reset';
 $zmSlangRestarting           = 'Sto riavviando';
 $zmSlangRestart              = 'Riavvia';
 $zmSlangRestrictedCameraIds  = 'Camera Ids Riservati';
+$zmSlangReturnDelay          = 'Return Delay';
+$zmSlangReturnLocation       = 'Return Location';
 $zmSlangRotateLeft           = 'Ruota a Sinista';
 $zmSlangRotateRight          = 'Ruota a Destra';
 $zmSlangRunMode              = 'Modalit Run';
@@ -313,24 +434,39 @@ $zmSlangSectionlength        = 'Lunghezza Sezione';
 $zmSlangSelect               = 'Select';
 $zmSlangSetLearnPrefs        = 'Set Learn Prefs'; // This can be ignored for now
 $zmSlangSetNewBandwidth      = 'Imposta nuova Banda';
+$zmSlangSetPreset            = 'Set Preset';
+$zmSlangSet                  = 'Set';
 $zmSlangSettings             = 'Impostazioni';
 $zmSlangShowFilterWindow     = 'MostraFinestraFiltri';
+$zmSlangSleep                = 'Sleep';
 $zmSlangSortAsc              = 'Cresc';
 $zmSlangSortBy               = 'Ordina per';
 $zmSlangSortDesc             = 'Decr';
 $zmSlangSource               = 'Sorgente';
 $zmSlangSourceType           = 'Tipo Sorgente';
+$zmSlangSpeedHigh            = 'High Speed';
+$zmSlangSpeedLow             = 'Low Speed';
+$zmSlangSpeedMedium          = 'Medium Speed';
+$zmSlangSpeed                = 'Speed';
+$zmSlangSpeedTurbo           = 'Turbo Speed';
 $zmSlangStart                = 'Avvia';
 $zmSlangState                = 'Stato';
 $zmSlangStats                = 'Statistiche';
 $zmSlangStatus               = 'Stato';
+$zmSlangStepLarge            = 'Large Step';
+$zmSlangStepMedium           = 'Medium Step';
+$zmSlangStepNone             = 'No Step';
+$zmSlangStepSmall            = 'Small Step';
+$zmSlangStep                 = 'Step';
 $zmSlangStills               = 'Foto';
 $zmSlangStopped              = 'Arrestato';
 $zmSlangStop                 = 'Stop';
 $zmSlangStream               = 'Flusso';
 $zmSlangSubmit               = 'Submit';
 $zmSlangSystem               = 'Sistema';
+$zmSlangTele                 = 'Tele';
 $zmSlangThumbnail            = 'Thumbnail';
+$zmSlangTilt                 = 'Tilt';
 $zmSlangTimeDelta            = 'Time Delta';
 $zmSlangTime                 = 'Ora';
 $zmSlangTimestampLabelFormat = 'Formato etichetta timestamp';
@@ -341,7 +477,11 @@ $zmSlangTimeStamp            = 'Time Stamp';
 $zmSlangToday                = 'Today';
 $zmSlangTools                = 'Tools';
 $zmSlangTotalBrScore         = 'Punteggio<br/>Totale';
+$zmSlangTrackDelay           = 'Track Delay';
+$zmSlangTrackMotion          = 'Track Motion';
 $zmSlangTriggers             = 'Triggers';
+$zmSlangTurboPanSpeed        = 'Turbo Pan Speed';
+$zmSlangTurboTiltSpeed       = 'Turbo Tilt Speed';
 $zmSlangType                 = 'Tipo';
 $zmSlangUnarchive            = 'Togli dall\'archivio';
 $zmSlangUnits                = 'Unit&agrave;';
@@ -368,10 +508,14 @@ $zmSlangVideo                = 'Video';
 $zmSlangViewAll              = 'Vedi Tutte';
 $zmSlangViewPaged            = 'Vedi con paginazione';
 $zmSlangView                 = 'vedi';
+$zmSlangWake                 = 'Wake';
 $zmSlangWarmupFrames         = 'Immagini Warmup';
 $zmSlangWatch                = 'Guarda';
 $zmSlangWeb                  = 'Web';
 $zmSlangWeek                 = 'Settimana';
+$zmSlangWhiteBalance         = 'White Balance';
+$zmSlangWhite                = 'White';
+$zmSlangWide                 = 'Wide';
 $zmSlangX10ActivationString  = 'Stringa attivazione X10';
 $zmSlangX10InputAlarmString  = 'Stringa allarme input X10';
 $zmSlangX10OutputAlarmString = 'Stringa allarme output X10';
@@ -385,18 +529,19 @@ $zmSlangZoneMaxAlarmedArea   = 'Massima Area Allarmata';
 $zmSlangZoneMaxBlobArea      = 'Massima Area Blob';
 $zmSlangZoneMaxBlobs         = 'Blob Massimi';
 $zmSlangZoneMaxFilteredArea  = 'Massima Area Fitlrata';
-$zmSlangZoneMaxPixelThres    = 'Pixel Massimi di Soglia (0>=?<=255)';
+$zmSlangZoneMaxPixelThres    = 'Pixel Massimi di Soglia (0-255)';
 $zmSlangZoneMaxX             = 'X Massimo (destra)';
 $zmSlangZoneMaxY             = 'Y Massimo (basso)';
 $zmSlangZoneMinAlarmedArea   = 'Minima Area Allarmata';
 $zmSlangZoneMinBlobArea      = 'Minima Area Blob';
 $zmSlangZoneMinBlobs         = 'Blob Minimi';
 $zmSlangZoneMinFilteredArea  = 'Minima Area Filtrata';
-$zmSlangZoneMinPixelThres    = 'Pixel Minimi di Soglia (0>=?<=255)';
+$zmSlangZoneMinPixelThres    = 'Pixel Minimi di Soglia (0-255)';
 $zmSlangZoneMinX             = 'X Minimo (sinistra)';
 $zmSlangZoneMinY             = 'Y Minimo (alto)';
 $zmSlangZones                = 'Zone';
 $zmSlangZone                 = 'Zona';
+$zmSlangZoom                 = 'Zoom';
 
 // Complex replacements with formatting and/or placements, must be passed through sprintf
 $zmClangCurrentLogin         = 'Login attuale: \'%1$s\'';
