@@ -1,7 +1,7 @@
 <?php
 //
-// ZoneMinder web Italian language file, $Date: 2004/12/29 18:50:35 $, $Revision: 1.4 $
-// Copyright (C) 2003  Philip Coombes
+// ZoneMinder web Italian language file, $Date: 2005/03/16 17:38:37 $, $Revision: 1.6 $
+// Copyright (C) 2003, 2004, 2005  Philip Coombes
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -73,6 +73,7 @@
 $zmSlang24BitColour          = 'colori a 24 bit';
 $zmSlang8BitGrey             = 'scala di grigio a 8 bit';
 $zmSlangActual               = 'Attuale';
+$zmSlangAddNewControl        = 'Add New Control';
 $zmSlangAddNewMonitor        = 'Aggiungi un nuovo Monitor';
 $zmSlangAddNewUser           = 'Aggiungi un nuovo Utente';
 $zmSlangAddNewZone           = 'Aggiungi una nuova Zona';
@@ -108,21 +109,61 @@ $zmSlangAttrTime             = 'Tempo';
 $zmSlangAttrTotalScore       = 'Punteggio Totale';
 $zmSlangAttrWeekday          = 'Giorno della Settimana';
 $zmSlangAutoArchiveEvents    = 'Archivia automaticamente tutti i matches';
+$zmSlangAuto                 = 'Auto';
 $zmSlangAutoDeleteEvents     = 'Cancella automaticamente tutti i matches';
 $zmSlangAutoEmailEvents      = 'Spedisci automaticamente emails con i dettagli di tutti i matches';
 $zmSlangAutoExecuteEvents    = 'Esegui comando automaticamente su tutti i';
 $zmSlangAutoMessageEvents    = 'Dettagli del messaggio automatico di tutti i matches';
 $zmSlangAutoUploadEvents     = 'Upload automatico di tutti i matches';
 $zmSlangAvgBrScore           = 'Punteggio Avg.<br/>';
-$zmSlangBadMonitorChars      = 'Il nome dei Monitor possono contenere solo caratteri alfanumerici piu - e _';
+$zmSlangBadNameChars         = 'Il nome possono contenere solo caratteri alfanumerici piu - e _';
+$zmSlangBadNameChars         = 'Names may only contain alphanumeric characters plus hyphen and underscore';
 $zmSlangBandwidth            = 'Banda Passante';
 $zmSlangBlobPx               = 'Blob Px';
 $zmSlangBlobs                = 'Blobs';
 $zmSlangBlobSizes            = 'Grandezza Blob';
 $zmSlangBrightness           = 'Luminosita';
 $zmSlangBuffers              = 'Buffers';
+$zmSlangCanAutoFocus         = 'Can Auto Focus';
+$zmSlangCanAutoGain          = 'Can Auto Gain';
+$zmSlangCanAutoIris          = 'Can Auto Iris';
+$zmSlangCanAutoWhite         = 'Can Auto White Bal.';
+$zmSlangCanAutoZoom          = 'Can Auto Zoom';
 $zmSlangCancel               = 'Cancella';
 $zmSlangCancelForcedAlarm    = 'Cancella&nbsp;Allarme&nbsp;Forzato';
+$zmSlangCanFocusAbs          = 'Can Focus Absolute';
+$zmSlangCanFocus             = 'Can Focus';
+$zmSlangCanFocusCon          = 'Can Focus Continuous';
+$zmSlangCanFocusRel          = 'Can Focus Relative';
+$zmSlangCanGainAbs           = 'Can Gain Absolute';
+$zmSlangCanGain              = 'Can Gain ';
+$zmSlangCanGainCon           = 'Can Gain Continuous';
+$zmSlangCanGainRel           = 'Can Gain Relative';
+$zmSlangCanIrisAbs           = 'Can Iris Absolute';
+$zmSlangCanIris              = 'Can Iris';
+$zmSlangCanIrisCon           = 'Can Iris Continuous';
+$zmSlangCanIrisRel           = 'Can Iris Relative';
+$zmSlangCanMoveAbs           = 'Can Move Absolute';
+$zmSlangCanMove              = 'Can Move';
+$zmSlangCanMoveCon           = 'Can Move Continuous';
+$zmSlangCanMoveDiag          = 'Can Move Diagonally';
+$zmSlangCanMoveMap           = 'Can Move Mapped';
+$zmSlangCanMoveRel           = 'Can Move Relative';
+$zmSlangCanPan               = 'Can Pan' ;
+$zmSlangCanReset             = 'Can Reset';
+$zmSlangCanSetPresets        = 'Can Set Presets';
+$zmSlangCanSleep             = 'Can Sleep';
+$zmSlangCanTilt              = 'Can Tilt';
+$zmSlangCanWake              = 'Can Wake';
+$zmSlangCanWhiteAbs          = 'Can White Bal. Absolute';
+$zmSlangCanWhiteBal          = 'Can White Bal.';
+$zmSlangCanWhite             = 'Can White Balance';
+$zmSlangCanWhiteCon          = 'Can White Bal. Continuous';
+$zmSlangCanWhiteRel          = 'Can White Bal. Relative';
+$zmSlangCanZoomAbs           = 'Can Zoom Absolute';
+$zmSlangCanZoom              = 'Can Zoom';
+$zmSlangCanZoomCon           = 'Can Zoom Continuous';
+$zmSlangCanZoomRel           = 'Can Zoom Relative';
 $zmSlangCaptureHeight        = 'Altezza immagine catturata';
 $zmSlangCapturePalette       = 'Palette immagine catturata';
 $zmSlangCaptureWidth         = 'Larghezza immagine catturata';
@@ -132,6 +173,7 @@ $zmSlangCheckMethod          = 'Metodo di controllo Alarme';
 $zmSlangChooseFilter         = 'Scegli il Filtro';
 $zmSlangClose                = 'Chiudi';
 $zmSlangColour               = 'Colore';
+$zmSlangCommand              = 'Command';
 $zmSlangConfig               = 'Configurazione';
 $zmSlangConfiguredFor        = 'Configurato per';
 $zmSlangConfirmPassword      = 'Conferma Password';
@@ -141,6 +183,13 @@ $zmSlangConsole              = 'Console';
 $zmSlangContactAdmin         = 'Chiama il tecnico per maggiori chiarimenti.';
 $zmSlangContinue             = 'Continue';
 $zmSlangContrast             = 'Contrasto';
+$zmSlangControlAddress       = 'Control Address';
+$zmSlangControlCap           = 'Control Capability';
+$zmSlangControlCaps          = 'Control Capabilities';
+$zmSlangControl              = 'Control';
+$zmSlangControlDevice        = 'Control Device';
+$zmSlangControllable         = 'Controllable';
+$zmSlangControlType          = 'Control Type';
 $zmSlangCycle                = 'Cycle';
 $zmSlangCycleWatch           = 'Guarda Ciclicamente';
 $zmSlangDay                  = 'Giorno';
@@ -170,9 +219,11 @@ $zmSlangEventName            = 'Event Name';
 $zmSlangEventPrefix          = 'Event Prefix';
 $zmSlangEvents               = 'Eventi';
 $zmSlangExclude              = 'Escludi';
+$zmSlangFar                  = 'Far';
 $zmSlangFeed                 = 'Feed';
 $zmSlangFilterPx             = 'Filter Px';
 $zmSlangFirst                = 'Primo';
+$zmSlangFocus                = 'Focus';
 $zmSlangForceAlarm           = 'Forza&nbsp;Allarme';
 $zmSlangFPS                  = 'fps';
 $zmSlangFPSReportInterval    = 'Intervallo di riporto FPS';
@@ -184,13 +235,26 @@ $zmSlangFrameSkip            = 'Immagini saltate';
 $zmSlangFTP                  = 'FTP';
 $zmSlangFunc                 = 'Funziona';
 $zmSlangFunction             = 'Funzione';
+$zmSlangGain                 = 'Gain';
 $zmSlangGenerateVideo        = 'Genera il Video';
 $zmSlangGeneratingVideo      = 'Sto Generando il Video';
 $zmSlangGoToZoneMinder       = 'Vai a: ZoneMinder.com';
 $zmSlangGrey                 = 'Grigio';
 $zmSlangGroups               = 'Groups';
+$zmSlangHasFocusSpeed        = 'Has Focus Speed';
+$zmSlangHasGainSpeed         = 'Has Gain Speed';
+$zmSlangHasHomePreset        = 'Has Home Preset';
+$zmSlangHasIrisSpeed         = 'Has Iris Speed';
+$zmSlangHasPanSpeed          = 'Has Pan Speed';
+$zmSlangHasPresets           = 'Has Presets';
+$zmSlangHasTiltSpeed         = 'Has Tilt Speed';
+$zmSlangHasTurboPan          = 'Has Turbo Pan';
+$zmSlangHasTurboTilt         = 'Has Turbo Tilt';
+$zmSlangHasWhiteSpeed        = 'Has White Bal. Speed';
+$zmSlangHasZoomSpeed         = 'Has Zoom Speed';
 $zmSlangHigh                 = 'Alta';
 $zmSlangHighBW               = 'High&nbsp;B/W';
+$zmSlangHome                 = 'Home';
 $zmSlangHour                 = 'Ora';
 $zmSlangHue                  = 'Hue';
 $zmSlangId                   = 'Id';
@@ -199,7 +263,9 @@ $zmSlangIgnore               = 'Ignora';
 $zmSlangImageBufferSize      = 'Grandezza Buffer Immagine (frames)';
 $zmSlangImage                = 'Immagine';
 $zmSlangInclude              = 'Includi';
+$zmSlangIn                   = 'In';
 $zmSlangInverted             = 'Invertito';
+$zmSlangIris                 = 'Iris';
 $zmSlangLanguage             = 'Linguaggio';
 $zmSlangLast                 = 'Ultimo';
 $zmSlangLimitResultsPost     = 'risultati;'; // This is used at the end of the phrase 'Limit to first N results only'
@@ -212,10 +278,34 @@ $zmSlangLogin                = 'Login';
 $zmSlangLogout               = 'Logout';
 $zmSlangLow                  = 'Bassa';
 $zmSlangLowBW                = 'Low&nbsp;B/W';
+$zmSlangMain                 = 'Main';
+$zmSlangMan                  = 'Man';
+$zmSlangManual               = 'Manual';
 $zmSlangMark                 = 'Contrassegna';
 $zmSlangMaxBrScore           = 'Punteggio<br/>Massimo';
+$zmSlangMaxFocusRange        = 'Max Focus Range';
+$zmSlangMaxFocusSpeed        = 'Max Focus Speed';
+$zmSlangMaxFocusStep         = 'Max Focus Step';
+$zmSlangMaxGainRange         = 'Max Gain Range';
+$zmSlangMaxGainSpeed         = 'Max Gain Speed';
+$zmSlangMaxGainStep          = 'Max Gain Step';
 $zmSlangMaximumFPS           = 'Massimi FPS';
+$zmSlangMaxIrisRange         = 'Max Iris Range';
+$zmSlangMaxIrisSpeed         = 'Max Iris Speed';
+$zmSlangMaxIrisStep          = 'Max Iris Step';
 $zmSlangMax                  = 'Massima';
+$zmSlangMaxPanRange          = 'Max Pan Range';
+$zmSlangMaxPanSpeed          = 'Max Pan Speed';
+$zmSlangMaxPanStep           = 'Max Pan Step';
+$zmSlangMaxTiltRange         = 'Max Tilt Range';
+$zmSlangMaxTiltSpeed         = 'Max Tilt Speed';
+$zmSlangMaxTiltStep          = 'Max Tilt Step';
+$zmSlangMaxWhiteRange        = 'Max White Bal. Range';
+$zmSlangMaxWhiteSpeed        = 'Max White Bal. Speed';
+$zmSlangMaxWhiteStep         = 'Max White Bal. Step';
+$zmSlangMaxZoomRange         = 'Max Zoom Range';
+$zmSlangMaxZoomSpeed         = 'Max Zoom Speed';
+$zmSlangMaxZoomStep          = 'Max Zoom Step';
 $zmSlangMediumBW             = 'Medium&nbsp;B/W';
 $zmSlangMedium               = 'Media';
 $zmSlangMinAlarmGeMinBlob    = 'Numero minimo di alarm-pixels che devono essere maggiori o uguali al numero minimo dei blob-pixels';
@@ -224,19 +314,42 @@ $zmSlangMinAlarmPixelsLtMax  = 'Numero minimo di alarm-pixels che devono essere
 $zmSlangMinBlobAreaLtMax     = 'Area di blob minima che deve essere minore dell area massima di blob';
 $zmSlangMinBlobsLtMax        = 'Numero minimo di blobs che devono essere minori al numero massimo di blobs';
 $zmSlangMinFilterPixelsLtMax = 'Numero minimo di filter-pixels che deve essere minore del numero massimo dei filter-pixels';
+$zmSlangMinFocusRange        = 'Min Focus Range';
+$zmSlangMinFocusSpeed        = 'Min Focus Speed';
+$zmSlangMinFocusStep         = 'Min Focus Step';
+$zmSlangMinGainRange         = 'Min Gain Range';
+$zmSlangMinGainSpeed         = 'Min Gain Speed';
+$zmSlangMinGainStep          = 'Min Gain Step';
+$zmSlangMinIrisRange         = 'Min Iris Range';
+$zmSlangMinIrisSpeed         = 'Min Iris Speed';
+$zmSlangMinIrisStep          = 'Min Iris Step';
+$zmSlangMinPanRange          = 'Min Pan Range';
+$zmSlangMinPanSpeed          = 'Min Pan Speed';
+$zmSlangMinPanStep           = 'Min Pan Step';
 $zmSlangMinPixelThresLtMax   = 'Soglia minima di pixel che devono essere minori della soglia massima di pixel';
+$zmSlangMinTiltRange         = 'Min Tilt Range';
+$zmSlangMinTiltSpeed         = 'Min Tilt Speed';
+$zmSlangMinTiltStep          = 'Min Tilt Step';
+$zmSlangMinWhiteRange        = 'Min White Bal. Range';
+$zmSlangMinWhiteSpeed        = 'Min White Bal. Speed';
+$zmSlangMinWhiteStep         = 'Min White Bal. Step';
+$zmSlangMinZoomRange         = 'Min Zoom Range';
+$zmSlangMinZoomSpeed         = 'Min Zoom Speed';
+$zmSlangMinZoomStep          = 'Min Zoom Step';
 $zmSlangMisc                 = 'Misc';
 $zmSlangMonitorIds           = 'Monitor&nbsp;Ids';
 $zmSlangMonitor              = 'Monitor';
 $zmSlangMonitors             = 'Monitors';
 $zmSlangMontage              = 'Montaggio';
 $zmSlangMonth                = 'Mese';
+$zmSlangMove                 = 'Move';
 $zmSlangMustBeGe             = 'deve essere maggiore o uguale di';
 $zmSlangMustBeLe             = 'deve essere minore o uguale di';
 $zmSlangMustConfirmPassword  = 'Devi confermare la password';
 $zmSlangMustSupplyPassword   = 'Devi inserire la password';
 $zmSlangMustSupplyUsername   = 'Devi inserire il nome-Utente';
 $zmSlangName                 = 'Nome';
+$zmSlangNear                 = 'Near';
 $zmSlangNetwork              = 'Network';
 $zmSlangNewGroup             = 'New Group';
 $zmSlangNew                  = 'Nuovo';
@@ -252,6 +365,8 @@ $zmSlangNo                   = 'No';
 $zmSlangNormal               = 'Normale';
 $zmSlangNoSavedFilters       = 'No_Filtri_Salvati';
 $zmSlangNoStatisticsRecorded = 'Non ci sono statistiche registrate per questo event/frame';
+$zmSlangNumPresets           = 'Num Presets';
+$zmSlangOpen                 = 'Open';
 $zmSlangOpEq                 = 'uguale a';
 $zmSlangOpGtEq               = 'maggiore o uguale di';
 $zmSlangOpGt                 = 'maggiore di';
@@ -267,8 +382,11 @@ $zmSlangOptionRestartWarning = 'Questi cambiamenti non avranno effetto\nfintanto
 $zmSlangOptions              = 'Optioni';
 $zmSlangOrEnterNewName       = 'o inserisci il nuovo nome';
 $zmSlangOrientation          = 'Orientazione';
+$zmSlangOut                  = 'Out';
 $zmSlangOverwriteExisting    = 'Sovrascrivi quello esistente';
 $zmSlangPaged                = 'Impaginato';
+$zmSlangPan                  = 'Pan';
+$zmSlangPanTilt              = 'Pan/Tilt';
 $zmSlangParameter            = 'Parametri';
 $zmSlangPassword             = 'Password';
 $zmSlangPasswordsDifferent   = 'Le password inserite sono differenti';
@@ -280,6 +398,8 @@ $zmSlangPlayAll              = 'Play All';
 $zmSlangPleaseWait           = 'ATTENDI';
 $zmSlangPostEventImageBuffer = 'Buffer delle immagini dopo gli Eventi';
 $zmSlangPreEventImageBuffer  = 'Buffer delle immagini prima degli Eventi';
+$zmSlangPreset               = 'Preset';
+$zmSlangPresets              = 'Presets';
 $zmSlangPrev                 = 'Precedente';
 $zmSlangRate                 = 'Rate';
 $zmSlangReal                 = 'Reale';
@@ -298,6 +418,8 @@ $zmSlangReset                = 'Reset';
 $zmSlangRestarting           = 'Sto Ripartendo';
 $zmSlangRestart              = 'Riparti';
 $zmSlangRestrictedCameraIds  = 'Restricted Camera Ids';
+$zmSlangReturnDelay          = 'Return Delay';
+$zmSlangReturnLocation       = 'Return Location';
 $zmSlangRotateLeft           = 'Ruota a sinistra';
 $zmSlangRotateRight          = 'Ruota a destra';
 $zmSlangRunMode              = 'Modo di funzionamento';
@@ -313,24 +435,39 @@ $zmSlangSectionlength        = 'Lunghezza della Sezione';
 $zmSlangSelect               = 'Select';
 $zmSlangSetLearnPrefs        = 'Seleziona le preferenze di autoapprendimento'; // This can be ignored for now
 $zmSlangSetNewBandwidth      = 'Seleziona la nuova BandaPassante';
+$zmSlangSetPreset            = 'Set Preset';
+$zmSlangSet                  = 'Set';
 $zmSlangSettings             = 'Settings';
 $zmSlangShowFilterWindow     = 'MostraFinestraFiltri';
+$zmSlangSleep                = 'Sleep';
 $zmSlangSortAsc              = 'Asc';
 $zmSlangSortBy               = 'Ordina per';
 $zmSlangSortDesc             = 'Desc';
 $zmSlangSource               = 'Ingresso';
 $zmSlangSourceType           = 'Tipo di ingresso';
+$zmSlangSpeedHigh            = 'High Speed';
+$zmSlangSpeedLow             = 'Low Speed';
+$zmSlangSpeedMedium          = 'Medium Speed';
+$zmSlangSpeed                = 'Speed';
+$zmSlangSpeedTurbo           = 'Turbo Speed';
 $zmSlangStart                = 'Start';
 $zmSlangState                = 'Stato';
 $zmSlangStats                = 'Stati';
 $zmSlangStatus               = 'Stato';
+$zmSlangStepLarge            = 'Large Step';
+$zmSlangStepMedium           = 'Medium Step';
+$zmSlangStepNone             = 'No Step';
+$zmSlangStepSmall            = 'Small Step';
+$zmSlangStep                 = 'Step';
 $zmSlangStills               = 'Fermo-immagine';
 $zmSlangStopped              = 'Sistema Stoppato';
 $zmSlangStop                 = 'Stop';
 $zmSlangStream               = 'Stream';
 $zmSlangSubmit               = 'Submit';
 $zmSlangSystem               = 'Sistema';
+$zmSlangTele                 = 'Tele';
 $zmSlangThumbnail            = 'Thumbnail';
+$zmSlangTilt                 = 'Tilt';
 $zmSlangTimeDelta            = 'Tempo di Delta';
 $zmSlangTime                 = 'Ora';
 $zmSlangTimestampLabelFormat = 'Formato etichetta Timestamp';
@@ -341,7 +478,11 @@ $zmSlangTimeStamp            = 'Time Stamp';
 $zmSlangToday                = 'Today';
 $zmSlangTools                = 'Tools';
 $zmSlangTotalBrScore         = 'Punteggio<br/>Totale';
+$zmSlangTrackDelay           = 'Track Delay';
+$zmSlangTrackMotion          = 'Track Motion';
 $zmSlangTriggers             = 'Triggers';
+$zmSlangTurboPanSpeed        = 'Turbo Pan Speed';
+$zmSlangTurboTiltSpeed       = 'Turbo Tilt Speed';
 $zmSlangType                 = 'Tipo';
 $zmSlangUnarchive            = 'Non_archiviato';
 $zmSlangUnits                = 'Unit';
@@ -368,10 +509,14 @@ $zmSlangVideo                = 'Video';
 $zmSlangViewAll              = 'Vedi tutto';
 $zmSlangViewPaged            = 'Vedi impaginato';
 $zmSlangView                 = 'Vedi';
+$zmSlangWake                 = 'Wake';
 $zmSlangWarmupFrames         = 'Frames di attenzione';
 $zmSlangWatch                = 'Guarda';
 $zmSlangWeb                  = 'Web';
 $zmSlangWeek                 = 'Settimana';
+$zmSlangWhiteBalance         = 'White Balance';
+$zmSlangWhite                = 'White';
+$zmSlangWide                 = 'Wide';
 $zmSlangX10ActivationString  = 'Stringa di Attivazione X10';
 $zmSlangX10InputAlarmString  = 'Stringa di ingresso Allarme X10';
 $zmSlangX10OutputAlarmString = 'Stringa di uscita Allarme X10';
@@ -385,18 +530,19 @@ $zmSlangZoneMaxAlarmedArea   = 'Area Massima di Allarme';
 $zmSlangZoneMaxBlobArea      = 'Area MAssima di Blob';
 $zmSlangZoneMaxBlobs         = 'Numero massimo di Blobs';
 $zmSlangZoneMaxFilteredArea  = 'Area massima Filtrata';
-$zmSlangZoneMaxPixelThres    = 'Soglia massima di Pixel (0>=?<=255)';
+$zmSlangZoneMaxPixelThres    = 'Soglia massima di Pixel (0-255)';
 $zmSlangZoneMaxX             = 'Massimo X (destra)';
 $zmSlangZoneMaxY             = 'Massimo Y (sotto)';
 $zmSlangZoneMinAlarmedArea   = 'Area massima di Allarme';
 $zmSlangZoneMinBlobArea      = 'Area minima di Blob';
 $zmSlangZoneMinBlobs         = 'Numero minimo di Blobs';
 $zmSlangZoneMinFilteredArea  = 'Area minima Filtrata';
-$zmSlangZoneMinPixelThres    = 'Soglia minima di Pixel (0>=?<=255)';
+$zmSlangZoneMinPixelThres    = 'Soglia minima di Pixel (0-255)';
 $zmSlangZoneMinX             = 'Minimo X (sinistra)';
 $zmSlangZoneMinY             = 'Minimo Y (alto)';
 $zmSlangZones                = 'Zone';
 $zmSlangZone                 = 'Zona';
+$zmSlangZoom                 = 'Zoom';
 
 // Complex replacements with formatting and/or placements, must be passed through sprintf
 $zmClangCurrentLogin         = 'Utente loggato  \'%1$s\'';
