@@ -1,7 +1,7 @@
 <?php
 //
-// ZoneMinder web Japanese language file, $Date: 2004/12/29 18:50:35 $, $Revision: 1.12 $
-// Copyright (C) 2003  Philip Coombes
+// ZoneMinder web Japanese language file, $Date: 2005/03/16 17:38:37 $, $Revision: 1.14 $
+// Copyright (C) 2003, 2004, 2005  Philip Coombes
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -73,6 +73,7 @@
 $zmSlang24BitColour          = '24ޯĶװ';
 $zmSlang8BitGrey             = '8ޯĔZW摜';
 $zmSlangActual               = 'p';
+$zmSlangAddNewControl        = 'Add New Control';
 $zmSlangAddNewMonitor        = 'ǉ';
 $zmSlangAddNewUser           = 'հޒǉ';
 $zmSlangAddNewZone           = 'ްݒǉ';
@@ -108,21 +109,60 @@ $zmSlangAttrTime             = '';
 $zmSlangAttrTotalScore       = 'v';
 $zmSlangAttrWeekday          = 'j';
 $zmSlangAutoArchiveEvents    = 'Automatically archive all matches';
+$zmSlangAuto                 = 'Auto';
 $zmSlangAutoDeleteEvents     = 'Automatically delete all matches';
 $zmSlangAutoEmailEvents      = 'Automatically email details of all matches';
 $zmSlangAutoExecuteEvents    = 'Automatically execute command on all matches';
 $zmSlangAutoMessageEvents    = 'Automatically message details of all matches';
 $zmSlangAutoUploadEvents     = 'Automatically upload all matches';
 $zmSlangAvgBrScore           = '<br/>';
-$zmSlangBadMonitorChars      = '̖OɎg镶͏a-zA0-9A-_ł';
+$zmSlangBadNameChars         = 'Names may only contain alphanumeric characters plus hyphen and underscore';
 $zmSlangBandwidth            = 'ш敝';
 $zmSlangBlobPx               = ' Px';
 $zmSlangBlobSizes            = ' ';
 $zmSlangBlobs                = '';
 $zmSlangBrightness           = 'Px';
 $zmSlangBuffers              = 'ޯ̧';
+$zmSlangCanAutoFocus         = 'Can Auto Focus';
+$zmSlangCanAutoGain          = 'Can Auto Gain';
+$zmSlangCanAutoIris          = 'Can Auto Iris';
+$zmSlangCanAutoWhite         = 'Can Auto White Bal.';
+$zmSlangCanAutoZoom          = 'Can Auto Zoom';
 $zmSlangCancelForcedAlarm    = 'װѷݾ';
 $zmSlangCancel               = 'ݾ';
+$zmSlangCanFocusAbs          = 'Can Focus Absolute';
+$zmSlangCanFocus             = 'Can Focus';
+$zmSlangCanFocusCon          = 'Can Focus Continuous';
+$zmSlangCanFocusRel          = 'Can Focus Relative';
+$zmSlangCanGainAbs           = 'Can Gain Absolute';
+$zmSlangCanGain              = 'Can Gain ';
+$zmSlangCanGainCon           = 'Can Gain Continuous';
+$zmSlangCanGainRel           = 'Can Gain Relative';
+$zmSlangCanIrisAbs           = 'Can Iris Absolute';
+$zmSlangCanIris              = 'Can Iris';
+$zmSlangCanIrisCon           = 'Can Iris Continuous';
+$zmSlangCanIrisRel           = 'Can Iris Relative';
+$zmSlangCanMoveAbs           = 'Can Move Absolute';
+$zmSlangCanMove              = 'Can Move';
+$zmSlangCanMoveCon           = 'Can Move Continuous';
+$zmSlangCanMoveDiag          = 'Can Move Diagonally';
+$zmSlangCanMoveMap           = 'Can Move Mapped';
+$zmSlangCanMoveRel           = 'Can Move Relative';
+$zmSlangCanPan               = 'Can Pan' ;
+$zmSlangCanReset             = 'Can Reset';
+$zmSlangCanSetPresets        = 'Can Set Presets';
+$zmSlangCanSleep             = 'Can Sleep';
+$zmSlangCanTilt              = 'Can Tilt';
+$zmSlangCanWake              = 'Can Wake';
+$zmSlangCanWhiteAbs          = 'Can White Bal. Absolute';
+$zmSlangCanWhiteBal          = 'Can White Bal.';
+$zmSlangCanWhite             = 'Can White Balance';
+$zmSlangCanWhiteCon          = 'Can White Bal. Continuous';
+$zmSlangCanWhiteRel          = 'Can White Bal. Relative';
+$zmSlangCanZoomAbs           = 'Can Zoom Absolute';
+$zmSlangCanZoom              = 'Can Zoom';
+$zmSlangCanZoomCon           = 'Can Zoom Continuous';
+$zmSlangCanZoomRel           = 'Can Zoom Relative';
 $zmSlangCaptureHeight        = '荞ݍ';
 $zmSlangCapturePalette       = '荞گ';
 $zmSlangCaptureWidth         = '荞ݕ';
@@ -132,6 +172,7 @@ $zmSlangCheckMethod          = 'װ @';
 $zmSlangChooseFilter         = '̨̑I';
 $zmSlangClose                = '';
 $zmSlangColour               = 'F';
+$zmSlangCommand              = 'Command';
 $zmSlangConfig               = 'Config';
 $zmSlangConfiguredFor        = 'ݒ:';
 $zmSlangConfirmPassword      = '߽ܰނ̊mF';
@@ -141,6 +182,13 @@ $zmSlangConsole              = 'ݿ';
 $zmSlangContactAdmin         = 'Ǘ҂ɂ₢킹B';
 $zmSlangContinue             = 'Continue';
 $zmSlangContrast             = '׽';
+$zmSlangControlAddress       = 'Control Address';
+$zmSlangControlCap           = 'Control Capability';
+$zmSlangControlCaps          = 'Control Capabilities';
+$zmSlangControl              = 'Control';
+$zmSlangControlDevice        = 'Control Device';
+$zmSlangControllable         = 'Controllable';
+$zmSlangControlType          = 'Control Type';
 $zmSlangCycle                = 'Cycle';
 $zmSlangCycleWatch           = 'يώ@';
 $zmSlangDay                  = 'j';
@@ -170,9 +218,11 @@ $zmSlangEventName            = 'Event Name';
 $zmSlangEventPrefix          = 'Event Prefix';
 $zmSlangEvents               = '';
 $zmSlangExclude              = 'r';
+$zmSlangFar                  = 'Far';
 $zmSlangFeed                 = '荞';
 $zmSlangFilterPx             = '̨ Px';
 $zmSlangFirst                = 'ŏ';
+$zmSlangFocus                = 'Focus';
 $zmSlangForceAlarm           = 'װ';
 $zmSlangFPS                  = 'fps';
 $zmSlangFPSReportInterval    = 'FPS񍐊Ԋu';
@@ -184,13 +234,26 @@ $zmSlangFrameSkip            = 'ڰѽ';
 $zmSlangFTP                  = 'FTP';
 $zmSlangFunc                 = '@\\';
 $zmSlangFunction             = '@\\';
+$zmSlangGain                 = 'Gain';
 $zmSlangGenerateVideo        = '޵̐';
 $zmSlangGeneratingVideo      = '޵';
 $zmSlangGoToZoneMinder       = 'ZoneMinder.comɍs';
 $zmSlangGrey                 = 'ڰ';
 $zmSlangGroups               = 'Groups';
+$zmSlangHasFocusSpeed        = 'Has Focus Speed';
+$zmSlangHasGainSpeed         = 'Has Gain Speed';
+$zmSlangHasHomePreset        = 'Has Home Preset';
+$zmSlangHasIrisSpeed         = 'Has Iris Speed';
+$zmSlangHasPanSpeed          = 'Has Pan Speed';
+$zmSlangHasPresets           = 'Has Presets';
+$zmSlangHasTiltSpeed         = 'Has Tilt Speed';
+$zmSlangHasTurboPan          = 'Has Turbo Pan';
+$zmSlangHasTurboTilt         = 'Has Turbo Tilt';
+$zmSlangHasWhiteSpeed        = 'Has White Bal. Speed';
+$zmSlangHasZoomSpeed         = 'Has Zoom Speed';
 $zmSlangHigh                 = '';
 $zmSlangHighBW               = 'ш';
+$zmSlangHome                 = 'Home';
 $zmSlangHour                 = '';
 $zmSlangHue                  = 'F';
 $zmSlangId                   = 'ID';
@@ -199,7 +262,9 @@ $zmSlangIgnore               = '';
 $zmSlangImage                = '摜';
 $zmSlangImageBufferSize      = '摜 ޯ̧ ';
 $zmSlangInclude              = 'gݍ';
+$zmSlangIn                   = 'In';
 $zmSlangInverted             = ']';
+$zmSlangIris                 = 'Iris';
 $zmSlangLanguage             = '';
 $zmSlangLast                 = 'ŏI';
 $zmSlangLimitResultsPost     = 'results only;'; // This is used at the end of the phrase 'Limit to first N results only'
@@ -212,10 +277,34 @@ $zmSlangLogin                = '۸޲';
 $zmSlangLogout               = '۸ޱ';
 $zmSlangLow                  = '';
 $zmSlangLowBW                = 'ш';
+$zmSlangMain                 = 'Main';
+$zmSlangMan                  = 'Man';
+$zmSlangManual               = 'Manual';
 $zmSlangMark                 = 'I';
 $zmSlangMax                  = 'ō';
 $zmSlangMaxBrScore           = 'ō<br/>';
+$zmSlangMaxFocusRange        = 'Max Focus Range';
+$zmSlangMaxFocusSpeed        = 'Max Focus Speed';
+$zmSlangMaxFocusStep         = 'Max Focus Step';
+$zmSlangMaxGainRange         = 'Max Gain Range';
+$zmSlangMaxGainSpeed         = 'Max Gain Speed';
+$zmSlangMaxGainStep          = 'Max Gain Step';
 $zmSlangMaximumFPS           = 'ō FPS';
+$zmSlangMaxIrisRange         = 'Max Iris Range';
+$zmSlangMaxIrisSpeed         = 'Max Iris Speed';
+$zmSlangMaxIrisStep          = 'Max Iris Step';
+$zmSlangMaxPanRange          = 'Max Pan Range';
+$zmSlangMaxPanSpeed          = 'Max Pan Speed';
+$zmSlangMaxPanStep           = 'Max Pan Step';
+$zmSlangMaxTiltRange         = 'Max Tilt Range';
+$zmSlangMaxTiltSpeed         = 'Max Tilt Speed';
+$zmSlangMaxTiltStep          = 'Max Tilt Step';
+$zmSlangMaxWhiteRange        = 'Max White Bal. Range';
+$zmSlangMaxWhiteSpeed        = 'Max White Bal. Speed';
+$zmSlangMaxWhiteStep         = 'Max White Bal. Step';
+$zmSlangMaxZoomRange         = 'Max Zoom Range';
+$zmSlangMaxZoomSpeed         = 'Max Zoom Speed';
+$zmSlangMaxZoomStep          = 'Max Zoom Step';
 $zmSlangMedium               = '';
 $zmSlangMediumBW             = 'ш';
 $zmSlangMinAlarmGeMinBlob    = 'ŒA[sNZŒuusNZȏłȂ΂Ȃ';
@@ -224,19 +313,42 @@ $zmSlangMinAlarmPixelsLtMax  = 'Œװ߸ق͍ōlȉłȂ΂Ȃ';
 $zmSlangMinBlobAreaLtMax     = 'Œۯޔ͈͍͂ōlȉłȂ΂Ȃ';
 $zmSlangMinBlobsLtMax        = 'Œۯސ͍ōȉłȂ΂Ȃ';
 $zmSlangMinFilterPixelsLtMax = 'Œ̨߸ِ͍ōȉłȂ΂Ȃ';
+$zmSlangMinFocusRange        = 'Min Focus Range';
+$zmSlangMinFocusSpeed        = 'Min Focus Speed';
+$zmSlangMinFocusStep         = 'Min Focus Step';
+$zmSlangMinGainRange         = 'Min Gain Range';
+$zmSlangMinGainSpeed         = 'Min Gain Speed';
+$zmSlangMinGainStep          = 'Min Gain Step';
+$zmSlangMinIrisRange         = 'Min Iris Range';
+$zmSlangMinIrisSpeed         = 'Min Iris Speed';
+$zmSlangMinIrisStep          = 'Min Iris Step';
+$zmSlangMinPanRange          = 'Min Pan Range';
+$zmSlangMinPanSpeed          = 'Min Pan Speed';
+$zmSlangMinPanStep           = 'Min Pan Step';
 $zmSlangMinPixelThresLtMax   = 'Œ߸臒l͍ōlȉłȂ΂Ȃ';
+$zmSlangMinTiltRange         = 'Min Tilt Range';
+$zmSlangMinTiltSpeed         = 'Min Tilt Speed';
+$zmSlangMinTiltStep          = 'Min Tilt Step';
+$zmSlangMinWhiteRange        = 'Min White Bal. Range';
+$zmSlangMinWhiteSpeed        = 'Min White Bal. Speed';
+$zmSlangMinWhiteStep         = 'Min White Bal. Step';
+$zmSlangMinZoomRange         = 'Min Zoom Range';
+$zmSlangMinZoomSpeed         = 'Min Zoom Speed';
+$zmSlangMinZoomStep          = 'Min Zoom Step';
 $zmSlangMisc                 = '̑';
 $zmSlangMonitorIds           = ' ID';
 $zmSlangMonitor              = '';
 $zmSlangMonitors             = '';
 $zmSlangMontage              = 'ޭ';
 $zmSlangMonth                = '';
+$zmSlangMove                 = 'Move';
 $zmSlangMustBeGe             = 'ȏłȂ΂Ȃ';
 $zmSlangMustBeLe             = 'ȉłȂ΂Ȃ';
 $zmSlangMustConfirmPassword  = 'pX[h̊mFĂ';
 $zmSlangMustSupplyPassword   = 'pX[h͂Ă';
 $zmSlangMustSupplyUsername   = '[U͂Ă';
 $zmSlangName                 = 'O';
+$zmSlangNear                 = 'Near';
 $zmSlangNetwork              = 'ȯܰ';
 $zmSlangNewGroup             = 'New Group';
 $zmSlangNewPassword          = 'V߽ܰ';
@@ -252,6 +364,8 @@ $zmSlangNone                 = '܂';
 $zmSlangNormal               = '';
 $zmSlangNoSavedFilters       = 'ۑꂽ̨͂܂';
 $zmSlangNoStatisticsRecorded = '̲/ڰт̓v͓o^Ă܂';
+$zmSlangNumPresets           = 'Num Presets';
+$zmSlangOpen                 = 'Open';
 $zmSlangOpEq                 = '';
 $zmSlangOpGt                 = 'ȉ';
 $zmSlangOpGtEq               = 'ȏ';
@@ -267,8 +381,11 @@ $zmSlangOptionRestartWarning = '̕ύX͋NfȂꍇ܂B\nύXĂZoneMinderċNĂB';
 $zmSlangOptions              = '߼';
 $zmSlangOrEnterNewName       = '͐VO͂Ă';
 $zmSlangOrientation          = 'صð';
+$zmSlangOut                  = 'Out';
 $zmSlangOverwriteExisting    = '㏑܂';
 $zmSlangPaged                = '߰މ';
+$zmSlangPan                  = 'Pan';
+$zmSlangPanTilt              = 'Pan/Tilt';
 $zmSlangParameter            = 'Ұ';
 $zmSlangPassword             = '߽ܰ';
 $zmSlangPasswordsDifferent   = 'VpX[hƍē̓pX[hv܂';
@@ -280,6 +397,8 @@ $zmSlangPlayAll              = 'Play All';
 $zmSlangPleaseWait           = '҂';
 $zmSlangPostEventImageBuffer = ' Ұ ޯ̧';
 $zmSlangPreEventImageBuffer  = ' Ұ ޯ̧O';
+$zmSlangPreset               = 'Preset';
+$zmSlangPresets              = 'Presets';
 $zmSlangPrev                 = 'O';
 $zmSlangRate                 = 'ڰ';
 $zmSlangReal                 = 'p';
@@ -298,6 +417,8 @@ $zmSlangReset                = 'Reset';
 $zmSlangRestart              = 'ċN';
 $zmSlangRestarting           = 'ċN';
 $zmSlangRestrictedCameraIds  = 'ꂽ ID';
+$zmSlangReturnDelay          = 'Return Delay';
+$zmSlangReturnLocation       = 'Return Location';
 $zmSlangRotateLeft           = 'ɉ]';
 $zmSlangRotateRight          = 'Eɉ]';
 $zmSlangRunMode              = 'NӰ';
@@ -313,24 +434,39 @@ $zmSlangSectionlength        = '';
 $zmSlangSelect               = 'Select';
 $zmSlangSetLearnPrefs        = 'Set Learn Prefs'; // Vݒ̎ۑ@This can be ignored for now
 $zmSlangSetNewBandwidth      = 'Vш敝̐ݒ';
+$zmSlangSetPreset            = 'Set Preset';
+$zmSlangSet                  = 'Set';
 $zmSlangSettings             = 'ݒ';
 $zmSlangShowFilterWindow     = '̨ ް̕\';
+$zmSlangSleep                = 'Sleep';
 $zmSlangSortAsc              = 'Asc';
 $zmSlangSortBy               = 'Sort by';
 $zmSlangSortDesc             = 'Desc';
 $zmSlangSource               = '';
 $zmSlangSourceType           = ' ';
+$zmSlangSpeedHigh            = 'High Speed';
+$zmSlangSpeedLow             = 'Low Speed';
+$zmSlangSpeedMedium          = 'Medium Speed';
+$zmSlangSpeed                = 'Speed';
+$zmSlangSpeedTurbo           = 'Turbo Speed';
 $zmSlangStart                = '';
 $zmSlangState                = '';
 $zmSlangStats                = 'v';
 $zmSlangStatus               = '';
+$zmSlangStepLarge            = 'Large Step';
+$zmSlangStepMedium           = 'Medium Step';
+$zmSlangStepNone             = 'No Step';
+$zmSlangStepSmall            = 'Small Step';
+$zmSlangStep                 = 'Step';
 $zmSlangStills               = 'ى摜';
 $zmSlangStop                 = '~';
 $zmSlangStopped              = '~';
 $zmSlangStream               = 'ذ';
 $zmSlangSubmit               = 'Submit';
 $zmSlangSystem               = '';
+$zmSlangTele                 = 'Tele';
 $zmSlangThumbnail            = 'Thumbnail';
+$zmSlangTilt                 = 'Tilt';
 $zmSlangTimeDelta            = ' ';
 $zmSlangTime                 = '';
 $zmSlangTimestamp            = 'ѽ';
@@ -341,7 +477,11 @@ $zmSlangTimestampLabelY      = 'ѽ  Y';
 $zmSlangToday                = 'Today';
 $zmSlangTools                = '°';
 $zmSlangTotalBrScore         = 'v<br/>';
+$zmSlangTrackDelay           = 'Track Delay';
+$zmSlangTrackMotion          = 'Track Motion';
 $zmSlangTriggers             = 'ضް';
+$zmSlangTurboPanSpeed        = 'Turbo Pan Speed';
+$zmSlangTurboTiltSpeed       = 'Turbo Tilt Speed';
 $zmSlangType                 = '';
 $zmSlangUnarchive            = '';
 $zmSlangUnits                = 'Ư';
@@ -368,10 +508,14 @@ $zmSlangVideoSize            = '޵ ';
 $zmSlangView                 = '\';
 $zmSlangViewAll              = 'S\';
 $zmSlangViewPaged            = '߰މ̕\';
+$zmSlangWake                 = 'Wake';
 $zmSlangWarmupFrames         = 'ѱ ڰ';
 $zmSlangWatch                = 'Ď';
 $zmSlangWeb                  = '';
 $zmSlangWeek                 = 'T';
+$zmSlangWhiteBalance         = 'White Balance';
+$zmSlangWhite                = 'White';
+$zmSlangWide                 = 'Wide';
 $zmSlangX10ActivationString  = 'X10N';
 $zmSlangX10InputAlarmString  = 'X10ͱװѕ';
 $zmSlangX10OutputAlarmString = 'X10oͱװѕ';
@@ -379,25 +523,26 @@ $zmSlangX10                  = 'X10';
 $zmSlangYes                  = '͂';
 $zmSlangYouNoPerms           = '̱̎܂B';
 $zmSlangZoneAlarmColour      = 'װ װ (RGB)';
-$zmSlangZoneAlarmThreshold   = 'װ 臒l(0>=?<=255)';
+$zmSlangZoneAlarmThreshold   = 'װ 臒l(0-255)';
 $zmSlangZoneFilterHeight     = '̨  (߸)';
 $zmSlangZoneFilterWidth      = '̨  (߸)';
 $zmSlangZoneMaxAlarmedArea   = 'ōװї̈';
 $zmSlangZoneMaxBlobArea      = 'ōޗ̈';
 $zmSlangZoneMaxBlobs         = 'ōސ';
 $zmSlangZoneMaxFilteredArea  = 'ǭ̈';
-$zmSlangZoneMaxPixelThres    = 'ō߸臒l (0>=?<=255)';
+$zmSlangZoneMaxPixelThres    = 'ō߸臒l (0-255)';
 $zmSlangZoneMaxX             = 'X (E)ō';
 $zmSlangZoneMaxY             = 'Y ()ō';
 $zmSlangZoneMinAlarmedArea   = 'Œװї̈';
 $zmSlangZoneMinBlobArea      = 'Œޗ̈';
 $zmSlangZoneMinBlobs         = 'Œސ';
 $zmSlangZoneMinFilteredArea  = 'Œ̨̈';
-$zmSlangZoneMinPixelThres    = 'Œ߸臒l (0>=?<=255)';
+$zmSlangZoneMinPixelThres    = 'Œ߸臒l (0-255)';
 $zmSlangZoneMinX             = 'X (E)Œ';
 $zmSlangZoneMinY             = 'Y ()Œ';
 $zmSlangZones                = 'ް';
 $zmSlangZone                 = 'ް';
+$zmSlangZoom                 = 'Zoom';
 
 // Complex replacements with formatting and/or placements, must be passed through sprintf
 $zmClangCurrentLogin         = '\'%1$s\۸޲݂Ă܂';
