@@ -1,7 +1,7 @@
 <?php
 //
-// ZoneMinder web Dutch language file, $Date: 2004/12/29 18:50:35 $, $Revision: 1.10 $
-// Copyright (C) 2003  Philip Coombes
+// ZoneMinder web Dutch language file, $Date: 2005/03/16 17:38:37 $, $Revision: 1.12 $
+// Copyright (C) 2003, 2004, 2005  Philip Coombes
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -73,6 +73,7 @@
 $zmSlang24BitColour          = '24 bit kleuren';
 $zmSlang8BitGrey             = '8 bit grijstinten';
 $zmSlangActual               = 'Aktueel';
+$zmSlangAddNewControl        = 'Add New Control';
 $zmSlangAddNewMonitor        = 'Voeg een nieuwe monitor toe';
 $zmSlangAddNewUser           = 'Voeg een nieuwe gebruiker toe';
 $zmSlangAddNewZone           = 'Voeg een nieuwe zone toe';
@@ -109,21 +110,60 @@ $zmSlangAttrTime             = 'Tijd';
 $zmSlangAttrTotalScore       = 'Totale Score';
 $zmSlangAttrWeekday          = 'Weekdag';
 $zmSlangAutoArchiveEvents    = 'Archiveer automatisch alle overeenkomsten';
+$zmSlangAuto                 = 'Auto';
 $zmSlangAutoDeleteEvents     = 'Verwijder automatisch alle overeenkomsten';
 $zmSlangAutoEmailEvents      = 'Email automatisch de details van alle overeenkomsten';
 $zmSlangAutoExecuteEvents    = 'Voer automatisch opdrachten op alle overeenkomsten uit';
 $zmSlangAutoMessageEvents    = 'Bericht automatisch de details van alle overeenkomsten';
 $zmSlangAutoUploadEvents     = 'Upload automatisch alle overeenkomsten';
 $zmSlangAvgBrScore           = 'Gem.<br/>score';
-$zmSlangBadMonitorChars      = 'Monitor Namen mogen alleen alpha numerieke karakters bevatten plus hyphens en underscores';
+$zmSlangBadNameChars         = 'Namen mogen alleen alpha numerieke karakters bevatten plus hyphens en underscores';
 $zmSlangBandwidth            = 'Bandbreedte';
 $zmSlangBlobPx               = 'Blob px';
 $zmSlangBlobs                = 'Blobs';
 $zmSlangBlobSizes            = 'Blob grootte';
 $zmSlangBrightness           = 'Helderheid';
 $zmSlangBuffers              = 'Buffers';
+$zmSlangCanAutoFocus         = 'Can Auto Focus';
+$zmSlangCanAutoGain          = 'Can Auto Gain';
+$zmSlangCanAutoIris          = 'Can Auto Iris';
+$zmSlangCanAutoWhite         = 'Can Auto White Bal.';
+$zmSlangCanAutoZoom          = 'Can Auto Zoom';
 $zmSlangCancel               = 'Cancel';
 $zmSlangCancelForcedAlarm    = 'Cancel&nbsp;geforceerd&nbsp;alarm';
+$zmSlangCanFocusAbs          = 'Can Focus Absolute';
+$zmSlangCanFocus             = 'Can Focus';
+$zmSlangCanFocusCon          = 'Can Focus Continuous';
+$zmSlangCanFocusRel          = 'Can Focus Relative';
+$zmSlangCanGainAbs           = 'Can Gain Absolute';
+$zmSlangCanGain              = 'Can Gain ';
+$zmSlangCanGainCon           = 'Can Gain Continuous';
+$zmSlangCanGainRel           = 'Can Gain Relative';
+$zmSlangCanIrisAbs           = 'Can Iris Absolute';
+$zmSlangCanIris              = 'Can Iris';
+$zmSlangCanIrisCon           = 'Can Iris Continuous';
+$zmSlangCanIrisRel           = 'Can Iris Relative';
+$zmSlangCanMoveAbs           = 'Can Move Absolute';
+$zmSlangCanMove              = 'Can Move';
+$zmSlangCanMoveCon           = 'Can Move Continuous';
+$zmSlangCanMoveDiag          = 'Can Move Diagonally';
+$zmSlangCanMoveMap           = 'Can Move Mapped';
+$zmSlangCanMoveRel           = 'Can Move Relative';
+$zmSlangCanPan               = 'Can Pan' ;
+$zmSlangCanReset             = 'Can Reset';
+$zmSlangCanSetPresets        = 'Can Set Presets';
+$zmSlangCanSleep             = 'Can Sleep';
+$zmSlangCanTilt              = 'Can Tilt';
+$zmSlangCanWake              = 'Can Wake';
+$zmSlangCanWhiteAbs          = 'Can White Bal. Absolute';
+$zmSlangCanWhiteBal          = 'Can White Bal.';
+$zmSlangCanWhite             = 'Can White Balance';
+$zmSlangCanWhiteCon          = 'Can White Bal. Continuous';
+$zmSlangCanWhiteRel          = 'Can White Bal. Relative';
+$zmSlangCanZoomAbs           = 'Can Zoom Absolute';
+$zmSlangCanZoom              = 'Can Zoom';
+$zmSlangCanZoomCon           = 'Can Zoom Continuous';
+$zmSlangCanZoomRel           = 'Can Zoom Relative';
 $zmSlangCaptureHeight        = 'Capture hoogte';
 $zmSlangCapturePalette       = 'Capture pallet';
 $zmSlangCaptureWidth         = 'Capture breedte';
@@ -133,6 +173,7 @@ $zmSlangCheckMethod          = 'Alarm Check Methode';
 $zmSlangChooseFilter         = 'Kies filter';
 $zmSlangClose                = 'Sluit';
 $zmSlangColour               = 'Kleur';
+$zmSlangCommand              = 'Command';
 $zmSlangConfig               = 'Config';
 $zmSlangConfiguredFor        = 'Geconfigureerd voor';
 $zmSlangConfirmPassword      = 'Bevestig wachtwoord';
@@ -142,6 +183,13 @@ $zmSlangConsole              = 'Console';
 $zmSlangContactAdmin         = 'Neem A.U.B. contact op met je beheerder voor details.';
 $zmSlangContinue             = 'Continue';
 $zmSlangContrast             = 'Contrast';
+$zmSlangControlAddress       = 'Control Address';
+$zmSlangControlCap           = 'Control Capability';
+$zmSlangControlCaps          = 'Control Capabilities';
+$zmSlangControl              = 'Control';
+$zmSlangControlDevice        = 'Control Device';
+$zmSlangControllable         = 'Controllable';
+$zmSlangControlType          = 'Control Type';
 $zmSlangCycle                = 'Cycle';
 $zmSlangCycleWatch           = 'Observeer cyclus';
 $zmSlangDay                  = 'Dag';
@@ -171,9 +219,11 @@ $zmSlangEventName            = 'Event Name';
 $zmSlangEventPrefix          = 'Event Prefix';
 $zmSlangEvents               = 'Gebeurtenissen';
 $zmSlangExclude              = 'Sluit uit';
+$zmSlangFar                  = 'Far';
 $zmSlangFeed                 = 'toevoer';
 $zmSlangFilterPx             = 'Filter px';
 $zmSlangFirst                = 'Eerste';
+$zmSlangFocus                = 'Focus';
 $zmSlangForceAlarm           = 'Forceeer&nbsp;alarm';
 $zmSlangFPS                  = 'fps';
 $zmSlangFPSReportInterval    = 'FPS rapport interval';
@@ -185,13 +235,26 @@ $zmSlangFrameSkip            = 'Frame overgeslagen';
 $zmSlangFTP                  = 'FTP';
 $zmSlangFunc                 = 'Func';
 $zmSlangFunction             = 'Functie';
+$zmSlangGain                 = 'Gain';
 $zmSlangGenerateVideo        = 'Genereer Video';
 $zmSlangGeneratingVideo      = 'Genereren Video';
 $zmSlangGoToZoneMinder       = 'ga naar ZoneMinder.com';
 $zmSlangGrey                 = 'Grijs';
 $zmSlangGroups               = 'Groups';
+$zmSlangHasFocusSpeed        = 'Has Focus Speed';
+$zmSlangHasGainSpeed         = 'Has Gain Speed';
+$zmSlangHasHomePreset        = 'Has Home Preset';
+$zmSlangHasIrisSpeed         = 'Has Iris Speed';
+$zmSlangHasPanSpeed          = 'Has Pan Speed';
+$zmSlangHasPresets           = 'Has Presets';
+$zmSlangHasTiltSpeed         = 'Has Tilt Speed';
+$zmSlangHasTurboPan          = 'Has Turbo Pan';
+$zmSlangHasTurboTilt         = 'Has Turbo Tilt';
+$zmSlangHasWhiteSpeed        = 'Has White Bal. Speed';
+$zmSlangHasZoomSpeed         = 'Has Zoom Speed';
 $zmSlangHighBW               = 'Hoog&nbsp;B/W';
 $zmSlangHigh                 = 'Hoog';
+$zmSlangHome                 = 'Home';
 $zmSlangHour                 = 'Uur';
 $zmSlangHue                  = 'Hue';
 $zmSlangId                   = 'Id';
@@ -200,7 +263,9 @@ $zmSlangIgnore               = 'Negeer';
 $zmSlangImageBufferSize      = 'Image buffer grootte (frames)';
 $zmSlangImage                = 'Image';
 $zmSlangInclude              = 'voeg in';
+$zmSlangIn                   = 'In';
 $zmSlangInverted             = 'omgedraaid';
+$zmSlangIris                 = 'Iris';
 $zmSlangLanguage             = 'Taal';
 $zmSlangLast                 = 'Laatste';
 $zmSlangLimitResultsPost     = 'resultaten;'; // This is used at the end of the phrase 'Limit to first N results only'
@@ -213,10 +278,34 @@ $zmSlangLogin                = 'Login';
 $zmSlangLogout               = 'Logout';
 $zmSlangLowBW                = 'Laag&nbsp;B/W';
 $zmSlangLow                  = 'Laag';
+$zmSlangMain                 = 'Main';
+$zmSlangMan                  = 'Man';
+$zmSlangManual               = 'Manual';
 $zmSlangMark                 = 'Markeer';
 $zmSlangMaxBrScore           = 'Max.<br/>score';
+$zmSlangMaxFocusRange        = 'Max Focus Range';
+$zmSlangMaxFocusSpeed        = 'Max Focus Speed';
+$zmSlangMaxFocusStep         = 'Max Focus Step';
+$zmSlangMaxGainRange         = 'Max Gain Range';
+$zmSlangMaxGainSpeed         = 'Max Gain Speed';
+$zmSlangMaxGainStep          = 'Max Gain Step';
 $zmSlangMaximumFPS           = 'Maximum FPS';
+$zmSlangMaxIrisRange         = 'Max Iris Range';
+$zmSlangMaxIrisSpeed         = 'Max Iris Speed';
+$zmSlangMaxIrisStep          = 'Max Iris Step';
 $zmSlangMax                  = 'Max';
+$zmSlangMaxPanRange          = 'Max Pan Range';
+$zmSlangMaxPanSpeed          = 'Max Pan Speed';
+$zmSlangMaxPanStep           = 'Max Pan Step';
+$zmSlangMaxTiltRange         = 'Max Tilt Range';
+$zmSlangMaxTiltSpeed         = 'Max Tilt Speed';
+$zmSlangMaxTiltStep          = 'Max Tilt Step';
+$zmSlangMaxWhiteRange        = 'Max White Bal. Range';
+$zmSlangMaxWhiteSpeed        = 'Max White Bal. Speed';
+$zmSlangMaxWhiteStep         = 'Max White Bal. Step';
+$zmSlangMaxZoomRange         = 'Max Zoom Range';
+$zmSlangMaxZoomSpeed         = 'Max Zoom Speed';
+$zmSlangMaxZoomStep          = 'Max Zoom Step';
 $zmSlangMediumBW             = 'Medium&nbsp;B/W';
 $zmSlangMedium               = 'Medium';
 $zmSlangMinAlarmGeMinBlob    = 'Minimum alarm pixels moet groter zijn of gelijk aan het minimum aantal blob pixels';
@@ -225,19 +314,42 @@ $zmSlangMinAlarmPixelsLtMax  = 'minimum alarm pixels moet kleiner zijn dan het m
 $zmSlangMinBlobAreaLtMax     = 'minimum blob gebied moet kleiner zijn dan maximum blob gebied';
 $zmSlangMinBlobsLtMax        = 'minimum blobs moet kleiner zijn dan maximum blobs';
 $zmSlangMinFilterPixelsLtMax = 'minimum filter pixels moet kleiner zijn dan maximum filter pixels';
+$zmSlangMinFocusRange        = 'Min Focus Range';
+$zmSlangMinFocusSpeed        = 'Min Focus Speed';
+$zmSlangMinFocusStep         = 'Min Focus Step';
+$zmSlangMinGainRange         = 'Min Gain Range';
+$zmSlangMinGainSpeed         = 'Min Gain Speed';
+$zmSlangMinGainStep          = 'Min Gain Step';
+$zmSlangMinIrisRange         = 'Min Iris Range';
+$zmSlangMinIrisSpeed         = 'Min Iris Speed';
+$zmSlangMinIrisStep          = 'Min Iris Step';
+$zmSlangMinPanRange          = 'Min Pan Range';
+$zmSlangMinPanSpeed          = 'Min Pan Speed';
+$zmSlangMinPanStep           = 'Min Pan Step';
 $zmSlangMinPixelThresLtMax   = 'minimum pixel kleurdiepte moet kleiner zijn dan maximum pixel threshold';
+$zmSlangMinTiltRange         = 'Min Tilt Range';
+$zmSlangMinTiltSpeed         = 'Min Tilt Speed';
+$zmSlangMinTiltStep          = 'Min Tilt Step';
+$zmSlangMinWhiteRange        = 'Min White Bal. Range';
+$zmSlangMinWhiteSpeed        = 'Min White Bal. Speed';
+$zmSlangMinWhiteStep         = 'Min White Bal. Step';
+$zmSlangMinZoomRange         = 'Min Zoom Range';
+$zmSlangMinZoomSpeed         = 'Min Zoom Speed';
+$zmSlangMinZoomStep          = 'Min Zoom Step';
 $zmSlangMisc                 = 'Misc';
 $zmSlangMonitorIds           = 'Monitor&nbsp;Ids';
 $zmSlangMonitor              = 'Monitor';
 $zmSlangMonitors             = 'Monitoren';
 $zmSlangMontage              = 'Montage';
 $zmSlangMonth                = 'Maand';
+$zmSlangMove                 = 'Move';
 $zmSlangMustBeGe             = 'Moet groter zijn of gelijk aan';
 $zmSlangMustBeLe             = 'Moet kleiner zijn of gelijk aan';
 $zmSlangMustConfirmPassword  = 'Je moet je wachtwoord bevestigen';
 $zmSlangMustSupplyPassword   = 'Je moet een wachtwoord geven';
 $zmSlangMustSupplyUsername   = 'Je moet een gebruikersnaam geven';
 $zmSlangName                 = 'Naam';
+$zmSlangNear                 = 'Near';
 $zmSlangNetwork              = 'Netwerk';
 $zmSlangNewGroup             = 'New Group';
 $zmSlangNew                  = 'Nieuw';
@@ -253,6 +365,8 @@ $zmSlangNone                 = 'Geen';
 $zmSlangNormal               = 'Normaal';
 $zmSlangNoSavedFilters       = 'GeenOpgeslagenFilters';
 $zmSlangNoStatisticsRecorded = 'er zijn geen statistieken opgenomen voor dit event/frame';
+$zmSlangNumPresets           = 'Num Presets';
+$zmSlangOpen                 = 'Open';
 $zmSlangOpEq                 = 'gelijk aan';
 $zmSlangOpGtEq               = 'groter dan of gelijk aan';
 $zmSlangOpGt                 = 'groter dan';
@@ -268,8 +382,11 @@ $zmSlangOptionRestartWarning = 'Deze veranderingen passen niet aan\nals het syst
 $zmSlangOptions              = 'Opties';
 $zmSlangOrEnterNewName       = 'of voer een nieuwe naam in';
 $zmSlangOrientation          = 'Orientatie';
+$zmSlangOut                  = 'Out';
 $zmSlangOverwriteExisting    = 'Overschrijf bestaande';
 $zmSlangPaged                = 'Paged';
+$zmSlangPan                  = 'Pan';
+$zmSlangPanTilt              = 'Pan/Tilt';
 $zmSlangParameter            = 'Parameter';
 $zmSlangPasswordsDifferent   = 'Het nieuwe en bevestigde wachtwoord zijn verschillend';
 $zmSlangPassword             = 'Wachtwoord';
@@ -281,6 +398,8 @@ $zmSlangPlayAll              = 'Play All';
 $zmSlangPleaseWait           = 'wacht A.U.B.';
 $zmSlangPostEventImageBuffer = 'Post gebeurtenis Image Buffer';
 $zmSlangPreEventImageBuffer  = 'Pre gebeurtenis Image Buffer';
+$zmSlangPreset               = 'Preset';
+$zmSlangPresets              = 'Presets';
 $zmSlangPrev                 = 'vorige';
 $zmSlangRate                 = 'Waardering';
 $zmSlangReal                 = 'Echte';
@@ -299,6 +418,8 @@ $zmSlangReset                = 'Reset';
 $zmSlangRestart              = 'herstart';
 $zmSlangRestarting           = 'herstarten';
 $zmSlangRestrictedCameraIds  = 'Verboden Camera Ids';
+$zmSlangReturnDelay          = 'Return Delay';
+$zmSlangReturnLocation       = 'Return Location';
 $zmSlangRotateLeft           = 'Draai linksom';
 $zmSlangRotateRight          = 'Draai rechtsom';
 $zmSlangRunMode              = 'Run Mode';
@@ -314,24 +435,39 @@ $zmSlangSectionlength        = 'Sectie lengte';
 $zmSlangSelect               = 'Select';
 $zmSlangSetLearnPrefs        = 'Set Learn Prefs'; // This can be ignored for now
 $zmSlangSetNewBandwidth      = 'Zet Nieuwe Bandbreedte';
+$zmSlangSetPreset            = 'Set Preset';
+$zmSlangSet                  = 'Set';
 $zmSlangSettings             = 'Instellingen';
 $zmSlangShowFilterWindow     = 'ToonFilterWindow';
+$zmSlangSleep                = 'Sleep';
 $zmSlangSortAsc              = 'Opl.';
 $zmSlangSortBy               = 'Sorteer op';
 $zmSlangSortDesc             = 'afl.';
 $zmSlangSource               = 'Bron';
 $zmSlangSourceType           = 'Bron Type';
+$zmSlangSpeedHigh            = 'High Speed';
+$zmSlangSpeedLow             = 'Low Speed';
+$zmSlangSpeedMedium          = 'Medium Speed';
+$zmSlangSpeed                = 'Speed';
+$zmSlangSpeedTurbo           = 'Turbo Speed';
 $zmSlangStart                = 'Start';
 $zmSlangState                = 'Status';
 $zmSlangStats                = 'Stats';
 $zmSlangStatus               = 'Status';
+$zmSlangStepLarge            = 'Large Step';
+$zmSlangStepMedium           = 'Medium Step';
+$zmSlangStepNone             = 'No Step';
+$zmSlangStepSmall            = 'Small Step';
+$zmSlangStep                 = 'Step';
 $zmSlangStills               = 'Plaatjes';
 $zmSlangStopped              = 'gestopt';
 $zmSlangStop                 = 'Stop';
 $zmSlangStream               = 'Stroom';
 $zmSlangSubmit               = 'Submit';
 $zmSlangSystem               = 'Systeem';
+$zmSlangTele                 = 'Tele';
 $zmSlangThumbnail            = 'Thumbnail';
+$zmSlangTilt                 = 'Tilt';
 $zmSlangTimeDelta            = 'Tijd Delta';
 $zmSlangTimestampLabelFormat = 'Tijdstempel Label Format';
 $zmSlangTimestampLabelX      = 'Tijdstempel Label X';
@@ -342,7 +478,11 @@ $zmSlangTime                 = 'Tijd';
 $zmSlangToday                = 'Today';
 $zmSlangTools                = 'Gereedschappen';
 $zmSlangTotalBrScore         = 'Totaal<br/>Score';
+$zmSlangTrackDelay           = 'Track Delay';
+$zmSlangTrackMotion          = 'Track Motion';
 $zmSlangTriggers             = 'Triggers';
+$zmSlangTurboPanSpeed        = 'Turbo Pan Speed';
+$zmSlangTurboTiltSpeed       = 'Turbo Tilt Speed';
 $zmSlangType                 = 'Type';
 $zmSlangUnarchive            = 'Dearchiveer';
 $zmSlangUnits                = 'Eenheden';
@@ -369,10 +509,14 @@ $zmSlangVideo                = 'Video';
 $zmSlangViewAll              = 'Bekijk Alles';
 $zmSlangView                 = 'Bekijk';
 $zmSlangViewPaged            = 'Bekijk Paged';
+$zmSlangWake                 = 'Wake';
 $zmSlangWarmupFrames         = 'Warmup Frames';
 $zmSlangWatch                = 'Observeer';
 $zmSlangWeb                  = 'Web';
 $zmSlangWeek                 = 'Week';
+$zmSlangWhiteBalance         = 'White Balance';
+$zmSlangWhite                = 'White';
+$zmSlangWide                 = 'Wide';
 $zmSlangX10ActivationString  = 'X10 Activatie String';
 $zmSlangX10InputAlarmString  = 'X10 Input Alarm String';
 $zmSlangX10OutputAlarmString = 'X10 Output Alarm String';
@@ -380,25 +524,26 @@ $zmSlangX10                  = 'X10';
 $zmSlangYes                  = 'Ja';
 $zmSlangYouNoPerms           = 'Je hebt niet de rechten om toegang te krijgen tot deze bronnen.';
 $zmSlangZoneAlarmColour      = 'Alarm Kleur (RGB)';
-$zmSlangZoneAlarmThreshold   = 'Alarm Drempel (0>=?<=255)';
+$zmSlangZoneAlarmThreshold   = 'Alarm Drempel (0-255)';
 $zmSlangZoneFilterHeight     = 'Filter Hoogte (pixels)';
 $zmSlangZoneFilterWidth      = 'Filter Breedte (pixels)';
 $zmSlangZoneMaxAlarmedArea   = 'Maximum Gealarmeerd gebied';
 $zmSlangZoneMaxBlobArea      = 'Maximum Blob gebied';
 $zmSlangZoneMaxBlobs         = 'Maximum Blobs';
 $zmSlangZoneMaxFilteredArea  = 'Maximum gefilterd gebied';
-$zmSlangZoneMaxPixelThres    = 'maximum Pixel diepte (0>=?<=255)';
+$zmSlangZoneMaxPixelThres    = 'maximum Pixel diepte (0-255)';
 $zmSlangZoneMaxX             = 'Maximum X (rechts)';
 $zmSlangZoneMaxY             = 'Maximum Y (onder)';
 $zmSlangZoneMinAlarmedArea   = 'Minimum Gealarmeerd gebied';
 $zmSlangZoneMinBlobArea      = 'Minimum Blob gebied';
 $zmSlangZoneMinBlobs         = 'Minimum Blobs';
 $zmSlangZoneMinFilteredArea  = 'Minimum gefilterd gebied';
-$zmSlangZoneMinPixelThres    = 'minimum Pixel diepte (0>=?<=255)';
+$zmSlangZoneMinPixelThres    = 'minimum Pixel diepte (0-255)';
 $zmSlangZoneMinX             = 'Minimum X (links)';
 $zmSlangZoneMinY             = 'Minimum Y (boven)';
 $zmSlangZones                = 'Zones';
 $zmSlangZone                 = 'Zone';
+$zmSlangZoom                 = 'Zoom';
 
 // Complex replacements with formatting and/or placements, must be passed through sprintf
 $zmClangCurrentLogin         = 'huidige login is \'%1$s\'';
