@@ -1,7 +1,7 @@
 <?php
 //
-// ZoneMinder web Polish language file, $Date: 2004/12/29 18:50:35 $, $Revision: 1.13 $
-// Copyright (C) 2003  Philip Coombes
+// ZoneMinder web Polish language file, $Date: 2005/03/16 17:38:37 $, $Revision: 1.15 $
+// Copyright (C) 2003, 2004, 2005  Philip Coombes
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -73,6 +73,7 @@ setlocale( LC_ALL, 'pl_PL' );   // All locale settings 4.3.0 and after
 $zmSlang24BitColour          = 'Kolor (24 bity)';
 $zmSlang8BitGrey             = 'Cz/b (8 bitw)';
 $zmSlangActual               = 'Aktualny';
+$zmSlangAddNewControl        = 'Add New Control';
 $zmSlangAddNewMonitor        = 'Dodaj nowy monitor';
 $zmSlangAddNewUser           = 'Dodaj uytkownika';
 $zmSlangAddNewZone           = 'Dodaj now stref';
@@ -109,21 +110,60 @@ $zmSlangAttrTime             = 'Czas';
 $zmSlangAttrTotalScore       = 'Cakowity wynik';
 $zmSlangAttrWeekday          = 'Dzie roboczy';
 $zmSlangAutoArchiveEvents    = 'Automatycznie archiwizuj wszystkie pasujce';
+$zmSlangAuto                 = 'Auto';
 $zmSlangAutoDeleteEvents     = 'Automatycznie usuwaj wszystkie pasujce';
 $zmSlangAutoEmailEvents      = 'Automatycznie wysyaj poczt wszystkie pasujce';
 $zmSlangAutoExecuteEvents    = 'Automatycznie wywouj komend na wszystkie pasujce';
 $zmSlangAutoMessageEvents    = 'Automatycznie wywietlaj komunikat na wszystkie pasujce';
 $zmSlangAutoUploadEvents     = 'Automatycznie wysyaj wszystkie pasujce';
 $zmSlangAvgBrScore           = 'red.<br/>wynik';
-$zmSlangBadMonitorChars      = 'Nazwy monitorw mog zawiera tylko litery, cyfry oraz mylnik i podkrelenie';
+$zmSlangBadNameChars         = 'Nazwy mog zawiera tylko litery, cyfry oraz mylnik i podkrelenie';
 $zmSlangBandwidth            = 'przepustowo';
 $zmSlangBlobPx               = 'Plamka Px';
 $zmSlangBlobSizes            = 'Rozmiary plamek';
 $zmSlangBlobs                = 'Plamki';
 $zmSlangBrightness           = 'Jaskrawo';
 $zmSlangBuffers              = 'Bufory';
+$zmSlangCanAutoFocus         = 'Can Auto Focus';
+$zmSlangCanAutoGain          = 'Can Auto Gain';
+$zmSlangCanAutoIris          = 'Can Auto Iris';
+$zmSlangCanAutoWhite         = 'Can Auto White Bal.';
+$zmSlangCanAutoZoom          = 'Can Auto Zoom';
 $zmSlangCancel               = 'Anuluj';
 $zmSlangCancelForcedAlarm    = 'Anuluj&nbsp;wymuszony&nbsp;alarm';
+$zmSlangCanFocusAbs          = 'Can Focus Absolute';
+$zmSlangCanFocus             = 'Can Focus';
+$zmSlangCanFocusCon          = 'Can Focus Continuous';
+$zmSlangCanFocusRel          = 'Can Focus Relative';
+$zmSlangCanGainAbs           = 'Can Gain Absolute';
+$zmSlangCanGain              = 'Can Gain ';
+$zmSlangCanGainCon           = 'Can Gain Continuous';
+$zmSlangCanGainRel           = 'Can Gain Relative';
+$zmSlangCanIrisAbs           = 'Can Iris Absolute';
+$zmSlangCanIris              = 'Can Iris';
+$zmSlangCanIrisCon           = 'Can Iris Continuous';
+$zmSlangCanIrisRel           = 'Can Iris Relative';
+$zmSlangCanMoveAbs           = 'Can Move Absolute';
+$zmSlangCanMove              = 'Can Move';
+$zmSlangCanMoveCon           = 'Can Move Continuous';
+$zmSlangCanMoveDiag          = 'Can Move Diagonally';
+$zmSlangCanMoveMap           = 'Can Move Mapped';
+$zmSlangCanMoveRel           = 'Can Move Relative';
+$zmSlangCanPan               = 'Can Pan' ;
+$zmSlangCanReset             = 'Can Reset';
+$zmSlangCanSetPresets        = 'Can Set Presets';
+$zmSlangCanSleep             = 'Can Sleep';
+$zmSlangCanTilt              = 'Can Tilt';
+$zmSlangCanWake              = 'Can Wake';
+$zmSlangCanWhiteAbs          = 'Can White Bal. Absolute';
+$zmSlangCanWhiteBal          = 'Can White Bal.';
+$zmSlangCanWhite             = 'Can White Balance';
+$zmSlangCanWhiteCon          = 'Can White Bal. Continuous';
+$zmSlangCanWhiteRel          = 'Can White Bal. Relative';
+$zmSlangCanZoomAbs           = 'Can Zoom Absolute';
+$zmSlangCanZoom              = 'Can Zoom';
+$zmSlangCanZoomCon           = 'Can Zoom Continuous';
+$zmSlangCanZoomRel           = 'Can Zoom Relative';
 $zmSlangCaptureHeight        = 'Wysoko obrazu';
 $zmSlangCapturePalette       = 'Paleta kolorw obrazu';
 $zmSlangCaptureWidth         = 'Szeroko obrazu';
@@ -133,6 +173,7 @@ $zmSlangCheckMethod          = 'Metoda sprawdzenia alarmu';
 $zmSlangChooseFilter         = 'Wybierz filtr';
 $zmSlangClose                = 'Zamknij';
 $zmSlangColour               = 'Nasycenie';
+$zmSlangCommand              = 'Command';
 $zmSlangConfig               = 'Konfiguracja';
 $zmSlangConfiguredFor        = 'Ustawiona';
 $zmSlangConfirmPassword      = 'Potwierd haso';
@@ -142,6 +183,13 @@ $zmSlangConsole              = 'Konsola';
 $zmSlangContactAdmin         = 'Skontaktuj si z Twoim adminstratorem w sprawie szczegw.';
 $zmSlangContinue             = 'Continue';
 $zmSlangContrast             = 'Kontrast';
+$zmSlangControlAddress       = 'Control Address';
+$zmSlangControlCap           = 'Control Capability';
+$zmSlangControlCaps          = 'Control Capabilities';
+$zmSlangControl              = 'Control';
+$zmSlangControlDevice        = 'Control Device';
+$zmSlangControllable         = 'Controllable';
+$zmSlangControlType          = 'Control Type';
 $zmSlangCycle                = 'Cycle';
 $zmSlangCycleWatch           = 'Cykl podgldu';
 $zmSlangDay                  = 'Dzie';
@@ -171,9 +219,11 @@ $zmSlangEventPrefix          = 'Event Prefix';
 $zmSlangEvents               = 'Zdarzenia';
 $zmSlangEvent                = 'Zdarzenie';
 $zmSlangExclude              = 'Wyklucz';
+$zmSlangFar                  = 'Far';
 $zmSlangFeed                 = 'Dostarcz';
 $zmSlangFilterPx             = 'Filtr Px';
 $zmSlangFirst                = 'Pierwszy';
+$zmSlangFocus                = 'Focus';
 $zmSlangForceAlarm           = 'Wymu&nbsp;alarm';
 $zmSlangFPS                  = 'fps';
 $zmSlangFPSReportInterval    = 'Raport (ramek/s)';
@@ -185,13 +235,26 @@ $zmSlangFrames               = 'Ramek';
 $zmSlangFTP                  = 'FTP';
 $zmSlangFunc                 = 'Funkcja';
 $zmSlangFunction             = 'Funkcja';
+$zmSlangGain                 = 'Gain';
 $zmSlangGenerateVideo        = 'Generowanie Video';
 $zmSlangGeneratingVideo      = 'Generuj Video';
 $zmSlangGoToZoneMinder       = 'Przejd na ZoneMinder.com';
 $zmSlangGrey                 = 'Cz/b';
 $zmSlangGroups               = 'Groups';
+$zmSlangHasFocusSpeed        = 'Has Focus Speed';
+$zmSlangHasGainSpeed         = 'Has Gain Speed';
+$zmSlangHasHomePreset        = 'Has Home Preset';
+$zmSlangHasIrisSpeed         = 'Has Iris Speed';
+$zmSlangHasPanSpeed          = 'Has Pan Speed';
+$zmSlangHasPresets           = 'Has Presets';
+$zmSlangHasTiltSpeed         = 'Has Tilt Speed';
+$zmSlangHasTurboPan          = 'Has Turbo Pan';
+$zmSlangHasTurboTilt         = 'Has Turbo Tilt';
+$zmSlangHasWhiteSpeed        = 'Has White Bal. Speed';
+$zmSlangHasZoomSpeed         = 'Has Zoom Speed';
 $zmSlangHighBW               = 'Wys.&nbsp;prz.';
 $zmSlangHigh                 = 'wysoka';
+$zmSlangHome                 = 'Home';
 $zmSlangHour                 = 'Godzina';
 $zmSlangHue                  = 'Odcie';
 $zmSlangIdle                 = 'Bezczynny';
@@ -200,7 +263,9 @@ $zmSlangIgnore               = 'Ignoruj';
 $zmSlangImageBufferSize      = 'Rozmiar bufora obrazu (ramek)';
 $zmSlangImage                = 'Obraz';
 $zmSlangInclude              = 'Docz';
+$zmSlangIn                   = 'In';
 $zmSlangInverted             = 'Odwrcony';
+$zmSlangIris                 = 'Iris';
 $zmSlangLanguage             = 'Jzyk';
 $zmSlangLast                 = 'Ostatni';
 $zmSlangLimitResultsPost     = 'wynikw;'; // This is used at the end of the phrase 'Limit to first N results only'
@@ -213,10 +278,34 @@ $zmSlangLogin                = 'Login';
 $zmSlangLogout               = 'Wyloguj';
 $zmSlangLowBW                = 'Nis.&nbsp;prz.';
 $zmSlangLow                  = 'niska';
+$zmSlangMain                 = 'Main';
+$zmSlangMan                  = 'Man';
+$zmSlangManual               = 'Manual';
 $zmSlangMark                 = 'Znacznik';
 $zmSlangMaxBrScore           = 'Maks.<br/>wynik';
+$zmSlangMaxFocusRange        = 'Max Focus Range';
+$zmSlangMaxFocusSpeed        = 'Max Focus Speed';
+$zmSlangMaxFocusStep         = 'Max Focus Step';
+$zmSlangMaxGainRange         = 'Max Gain Range';
+$zmSlangMaxGainSpeed         = 'Max Gain Speed';
+$zmSlangMaxGainStep          = 'Max Gain Step';
 $zmSlangMaximumFPS           = 'Maks. FPS';
+$zmSlangMaxIrisRange         = 'Max Iris Range';
+$zmSlangMaxIrisSpeed         = 'Max Iris Speed';
+$zmSlangMaxIrisStep          = 'Max Iris Step';
 $zmSlangMax                  = 'Maks.';
+$zmSlangMaxPanRange          = 'Max Pan Range';
+$zmSlangMaxPanSpeed          = 'Max Pan Speed';
+$zmSlangMaxPanStep           = 'Max Pan Step';
+$zmSlangMaxTiltRange         = 'Max Tilt Range';
+$zmSlangMaxTiltSpeed         = 'Max Tilt Speed';
+$zmSlangMaxTiltStep          = 'Max Tilt Step';
+$zmSlangMaxWhiteRange        = 'Max White Bal. Range';
+$zmSlangMaxWhiteSpeed        = 'Max White Bal. Speed';
+$zmSlangMaxWhiteStep         = 'Max White Bal. Step';
+$zmSlangMaxZoomRange         = 'Max Zoom Range';
+$zmSlangMaxZoomSpeed         = 'Max Zoom Speed';
+$zmSlangMaxZoomStep          = 'Max Zoom Step';
 $zmSlangMediumBW             = 'red.&nbsp;prz.';
 $zmSlangMedium               = 'rednia';
 $zmSlangMinAlarmGeMinBlob    = 'Minimalny rozmiar piksela alarmu musi by wikszy lub rwny od najmniejszego piksela plamki';
@@ -225,19 +314,42 @@ $zmSlangMinAlarmPixelsLtMax  = 'Minimalna liczba pikseli alarmu powinna by wiksz
 $zmSlangMinBlobAreaLtMax     = 'Minimalny obszar plamki powinien by mniejszy od maksymalnego obszaru plamki';
 $zmSlangMinBlobsLtMax        = 'Najmniejsze plamki powinny by mniejsze od najwikszych plamek' ;
 $zmSlangMinFilterPixelsLtMax = 'Najmniejsze piksele filtru powinny by mniejsze od najwikszych pikseli';
+$zmSlangMinFocusRange        = 'Min Focus Range';
+$zmSlangMinFocusSpeed        = 'Min Focus Speed';
+$zmSlangMinFocusStep         = 'Min Focus Step';
+$zmSlangMinGainRange         = 'Min Gain Range';
+$zmSlangMinGainSpeed         = 'Min Gain Speed';
+$zmSlangMinGainStep          = 'Min Gain Step';
+$zmSlangMinIrisRange         = 'Min Iris Range';
+$zmSlangMinIrisSpeed         = 'Min Iris Speed';
+$zmSlangMinIrisStep          = 'Min Iris Step';
+$zmSlangMinPanRange          = 'Min Pan Range';
+$zmSlangMinPanSpeed          = 'Min Pan Speed';
+$zmSlangMinPanStep           = 'Min Pan Step';
 $zmSlangMinPixelThresLtMax   = 'Najmniejsze progi pikseli powinny by mniejsze od najwikszych progw pikseli';
+$zmSlangMinTiltRange         = 'Min Tilt Range';
+$zmSlangMinTiltSpeed         = 'Min Tilt Speed';
+$zmSlangMinTiltStep          = 'Min Tilt Step';
+$zmSlangMinWhiteRange        = 'Min White Bal. Range';
+$zmSlangMinWhiteSpeed        = 'Min White Bal. Speed';
+$zmSlangMinWhiteStep         = 'Min White Bal. Step';
+$zmSlangMinZoomRange         = 'Min Zoom Range';
+$zmSlangMinZoomSpeed         = 'Min Zoom Speed';
+$zmSlangMinZoomStep          = 'Min Zoom Step';
 $zmSlangMisc                 = 'Inne';
 $zmSlangMonitorIds           = 'Numery&nbsp;monitorw';
 $zmSlangMonitor              = 'Monitor';
 $zmSlangMonitors             = 'Monitory';
 $zmSlangMontage              = 'Monta';
 $zmSlangMonth                = 'Miesic';
+$zmSlangMove                 = 'Move';
 $zmSlangMustBeGe             = 'musi by wiksze lub rwne od';
 $zmSlangMustBeLe             = 'musi by mniejsze lub rwne od';
 $zmSlangMustConfirmPassword  = 'Musisz potwierdzi haso';
 $zmSlangMustSupplyPassword   = 'Musisz poda haso';
 $zmSlangMustSupplyUsername   = 'Musisz poda nazw uytkownika';
 $zmSlangName                 = 'Nazwa';
+$zmSlangNear                 = 'Near';
 $zmSlangNetwork              = 'Sie';
 $zmSlangNewGroup             = 'New Group';
 $zmSlangNew                  = 'Nowy';
@@ -253,6 +365,8 @@ $zmSlangNo                   = 'Nie';
 $zmSlangNormal               = 'Normalny';
 $zmSlangNoSavedFilters       = 'BrakZapisanychFiltrw';
 $zmSlangNoStatisticsRecorded = 'Brak zapisanych statystyk dla tego zdarzenia/ramki';
+$zmSlangNumPresets           = 'Num Presets';
+$zmSlangOpen                 = 'Open';
 $zmSlangOpEq                 = 'rwny';
 $zmSlangOpGtEq               = 'wiksze lub rwne od';
 $zmSlangOpGt                 = 'wiksze od';
@@ -268,8 +382,11 @@ $zmSlangOptionRestartWarning = 'Te zmiany nie przynios natychmiastowego efektu\n
 $zmSlangOptions              = 'Opcje';
 $zmSlangOrEnterNewName       = 'lub wpisz now nazw';
 $zmSlangOrientation          = 'Orientacja';
+$zmSlangOut                  = 'Out';
 $zmSlangOverwriteExisting    = 'Nadpisz istniejce';
 $zmSlangPaged                = 'Stronicowane';
+$zmSlangPan                  = 'Pan';
+$zmSlangPanTilt              = 'Pan/Tilt';
 $zmSlangParameter            = 'Parametr';
 $zmSlangPassword             = 'Haso';
 $zmSlangPasswordsDifferent   = 'Hasa: nowe i potwierdzone s rne!';
@@ -281,6 +398,8 @@ $zmSlangPlayAll              = 'Play All';
 $zmSlangPleaseWait           = 'Prosz czeka';
 $zmSlangPostEventImageBuffer = 'Bufor obrazw po zdarzeniu';
 $zmSlangPreEventImageBuffer  = 'Bufor obrazw przed zdarzeniem';
+$zmSlangPreset               = 'Preset';
+$zmSlangPresets              = 'Presets';
 $zmSlangPrev                 = 'Poprzedni';
 $zmSlangRate                 = 'Tempo';
 $zmSlangReal                 = 'Rzeczywiste';
@@ -299,6 +418,8 @@ $zmSlangReset                = 'Reset';
 $zmSlangRestarting           = 'Restartuj';
 $zmSlangRestart              = 'Restart';
 $zmSlangRestrictedCameraIds  = 'Numery kamer';
+$zmSlangReturnDelay          = 'Return Delay';
+$zmSlangReturnLocation       = 'Return Location';
 $zmSlangRotateLeft           = 'Obr w lewo';
 $zmSlangRotateRight          = 'Obr w prawo';
 $zmSlangRunMode              = 'Tryb pracy';
@@ -314,24 +435,39 @@ $zmSlangSectionlength        = 'Dugo sekcji';
 $zmSlangSelect               = 'Select';
 $zmSlangSetLearnPrefs        = 'Ustaw preferencje nauki'; // This can be ignored for now
 $zmSlangSetNewBandwidth      = 'Ustaw now przepustowo';
+$zmSlangSetPreset            = 'Set Preset';
+$zmSlangSet                  = 'Set';
 $zmSlangSettings             = 'Ustawienia';
 $zmSlangShowFilterWindow     = 'PokaOknoFiltru';
+$zmSlangSleep                = 'Sleep';
 $zmSlangSortAsc              = 'Nara.';
 $zmSlangSortBy               = 'Sortuj';
 $zmSlangSortDesc             = 'Opad.';
 $zmSlangSource               = 'rdo';
 $zmSlangSourceType           = 'Typ rda';
+$zmSlangSpeedHigh            = 'High Speed';
+$zmSlangSpeedLow             = 'Low Speed';
+$zmSlangSpeedMedium          = 'Medium Speed';
+$zmSlangSpeed                = 'Speed';
+$zmSlangSpeedTurbo           = 'Turbo Speed';
 $zmSlangStart                = 'Start';
 $zmSlangState                = 'Stan';
 $zmSlangStats                = 'Statystyki';
 $zmSlangStatus               = 'Status';
+$zmSlangStepLarge            = 'Large Step';
+$zmSlangStepMedium           = 'Medium Step';
+$zmSlangStepNone             = 'No Step';
+$zmSlangStepSmall            = 'Small Step';
+$zmSlangStep                 = 'Step';
 $zmSlangStills               = 'Nieruchome';
 $zmSlangStopped              = 'Zatrzymany';
 $zmSlangStop                 = 'Stop';
 $zmSlangStream               = 'Ruchomy';
 $zmSlangSubmit               = 'Submit';
 $zmSlangSystem               = 'System';
+$zmSlangTele                 = 'Tele';
 $zmSlangThumbnail            = 'Thumbnail';
+$zmSlangTilt                 = 'Tilt';
 $zmSlangTime                 = 'Czas';
 $zmSlangTimeDelta            = 'Rnica czasu';
 $zmSlangTimestamp            = 'Czas';
@@ -342,7 +478,11 @@ $zmSlangTimeStamp            = 'Piecz czasu';
 $zmSlangToday                = 'Today';
 $zmSlangTools                = 'Narzdzia';
 $zmSlangTotalBrScore         = 'Cakowity<br/>wynik';
+$zmSlangTrackDelay           = 'Track Delay';
+$zmSlangTrackMotion          = 'Track Motion';
 $zmSlangTriggers             = 'Wyzwalacze';
+$zmSlangTurboPanSpeed        = 'Turbo Pan Speed';
+$zmSlangTurboTiltSpeed       = 'Turbo Tilt Speed';
 $zmSlangType                 = 'Typ';
 $zmSlangUnarchive            = 'Nie archiwizuj';
 $zmSlangUnits                = 'Jednostki';
@@ -369,10 +509,14 @@ $zmSlangVideo                = 'Video';
 $zmSlangViewAll              = 'Poka wszystko';
 $zmSlangViewPaged            = 'Poka stronami';
 $zmSlangView                 = 'Podgld';
+$zmSlangWake                 = 'Wake';
 $zmSlangWarmupFrames         = 'Ignorowane ramki';
 $zmSlangWatch                = 'podgld';
 $zmSlangWeb                  = 'Web';
 $zmSlangWeek                 = 'Tydzie';
+$zmSlangWhiteBalance         = 'White Balance';
+$zmSlangWhite                = 'White';
+$zmSlangWide                 = 'Wide';
 $zmSlangX10ActivationString  = 'X10: acuch aktywujcy';
 $zmSlangX10InputAlarmString  = 'X10: acuch wejcia alarmu';
 $zmSlangX10OutputAlarmString = 'X10: acuch wyjcia alarmu';
@@ -380,25 +524,26 @@ $zmSlangX10                  = 'X10';
 $zmSlangYes                  = 'Tak';
 $zmSlangYouNoPerms           = 'Nie masz uprawnie na dostp do tego zasobu.';
 $zmSlangZoneAlarmColour      = 'Kolor alarmu (RGB)';
-$zmSlangZoneAlarmThreshold   = 'Prg alarmu (0>=?<=255)';
+$zmSlangZoneAlarmThreshold   = 'Prg alarmu (0-255)';
 $zmSlangZoneFilterHeight     = 'Wysoko filtru (piksele)';
 $zmSlangZoneFilterWidth      = 'Szeroko filtru (piksele)';
 $zmSlangZoneMaxAlarmedArea   = 'Najwikszy obszar alarmowany';
 $zmSlangZoneMaxBlobArea      = 'Najwikszy obszar plamki';
 $zmSlangZoneMaxBlobs         = 'Najwiksze plamki';
 $zmSlangZoneMaxFilteredArea  = 'Najwikszy obszar filtrowany';
-$zmSlangZoneMaxPixelThres    = 'Najwikszy prg piksela (0>=?<=255)';
+$zmSlangZoneMaxPixelThres    = 'Najwikszy prg piksela (0-255)';
 $zmSlangZoneMaxX             = 'Najwiksze X (prawo)';
 $zmSlangZoneMaxY             = 'Najwiksze Y (d)';
 $zmSlangZoneMinAlarmedArea   = 'Najmniejszy obszar alarmowany';
 $zmSlangZoneMinBlobArea      = 'Najmniejszy obszar plamki';
 $zmSlangZoneMinBlobs         = 'Najmniejsze plamki';
 $zmSlangZoneMinFilteredArea  = 'Najmniejszy obszar filtrowany';
-$zmSlangZoneMinPixelThres    = 'Minimalny prg piksela (0>=?<=255)';
+$zmSlangZoneMinPixelThres    = 'Minimalny prg piksela (0-255)';
 $zmSlangZoneMinX             = 'Najmniejsze X (lewo)';
 $zmSlangZoneMinY             = 'Najmniejsze Y (gra)';
 $zmSlangZones                = 'Strefy';
 $zmSlangZone                 = 'Strefa';
+$zmSlangZoom                 = 'Zoom';
 
 // Complex replacements with formatting and/or placements, must be passed through sprintf
 $zmClangCurrentLogin         = 'Aktualny login \'%1$s\'';
