@@ -10,10 +10,10 @@
 
 
 // Simple String Replacements
-
 $zmSlang24BitColour          = 'cor 24 bits';
 $zmSlang8BitGrey             = 'cinza 8 bits';
 $zmSlangActual               = 'Atual';
+$zmSlangAddNewControl        = 'Add New Control';
 $zmSlangAddNewMonitor        = 'Adicionar Monitor';
 $zmSlangAddNewUser           = 'Adicionar Usurio';
 $zmSlangAddNewZone           = 'Adicionar Zona';
@@ -49,21 +49,60 @@ $zmSlangAttrTime             = 'Horrio';
 $zmSlangAttrTotalScore       = 'Score Total';
 $zmSlangAttrWeekday          = 'Dia/Semana';
 $zmSlangAutoArchiveEvents    = 'Arquivar automaticamente resultados';
+$zmSlangAuto                 = 'Auto';
 $zmSlangAutoDeleteEvents     = 'Apagar automaticamente resultados';
 $zmSlangAutoEmailEvents      = 'Enviar e-mail com detalhes dos resultados';
 $zmSlangAutoExecuteEvents    = 'Executar comando automaticamente p/ resultados';
 $zmSlangAutoMessageEvents    = 'Enviar Mensagem dos resultados';
 $zmSlangAutoUploadEvents     = 'Fazer upload automtico dos resultados';
 $zmSlangAvgBrScore           = 'Maior<br/>Score';
-$zmSlangBadMonitorChars      = 'Nomes de monitor devem ser caracteres alfanumricos mais hfen e underscore';
+$zmSlangBadNameChars         = 'Nomes devem ser caracteres alfanumricos mais hfen e underscore';
 $zmSlangBandwidth            = 'Larg/Banda';
 $zmSlangBlobPx               = 'Px Blob';
 $zmSlangBlobs                = 'Blobs';
 $zmSlangBlobSizes            = 'Tam Blob';
 $zmSlangBrightness           = 'Brilho';
 $zmSlangBuffers              = 'Buffers';
+$zmSlangCanAutoFocus         = 'Can Auto Focus';
+$zmSlangCanAutoGain          = 'Can Auto Gain';
+$zmSlangCanAutoIris          = 'Can Auto Iris';
+$zmSlangCanAutoWhite         = 'Can Auto White Bal.';
+$zmSlangCanAutoZoom          = 'Can Auto Zoom';
 $zmSlangCancel               = 'Cancelar';
 $zmSlangCancelForcedAlarm    = 'Cancelar&nbsp;Alarme&nbsp;Forado';
+$zmSlangCanFocusAbs          = 'Can Focus Absolute';
+$zmSlangCanFocus             = 'Can Focus';
+$zmSlangCanFocusCon          = 'Can Focus Continuous';
+$zmSlangCanFocusRel          = 'Can Focus Relative';
+$zmSlangCanGainAbs           = 'Can Gain Absolute';
+$zmSlangCanGain              = 'Can Gain ';
+$zmSlangCanGainCon           = 'Can Gain Continuous';
+$zmSlangCanGainRel           = 'Can Gain Relative';
+$zmSlangCanIrisAbs           = 'Can Iris Absolute';
+$zmSlangCanIris              = 'Can Iris';
+$zmSlangCanIrisCon           = 'Can Iris Continuous';
+$zmSlangCanIrisRel           = 'Can Iris Relative';
+$zmSlangCanMoveAbs           = 'Can Move Absolute';
+$zmSlangCanMove              = 'Can Move';
+$zmSlangCanMoveCon           = 'Can Move Continuous';
+$zmSlangCanMoveDiag          = 'Can Move Diagonally';
+$zmSlangCanMoveMap           = 'Can Move Mapped';
+$zmSlangCanMoveRel           = 'Can Move Relative';
+$zmSlangCanPan               = 'Can Pan' ;
+$zmSlangCanReset             = 'Can Reset';
+$zmSlangCanSetPresets        = 'Can Set Presets';
+$zmSlangCanSleep             = 'Can Sleep';
+$zmSlangCanTilt              = 'Can Tilt';
+$zmSlangCanWake              = 'Can Wake';
+$zmSlangCanWhiteAbs          = 'Can White Bal. Absolute';
+$zmSlangCanWhiteBal          = 'Can White Bal.';
+$zmSlangCanWhite             = 'Can White Balance';
+$zmSlangCanWhiteCon          = 'Can White Bal. Continuous';
+$zmSlangCanWhiteRel          = 'Can White Bal. Relative';
+$zmSlangCanZoomAbs           = 'Can Zoom Absolute';
+$zmSlangCanZoom              = 'Can Zoom';
+$zmSlangCanZoomCon           = 'Can Zoom Continuous';
+$zmSlangCanZoomRel           = 'Can Zoom Relative';
 $zmSlangCaptureHeight        = 'Altura da Captura';
 $zmSlangCapturePalette       = 'Paleta de Captura';
 $zmSlangCaptureWidth         = 'Largura de Captura';
@@ -73,6 +112,7 @@ $zmSlangCheckMethod          = 'Metodo marcar por alarme';
 $zmSlangChooseFilter         = 'Escolher Filtro';
 $zmSlangClose                = 'Fechar';
 $zmSlangColour               = 'Cor';
+$zmSlangCommand              = 'Command';
 $zmSlangConfig               = 'Config';
 $zmSlangConfiguredFor        = 'Configurado para';
 $zmSlangConfirmPassword      = 'Confirmar Senha';
@@ -82,6 +122,13 @@ $zmSlangConsole              = 'Console';
 $zmSlangContactAdmin         = 'Por favor contate o administrador para detalhes.';
 $zmSlangContinue             = 'Continue';
 $zmSlangContrast             = 'Contraste';
+$zmSlangControlAddress       = 'Control Address';
+$zmSlangControlCap           = 'Control Capability';
+$zmSlangControlCaps          = 'Control Capabilities';
+$zmSlangControl              = 'Control';
+$zmSlangControlDevice        = 'Control Device';
+$zmSlangControllable         = 'Controllable';
+$zmSlangControlType          = 'Control Type';
 $zmSlangCycle                = 'Cycle';
 $zmSlangCycleWatch           = 'Ciclo Monitor';
 $zmSlangDay                  = 'Dia';
@@ -111,9 +158,11 @@ $zmSlangEventName            = 'Event Name';
 $zmSlangEventPrefix          = 'Event Prefix';
 $zmSlangEvents               = 'Eventos';
 $zmSlangExclude              = 'Excluir';
+$zmSlangFar                  = 'Far';
 $zmSlangFeed                 = 'Alimentar';
 $zmSlangFilterPx             = 'Px de Filtro';
 $zmSlangFirst                = 'Primeiro';
+$zmSlangFocus                = 'Focus';
 $zmSlangForceAlarm           = 'Forar&nbsp;Alarme';
 $zmSlangFPS                  = 'fps';
 $zmSlangFPSReportInterval    = 'Intervalo de mostragem FPS';
@@ -125,13 +174,26 @@ $zmSlangFrameSkip            = 'Salto de Imagem';
 $zmSlangFTP                  = 'FTP';
 $zmSlangFunc                 = 'Func';
 $zmSlangFunction             = 'Funo';
+$zmSlangGain                 = 'Gain';
 $zmSlangGenerateVideo        = 'Gerar Video';
 $zmSlangGeneratingVideo      = 'Gerando Video';
 $zmSlangGoToZoneMinder       = 'Ir Para ZoneMinder.com';
 $zmSlangGrey                 = 'Cinza';
 $zmSlangGroups               = 'Groups';
+$zmSlangHasFocusSpeed        = 'Has Focus Speed';
+$zmSlangHasGainSpeed         = 'Has Gain Speed';
+$zmSlangHasHomePreset        = 'Has Home Preset';
+$zmSlangHasIrisSpeed         = 'Has Iris Speed';
+$zmSlangHasPanSpeed          = 'Has Pan Speed';
+$zmSlangHasPresets           = 'Has Presets';
+$zmSlangHasTiltSpeed         = 'Has Tilt Speed';
+$zmSlangHasTurboPan          = 'Has Turbo Pan';
+$zmSlangHasTurboTilt         = 'Has Turbo Tilt';
+$zmSlangHasWhiteSpeed        = 'Has White Bal. Speed';
+$zmSlangHasZoomSpeed         = 'Has Zoom Speed';
 $zmSlangHigh                 = 'Alto';
 $zmSlangHighBW               = 'Alta&nbsp;L/B';
+$zmSlangHome                 = 'Home';
 $zmSlangHour                 = 'Hora';
 $zmSlangHue                  = 'Saturao';
 $zmSlangId                   = 'Id';
@@ -140,7 +202,9 @@ $zmSlangIgnore               = 'Ignorar';
 $zmSlangImageBufferSize      = 'Tamanho de Buffer (imagens)';
 $zmSlangImage                = 'Imagem';
 $zmSlangInclude              = 'Incluir';
+$zmSlangIn                   = 'In';
 $zmSlangInverted             = 'Invertido';
+$zmSlangIris                 = 'Iris';
 $zmSlangLanguage             = 'Linguagem';
 $zmSlangLast                 = 'ltimo';
 $zmSlangLimitResultsPost     = 'resultados somente;'; // This is used at the end of the phrase 'Limit to first N results only'
@@ -153,10 +217,34 @@ $zmSlangLogin                = 'Conectar';
 $zmSlangLogout               = 'Sair';
 $zmSlangLow                  = 'Baixa';
 $zmSlangLowBW                = 'Baixa&nbsp;L/B';
+$zmSlangMain                 = 'Main';
+$zmSlangMan                  = 'Man';
+$zmSlangManual               = 'Manual';
 $zmSlangMark                 = 'Marcar';
 $zmSlangMaxBrScore           = 'Max.<br/>Score';
+$zmSlangMaxFocusRange        = 'Max Focus Range';
+$zmSlangMaxFocusSpeed        = 'Max Focus Speed';
+$zmSlangMaxFocusStep         = 'Max Focus Step';
+$zmSlangMaxGainRange         = 'Max Gain Range';
+$zmSlangMaxGainSpeed         = 'Max Gain Speed';
+$zmSlangMaxGainStep          = 'Max Gain Step';
 $zmSlangMaximumFPS           = 'Maximo FPS';
+$zmSlangMaxIrisRange         = 'Max Iris Range';
+$zmSlangMaxIrisSpeed         = 'Max Iris Speed';
+$zmSlangMaxIrisStep          = 'Max Iris Step';
 $zmSlangMax                  = 'Maximo';
+$zmSlangMaxPanRange          = 'Max Pan Range';
+$zmSlangMaxPanSpeed          = 'Max Pan Speed';
+$zmSlangMaxPanStep           = 'Max Pan Step';
+$zmSlangMaxTiltRange         = 'Max Tilt Range';
+$zmSlangMaxTiltSpeed         = 'Max Tilt Speed';
+$zmSlangMaxTiltStep          = 'Max Tilt Step';
+$zmSlangMaxWhiteRange        = 'Max White Bal. Range';
+$zmSlangMaxWhiteSpeed        = 'Max White Bal. Speed';
+$zmSlangMaxWhiteStep         = 'Max White Bal. Step';
+$zmSlangMaxZoomRange         = 'Max Zoom Range';
+$zmSlangMaxZoomSpeed         = 'Max Zoom Speed';
+$zmSlangMaxZoomStep          = 'Max Zoom Step';
 $zmSlangMediumBW             = 'Media&nbsp;L/B';
 $zmSlangMedium               = 'Media';
 $zmSlangMinAlarmGeMinBlob    = 'Minimo px de alarme deve ser maior ou igual ao minimo px de blob';
@@ -165,19 +253,42 @@ $zmSlangMinAlarmPixelsLtMax  = 'Minimo de px de alarme deve ser menor do que o m
 $zmSlangMinBlobAreaLtMax     = 'A area minima de blob deve ser menor do que a area mxima de blob';
 $zmSlangMinBlobsLtMax        = 'O minimo de Blobs deve ser menor que o maximo de blobs';
 $zmSlangMinFilterPixelsLtMax = 'O minimo pixel filtrados deve ser menor que o max pixels filtrados';
+$zmSlangMinFocusRange        = 'Min Focus Range';
+$zmSlangMinFocusSpeed        = 'Min Focus Speed';
+$zmSlangMinFocusStep         = 'Min Focus Step';
+$zmSlangMinGainRange         = 'Min Gain Range';
+$zmSlangMinGainSpeed         = 'Min Gain Speed';
+$zmSlangMinGainStep          = 'Min Gain Step';
+$zmSlangMinIrisRange         = 'Min Iris Range';
+$zmSlangMinIrisSpeed         = 'Min Iris Speed';
+$zmSlangMinIrisStep          = 'Min Iris Step';
+$zmSlangMinPanRange          = 'Min Pan Range';
+$zmSlangMinPanSpeed          = 'Min Pan Speed';
+$zmSlangMinPanStep           = 'Min Pan Step';
 $zmSlangMinPixelThresLtMax   = 'Minimum pixel threshold should be less than maximum pixel threshold';
+$zmSlangMinTiltRange         = 'Min Tilt Range';
+$zmSlangMinTiltSpeed         = 'Min Tilt Speed';
+$zmSlangMinTiltStep          = 'Min Tilt Step';
+$zmSlangMinWhiteRange        = 'Min White Bal. Range';
+$zmSlangMinWhiteSpeed        = 'Min White Bal. Speed';
+$zmSlangMinWhiteStep         = 'Min White Bal. Step';
+$zmSlangMinZoomRange         = 'Min Zoom Range';
+$zmSlangMinZoomSpeed         = 'Min Zoom Speed';
+$zmSlangMinZoomStep          = 'Min Zoom Step';
 $zmSlangMisc                 = 'Misc';
 $zmSlangMonitorIds           = 'Ids&nbsp;de Monitor';
 $zmSlangMonitor              = 'Monitor';
 $zmSlangMonitors             = 'Monitores';
 $zmSlangMontage              = 'Montagem';
 $zmSlangMonth                = 'Ms';
+$zmSlangMove                 = 'Move';
 $zmSlangMustBeGe             = 'deve ser maior ou igual a';
 $zmSlangMustBeLe             = 'deve ser menor ou igual a';
 $zmSlangMustConfirmPassword  = 'Voce deve Confirmar a senha';
 $zmSlangMustSupplyPassword   = 'Voce deve informar a senha';
 $zmSlangMustSupplyUsername   = 'Voce deve informar nome de usurio';
 $zmSlangName                 = 'Nome';
+$zmSlangNear                 = 'Near';
 $zmSlangNetwork              = 'Rede';
 $zmSlangNewGroup             = 'New Group';
 $zmSlangNew                  = 'Novo';
@@ -193,6 +304,8 @@ $zmSlangNone                 = 'Nada';
 $zmSlangNormal               = 'Normal';
 $zmSlangNoSavedFilters       = 'SemFiltrosSalvos';
 $zmSlangNoStatisticsRecorded = 'No h estatsticas gravadas neste evento/imagem';
+$zmSlangNumPresets           = 'Num Presets';
+$zmSlangOpen                 = 'Open';
 $zmSlangOpEq                 = 'igual a';
 $zmSlangOpGtEq               = 'maior que ou igual a';
 $zmSlangOpGt                 = 'maior que';
@@ -208,8 +321,11 @@ $zmSlangOptionRestartWarning = 'Reinicie o Zoneminder para que as mudanas tenham
 $zmSlangOptions              = 'Opes';
 $zmSlangOrEnterNewName       = 'ou defina novo nome';
 $zmSlangOrientation          = 'Orientao';
+$zmSlangOut                  = 'Out';
 $zmSlangOverwriteExisting    = 'Sobrescrever Existente';
 $zmSlangPaged                = 'Paginado';
+$zmSlangPan                  = 'Pan';
+$zmSlangPanTilt              = 'Pan/Tilt';
 $zmSlangParameter            = 'Parametro';
 $zmSlangPasswordsDifferent   = 'A nova senha e a de confirmao so diferentes';
 $zmSlangPassword             = 'Senha';
@@ -221,6 +337,8 @@ $zmSlangPlayAll              = 'Play All';
 $zmSlangPleaseWait           = 'Por Favor Espere';
 $zmSlangPostEventImageBuffer = 'Buffer de imagem ps evento';
 $zmSlangPreEventImageBuffer  = 'Buffer de imagem pr evento';
+$zmSlangPreset               = 'Preset';
+$zmSlangPresets              = 'Presets';
 $zmSlangPrev                 = 'Ant.';
 $zmSlangRate                 = 'Vel.';
 $zmSlangReal                 = 'Real';
@@ -239,6 +357,8 @@ $zmSlangReset                = 'Reset';
 $zmSlangRestarting           = 'Reiniciando';
 $zmSlangRestart              = 'Reiniciar';
 $zmSlangRestrictedCameraIds  = 'Ids de camera proibdos';
+$zmSlangReturnDelay          = 'Return Delay';
+$zmSlangReturnLocation       = 'Return Location';
 $zmSlangRotateLeft           = 'Rotacionar  esquerda ';
 $zmSlangRotateRight          = 'Rotacionar  direita';
 $zmSlangRunMode              = 'Modo de Execuo';
@@ -254,24 +374,39 @@ $zmSlangSectionlength        = 'Tamanho de evento Fixo';
 $zmSlangSelect               = 'Select';
 $zmSlangSetLearnPrefs        = 'Set Learn Prefs'; // This can be ignored for now
 $zmSlangSetNewBandwidth      = 'Defina Nova L/B';
+$zmSlangSetPreset            = 'Set Preset';
+$zmSlangSet                  = 'Set';
 $zmSlangSettings             = 'Configuraes';
 $zmSlangShowFilterWindow     = 'MostrarJanelaDeFiltros';
+$zmSlangSleep                = 'Sleep';
 $zmSlangSortAsc              = 'Asc';
 $zmSlangSortBy               = 'mostrar por';
 $zmSlangSortDesc             = 'Desc';
 $zmSlangSource               = 'Origem';
 $zmSlangSourceType           = 'Tipo de Origem';
+$zmSlangSpeedHigh            = 'High Speed';
+$zmSlangSpeedLow             = 'Low Speed';
+$zmSlangSpeedMedium          = 'Medium Speed';
+$zmSlangSpeed                = 'Speed';
+$zmSlangSpeedTurbo           = 'Turbo Speed';
 $zmSlangStart                = 'Iniciar';
 $zmSlangState                = 'Estado';
 $zmSlangStats                = 'Status';
 $zmSlangStatus               = 'Status';
+$zmSlangStepLarge            = 'Large Step';
+$zmSlangStepMedium           = 'Medium Step';
+$zmSlangStepNone             = 'No Step';
+$zmSlangStepSmall            = 'Small Step';
+$zmSlangStep                 = 'Step';
 $zmSlangStills               = 'Imagens';
 $zmSlangStop                 = 'Parar';
 $zmSlangStopped              = 'Parado';
 $zmSlangStream               = 'Contnuo';
 $zmSlangSubmit               = 'Submit';
 $zmSlangSystem               = 'Sistema';
+$zmSlangTele                 = 'Tele';
 $zmSlangThumbnail            = 'Thumbnail';
+$zmSlangTilt                 = 'Tilt';
 $zmSlangTimeDelta            = 'Tempo Delta';
 $zmSlangTimestampLabelFormat = 'Formato de etiqueta de tempo';
 $zmSlangTimestampLabelX      = 'posio de etiqueta X';
@@ -282,7 +417,11 @@ $zmSlangTime                 = 'Tempo';
 $zmSlangToday                = 'Today';
 $zmSlangTools                = 'Ferramentas';
 $zmSlangTotalBrScore         = 'Score<br/>Total';
+$zmSlangTrackDelay           = 'Track Delay';
+$zmSlangTrackMotion          = 'Track Motion';
 $zmSlangTriggers             = 'Acionadores';
+$zmSlangTurboPanSpeed        = 'Turbo Pan Speed';
+$zmSlangTurboTiltSpeed       = 'Turbo Tilt Speed';
 $zmSlangType                 = 'Tipo';
 $zmSlangUnarchive            = 'Desarquivar';
 $zmSlangUnits                = 'Unidades';
@@ -309,10 +448,14 @@ $zmSlangVideo                = 'Video';
 $zmSlangViewAll              = 'Ver Tudo';
 $zmSlangViewPaged            = 'Ver Paginado';
 $zmSlangView                 = 'Ver';
+$zmSlangWake                 = 'Wake';
 $zmSlangWarmupFrames         = 'Imagens Desconsideradas';
 $zmSlangWatch                = 'Assistir';
 $zmSlangWeb                  = 'Web';
 $zmSlangWeek                 = 'Semana';
+$zmSlangWhiteBalance         = 'White Balance';
+$zmSlangWhite                = 'White';
+$zmSlangWide                 = 'Wide';
 $zmSlangX10ActivationString  = 'String de Ativao X10';
 $zmSlangX10InputAlarmString  = 'String de Entrada  de alarme X10';
 $zmSlangX10OutputAlarmString = 'String de Sada de Alarme X10';
@@ -326,18 +469,19 @@ $zmSlangZoneMaxAlarmedArea   = 'Area mxima alarmada';
 $zmSlangZoneMaxBlobArea      = 'Area mxima de blob';
 $zmSlangZoneMaxBlobs         = 'Mximo de Blobs';
 $zmSlangZoneMaxFilteredArea  = 'Area mxima filtrada';
-$zmSlangZoneMaxPixelThres    = 'Threshold Mximo de Pixel (0>=?<=255)';
+$zmSlangZoneMaxPixelThres    = 'Threshold Mximo de Pixel (0-255)';
 $zmSlangZoneMaxX             = 'Maximo X (direita)';
 $zmSlangZoneMaxY             = 'Maximo Y (baixo)';
 $zmSlangZoneMinAlarmedArea   = 'Area Minima alarmada';
 $zmSlangZoneMinBlobArea      = 'Area Minima de Blob';
 $zmSlangZoneMinBlobs         = 'Mnimo de Blobs';
 $zmSlangZoneMinFilteredArea  = 'Area Mnima Filtrada';
-$zmSlangZoneMinPixelThres    = 'Threshold Mnimo de Pixel (0>=?<=255)';
+$zmSlangZoneMinPixelThres    = 'Threshold Mnimo de Pixel (0-255)';
 $zmSlangZoneMinX             = 'Minimo X (esquerda)';
 $zmSlangZoneMinY             = 'Minimo Y (topo)';
 $zmSlangZones                = 'Zonas';
 $zmSlangZone                 = 'Zona';
+$zmSlangZoom                 = 'Zoom';
 
 // Complex replacements with formatting and/or placements, must be passed through sprintf
 $zmClangCurrentLogin         = 'Login atual  \'%1$s\'';
