@@ -1,7 +1,7 @@
 <?php
 //
-// ZoneMinder web UK English language file, $Date: 2004/12/29 18:50:35 $, $Revision: 1.8 $
-// Copyright (C) 2003  Philip Coombes
+// ZoneMinder web UK English language file, $Date: 2005/03/16 17:38:37 $, $Revision: 1.10 $
+// Copyright (C) 2003, 2004, 2005  Philip Coombes
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -73,6 +73,7 @@ header( "Content-Type: text/html; charset=koi8-r" );
 $zmSlang24BitColour          = '24  ';
 $zmSlang8BitGrey             = '256  ';
 $zmSlangActual               = '';
+$zmSlangAddNewControl        = 'Add New Control';
 $zmSlangAddNewMonitor        = ' ';
 $zmSlangAddNewUser           = ' ';
 $zmSlangAddNewZone           = ' ';
@@ -109,21 +110,60 @@ $zmSlangAttrTime             = '';
 $zmSlangAttrTotalScore       = '. ';
 $zmSlangAttrWeekday          = ' ';
 $zmSlangAutoArchiveEvents    = 'Automatically archive all matches';
+$zmSlangAuto                 = 'Auto';
 $zmSlangAutoDeleteEvents     = 'Automatically delete all matches';
 $zmSlangAutoEmailEvents      = 'Automatically email details of all matches';
 $zmSlangAutoExecuteEvents    = 'Automatically execute command on all matches';
 $zmSlangAutoMessageEvents    = 'Automatically message details of all matches';
 $zmSlangAutoUploadEvents     = 'Automatically upload all matches';
 $zmSlangAvgBrScore           = '.<br/>';
-$zmSlangBadMonitorChars      = '     ,   ';
+$zmSlangBadNameChars         = 'Names may only contain alphanumeric characters plus hyphen and underscore';
 $zmSlangBandwidth            = '';
 $zmSlangBlobPx               = ' ';
 $zmSlangBlobs                = '- ';
 $zmSlangBlobSizes            = ' ';
 $zmSlangBrightness           = '';
 $zmSlangBuffers              = '';
+$zmSlangCanAutoFocus         = 'Can Auto Focus';
+$zmSlangCanAutoGain          = 'Can Auto Gain';
+$zmSlangCanAutoIris          = 'Can Auto Iris';
+$zmSlangCanAutoWhite         = 'Can Auto White Bal.';
+$zmSlangCanAutoZoom          = 'Can Auto Zoom';
 $zmSlangCancelForcedAlarm    = '&nbsp;&nbsp;';
 $zmSlangCancel               = '';
+$zmSlangCanFocusAbs          = 'Can Focus Absolute';
+$zmSlangCanFocus             = 'Can Focus';
+$zmSlangCanFocusCon          = 'Can Focus Continuous';
+$zmSlangCanFocusRel          = 'Can Focus Relative';
+$zmSlangCanGainAbs           = 'Can Gain Absolute';
+$zmSlangCanGain              = 'Can Gain ';
+$zmSlangCanGainCon           = 'Can Gain Continuous';
+$zmSlangCanGainRel           = 'Can Gain Relative';
+$zmSlangCanIrisAbs           = 'Can Iris Absolute';
+$zmSlangCanIris              = 'Can Iris';
+$zmSlangCanIrisCon           = 'Can Iris Continuous';
+$zmSlangCanIrisRel           = 'Can Iris Relative';
+$zmSlangCanMoveAbs           = 'Can Move Absolute';
+$zmSlangCanMove              = 'Can Move';
+$zmSlangCanMoveCon           = 'Can Move Continuous';
+$zmSlangCanMoveDiag          = 'Can Move Diagonally';
+$zmSlangCanMoveMap           = 'Can Move Mapped';
+$zmSlangCanMoveRel           = 'Can Move Relative';
+$zmSlangCanPan               = 'Can Pan' ;
+$zmSlangCanReset             = 'Can Reset';
+$zmSlangCanSetPresets        = 'Can Set Presets';
+$zmSlangCanSleep             = 'Can Sleep';
+$zmSlangCanTilt              = 'Can Tilt';
+$zmSlangCanWake              = 'Can Wake';
+$zmSlangCanWhiteAbs          = 'Can White Bal. Absolute';
+$zmSlangCanWhiteBal          = 'Can White Bal.';
+$zmSlangCanWhite             = 'Can White Balance';
+$zmSlangCanWhiteCon          = 'Can White Bal. Continuous';
+$zmSlangCanWhiteRel          = 'Can White Bal. Relative';
+$zmSlangCanZoomAbs           = 'Can Zoom Absolute';
+$zmSlangCanZoom              = 'Can Zoom';
+$zmSlangCanZoomCon           = 'Can Zoom Continuous';
+$zmSlangCanZoomRel           = 'Can Zoom Relative';
 $zmSlangCaptureHeight        = '  Y';
 $zmSlangCapturePalette       = ' ';
 $zmSlangCaptureWidth         = '  X';
@@ -133,6 +173,7 @@ $zmSlangCheckMethod          = '  ';
 $zmSlangChooseFilter         = ' ';
 $zmSlangClose                = '';
 $zmSlangColour               = '';
+$zmSlangCommand              = 'Command';
 $zmSlangConfig               = 'Config';
 $zmSlangConfiguredFor        = ' ';
 $zmSlangConfirmPassword      = ' ';
@@ -142,6 +183,13 @@ $zmSlangConsole              = '';
 $zmSlangContactAdmin         = '    .';
 $zmSlangContinue             = 'Continue';
 $zmSlangContrast             = '';
+$zmSlangControlAddress       = 'Control Address';
+$zmSlangControlCap           = 'Control Capability';
+$zmSlangControlCaps          = 'Control Capabilities';
+$zmSlangControl              = 'Control';
+$zmSlangControlDevice        = 'Control Device';
+$zmSlangControllable         = 'Controllable';
+$zmSlangControlType          = 'Control Type';
 $zmSlangCycle                = 'Cycle';
 $zmSlangCycleWatch           = ' ';
 $zmSlangDay                  = '';
@@ -171,9 +219,11 @@ $zmSlangEvent                = '';
 $zmSlangEventPrefix          = 'Event Prefix';
 $zmSlangEvents               = '';
 $zmSlangExclude              = '';
+$zmSlangFar                  = 'Far';
 $zmSlangFeed                 = 'Feed';
 $zmSlangFilterPx             = ' ';
 $zmSlangFirst                = '';
+$zmSlangFocus                = 'Focus';
 $zmSlangForceAlarm           = '&nbsp;';
 $zmSlangFPS                  = '/c';
 $zmSlangFPSReportInterval    = '   ';
@@ -185,13 +235,26 @@ $zmSlangFrameSkip            = ' ';
 $zmSlangFTP                  = 'FTP';
 $zmSlangFunc                 = '.';
 $zmSlangFunction             = '';
+$zmSlangGain                 = 'Gain';
 $zmSlangGenerateVideo        = ' ';
 $zmSlangGeneratingVideo      = ' ';
 $zmSlangGoToZoneMinder       = '  ZoneMinder.com';
 $zmSlangGrey                 = '/';
 $zmSlangGroups               = 'Groups';
+$zmSlangHasFocusSpeed        = 'Has Focus Speed';
+$zmSlangHasGainSpeed         = 'Has Gain Speed';
+$zmSlangHasHomePreset        = 'Has Home Preset';
+$zmSlangHasIrisSpeed         = 'Has Iris Speed';
+$zmSlangHasPanSpeed          = 'Has Pan Speed';
+$zmSlangHasPresets           = 'Has Presets';
+$zmSlangHasTiltSpeed         = 'Has Tilt Speed';
+$zmSlangHasTurboPan          = 'Has Turbo Pan';
+$zmSlangHasTurboTilt         = 'Has Turbo Tilt';
+$zmSlangHasWhiteSpeed        = 'Has White Bal. Speed';
+$zmSlangHasZoomSpeed         = 'Has Zoom Speed';
 $zmSlangHighBW               = ' ';
 $zmSlangHigh                 = '';
+$zmSlangHome                 = 'Home';
 $zmSlangHour                 = '';
 $zmSlangHue                  = '';
 $zmSlangId                   = 'Id';
@@ -200,7 +263,9 @@ $zmSlangIgnore               = '';
 $zmSlangImageBufferSize      = '  ';
 $zmSlangImage                = '';
 $zmSlangInclude              = '';
+$zmSlangIn                   = 'In';
 $zmSlangInverted             = '';
+$zmSlangIris                 = 'Iris';
 $zmSlangLanguage             = '';
 $zmSlangLast                 = '';
 $zmSlangLimitResultsPost     = 'results only;'; // This is used at the end of the phrase 'Limit to first N results only'
@@ -213,10 +278,34 @@ $zmSlangLogin                = '';
 $zmSlangLogout               = '';
 $zmSlangLowBW                = ' ';
 $zmSlangLow                  = '';
+$zmSlangMain                 = 'Main';
+$zmSlangMan                  = 'Man';
+$zmSlangManual               = 'Manual';
 $zmSlangMark                 = '';
 $zmSlangMaxBrScore           = '.<br/>';
+$zmSlangMaxFocusRange        = 'Max Focus Range';
+$zmSlangMaxFocusSpeed        = 'Max Focus Speed';
+$zmSlangMaxFocusStep         = 'Max Focus Step';
+$zmSlangMaxGainRange         = 'Max Gain Range';
+$zmSlangMaxGainSpeed         = 'Max Gain Speed';
+$zmSlangMaxGainStep          = 'Max Gain Step';
 $zmSlangMax                  = '.';
 $zmSlangMaximumFPS           = '   (/)';
+$zmSlangMaxIrisRange         = 'Max Iris Range';
+$zmSlangMaxIrisSpeed         = 'Max Iris Speed';
+$zmSlangMaxIrisStep          = 'Max Iris Step';
+$zmSlangMaxPanRange          = 'Max Pan Range';
+$zmSlangMaxPanSpeed          = 'Max Pan Speed';
+$zmSlangMaxPanStep           = 'Max Pan Step';
+$zmSlangMaxTiltRange         = 'Max Tilt Range';
+$zmSlangMaxTiltSpeed         = 'Max Tilt Speed';
+$zmSlangMaxTiltStep          = 'Max Tilt Step';
+$zmSlangMaxWhiteRange        = 'Max White Bal. Range';
+$zmSlangMaxWhiteSpeed        = 'Max White Bal. Speed';
+$zmSlangMaxWhiteStep         = 'Max White Bal. Step';
+$zmSlangMaxZoomRange         = 'Max Zoom Range';
+$zmSlangMaxZoomSpeed         = 'Max Zoom Speed';
+$zmSlangMaxZoomStep          = 'Max Zoom Step';
 $zmSlangMediumBW             = ' ';
 $zmSlangMedium               = '';
 $zmSlangMinAlarmGeMinBlob    = '.         .   ';
@@ -225,19 +314,42 @@ $zmSlangMinAlarmPixelsLtMax  = ' -       -  ';
 $zmSlangMinBlobAreaLtMax     = '         ';
 $zmSlangMinBlobsLtMax        = '         ';
 $zmSlangMinFilterPixelsLtMax = '            ';
+$zmSlangMinFocusRange        = 'Min Focus Range';
+$zmSlangMinFocusSpeed        = 'Min Focus Speed';
+$zmSlangMinFocusStep         = 'Min Focus Step';
+$zmSlangMinGainRange         = 'Min Gain Range';
+$zmSlangMinGainSpeed         = 'Min Gain Speed';
+$zmSlangMinGainStep          = 'Min Gain Step';
+$zmSlangMinIrisRange         = 'Min Iris Range';
+$zmSlangMinIrisSpeed         = 'Min Iris Speed';
+$zmSlangMinIrisStep          = 'Min Iris Step';
+$zmSlangMinPanRange          = 'Min Pan Range';
+$zmSlangMinPanSpeed          = 'Min Pan Speed';
+$zmSlangMinPanStep           = 'Min Pan Step';
 $zmSlangMinPixelThresLtMax   = '  -       - ';
+$zmSlangMinTiltRange         = 'Min Tilt Range';
+$zmSlangMinTiltSpeed         = 'Min Tilt Speed';
+$zmSlangMinTiltStep          = 'Min Tilt Step';
+$zmSlangMinWhiteRange        = 'Min White Bal. Range';
+$zmSlangMinWhiteSpeed        = 'Min White Bal. Speed';
+$zmSlangMinWhiteStep         = 'Min White Bal. Step';
+$zmSlangMinZoomRange         = 'Min Zoom Range';
+$zmSlangMinZoomSpeed         = 'Min Zoom Speed';
+$zmSlangMinZoomStep          = 'Min Zoom Step';
 $zmSlangMisc                 = '';
 $zmSlangMonitorIds           = 'Id&nbsp;';
 $zmSlangMonitor              = '';
 $zmSlangMonitors             = '';
 $zmSlangMontage              = 'Montage';
 $zmSlangMonth                = '';
+$zmSlangMove                 = 'Move';
 $zmSlangMustBeGe             = '    ';
 $zmSlangMustBeLe             = '    ';
 $zmSlangMustConfirmPassword  = '   ';
 $zmSlangMustSupplyPassword   = '   ';
 $zmSlangMustSupplyUsername   = '    ';
 $zmSlangName                 = '';
+$zmSlangNear                 = 'Near';
 $zmSlangNetwork              = '';
 $zmSlangNewGroup             = 'New Group';
 $zmSlangNew                  = '.';
@@ -253,6 +365,8 @@ $zmSlangNone                 = '';
 $zmSlangNormal               = '';
 $zmSlangNoSavedFilters       = '  ';
 $zmSlangNoStatisticsRecorded = '   /  ';
+$zmSlangNumPresets           = 'Num Presets';
+$zmSlangOpen                 = 'Open';
 $zmSlangOpEq                 = '';
 $zmSlangOpGt                 = '';
 $zmSlangOpGtEq               = '  ';
@@ -268,8 +382,11 @@ $zmSlangOptionRestartWarning = '      .';
 $zmSlangOptions              = '';
 $zmSlangOrEnterNewName       = '   ';
 $zmSlangOrientation          = '';
+$zmSlangOut                  = 'Out';
 $zmSlangOverwriteExisting    = ' ';
 $zmSlangPaged                = ' ';
+$zmSlangPan                  = 'Pan';
+$zmSlangPanTilt              = 'Pan/Tilt';
 $zmSlangParameter            = '';
 $zmSlangPassword             = '';
 $zmSlangPasswordsDifferent   = '  ';
@@ -281,6 +398,8 @@ $zmSlangPlayAll              = 'Play All';
 $zmSlangPleaseWait           = ' ';
 $zmSlangPostEventImageBuffer = '  ';
 $zmSlangPreEventImageBuffer  = '  ';
+$zmSlangPreset               = 'Preset';
+$zmSlangPresets              = 'Presets';
 $zmSlangPrev                 = '.';
 $zmSlangRate                 = '';
 $zmSlangReal                 = '';
@@ -299,6 +418,8 @@ $zmSlangReset                = 'Reset';
 $zmSlangRestart              = '';
 $zmSlangRestarting           = '';
 $zmSlangRestrictedCameraIds  = 'Id  ';
+$zmSlangReturnDelay          = 'Return Delay';
+$zmSlangReturnLocation       = 'Return Location';
 $zmSlangRotateLeft           = ' ';
 $zmSlangRotateRight          = ' ';
 $zmSlangRunMode              = ' ';
@@ -314,24 +435,39 @@ $zmSlangSectionlength        = '  ( )';
 $zmSlangSelect               = 'Select';
 $zmSlangSetLearnPrefs        = 'Set Learn Prefs'; // This can be ignored for now
 $zmSlangSetNewBandwidth      = '   ';
+$zmSlangSetPreset            = 'Set Preset';
+$zmSlangSet                  = 'Set';
 $zmSlangSettings             = '';
 $zmSlangShowFilterWindow     = '  ';
+$zmSlangSleep                = 'Sleep';
 $zmSlangSortAsc              = 'Asc';
 $zmSlangSortBy               = 'Sort by';
 $zmSlangSortDesc             = 'Desc';
 $zmSlangSource               = '';
 $zmSlangSourceType           = ' ';
+$zmSlangSpeedHigh            = 'High Speed';
+$zmSlangSpeedLow             = 'Low Speed';
+$zmSlangSpeedMedium          = 'Medium Speed';
+$zmSlangSpeed                = 'Speed';
+$zmSlangSpeedTurbo           = 'Turbo Speed';
 $zmSlangStart                = '';
 $zmSlangState                = '';
 $zmSlangStats                = '';
 $zmSlangStatus               = '';
+$zmSlangStepLarge            = 'Large Step';
+$zmSlangStepMedium           = 'Medium Step';
+$zmSlangStepNone             = 'No Step';
+$zmSlangStepSmall            = 'Small Step';
+$zmSlangStep                 = 'Step';
 $zmSlangStills               = '-';
 $zmSlangStop                 = '';
 $zmSlangStopped              = '';
 $zmSlangStream               = '';
 $zmSlangSubmit               = 'Submit';
 $zmSlangSystem               = '';
+$zmSlangTele                 = 'Tele';
 $zmSlangThumbnail            = 'Thumbnail';
+$zmSlangTilt                 = 'Tilt';
 $zmSlangTimeDelta            = ' ';
 $zmSlangTime                 = '';
 $zmSlangTimestamp            = ' ';
@@ -342,7 +478,11 @@ $zmSlangTimestampLabelY      = 'Y- ';
 $zmSlangToday                = 'Today';
 $zmSlangTools                = '';
 $zmSlangTotalBrScore         = '.<br/>';
+$zmSlangTrackDelay           = 'Track Delay';
+$zmSlangTrackMotion          = 'Track Motion';
 $zmSlangTriggers             = '';
+$zmSlangTurboPanSpeed        = 'Turbo Pan Speed';
+$zmSlangTurboTiltSpeed       = 'Turbo Tilt Speed';
 $zmSlangType                 = '';
 $zmSlangUnarchive            = '.&nbsp;&nbsp;';
 $zmSlangUnits                = '. ';
@@ -369,10 +509,14 @@ $zmSlangVideoSize            = ' ';
 $zmSlangViewAll              = '. ';
 $zmSlangView                 = '';
 $zmSlangViewPaged            = '. ';
+$zmSlangWake                 = 'Wake';
 $zmSlangWarmupFrames         = ' ';
 $zmSlangWatch                = 'Watch';
 $zmSlangWeb                  = '';
 $zmSlangWeek                 = '';
+$zmSlangWhiteBalance         = 'White Balance';
+$zmSlangWhite                = 'White';
+$zmSlangWide                 = 'Wide';
 $zmSlangX10ActivationString  = 'X10 Activation String';
 $zmSlangX10InputAlarmString  = 'X10 Input Alarm String';
 $zmSlangX10OutputAlarmString = 'X10 Output Alarm String';
@@ -380,25 +524,26 @@ $zmSlangX10                  = 'X10';
 $zmSlangYes                  = '';
 $zmSlangYouNoPerms           = '         .';
 $zmSlangZoneAlarmColour      = '  (RGB)';
-$zmSlangZoneAlarmThreshold   = '  (0>=?<=255)';
+$zmSlangZoneAlarmThreshold   = '  (0-255)';
 $zmSlangZoneFilterHeight     = '  ( .)';
 $zmSlangZoneFilterWidth      = '  ( .)';
 $zmSlangZoneMaxAlarmedArea   = '.  ';
 $zmSlangZoneMaxBlobArea      = '.  ';
 $zmSlangZoneMaxBlobs         = '. - ';
 $zmSlangZoneMaxFilteredArea  = 'c.   ';
-$zmSlangZoneMaxPixelThres    = '  -  (0>=?<=255)';
+$zmSlangZoneMaxPixelThres    = '  -  (0-255)';
 $zmSlangZoneMaxX             = '. X  ( )';
 $zmSlangZoneMaxY             = 'M. Y  ( )';
 $zmSlangZoneMinAlarmedArea   = '.  ';
 $zmSlangZoneMinBlobArea      = '.  ';
 $zmSlangZoneMinBlobs         = '. - ';
 $zmSlangZoneMinFilteredArea  = '.   ';
-$zmSlangZoneMinPixelThres    = '  -  (0>=?<=255)';
+$zmSlangZoneMinPixelThres    = '  -  (0-255)';
 $zmSlangZoneMinX             = '. X  ( )';
 $zmSlangZoneMinY             = 'M. Y  ( )';
 $zmSlangZones                = '';
 $zmSlangZone                 = '';
+$zmSlangZoom                 = 'Zoom';
 
 // Complex replacements with formatting and/or placements, must be passed through sprintf
 $zmClangCurrentLogin         = ' : \'%1$s\'';
